@@ -1,10 +1,4 @@
-/* HEADER */
-
-/*                                          *
- * Contains:                                *
- *                                          *
- *                                          */
-
+#include "license_pbs.h" /* See here for the software license */
 
 #include "mcom.h"
 
@@ -460,9 +454,7 @@ int MXMLAppendAttr(
 
     len = strlen(E->AVal[ATok]) + strlen(AVal) + 2;
 
-    tmpAVal = realloc(
-      E->AVal[ATok],
-      len);
+    tmpAVal = realloc(E->AVal[ATok], len);
 
     if (tmpAVal == NULL)
       {
@@ -532,7 +524,7 @@ int MXMLSetVal(
       ptr = (char *)V;
       Vlen = strlen(ptr);
     
-      outbuf = (char *)malloc(buf_size*(sizeof(char)));
+      outbuf = calloc(buf_size, (sizeof(char)));
       
       if (outbuf == NULL)
         {
@@ -756,7 +748,7 @@ int MXMLToXString(
     {
     NewSize = MMAX_BUFFER;
 
-    if ((*Buf = (char *)malloc(NewSize)) == NULL)
+    if ((*Buf = calloc(1, NewSize)) == NULL)
       {
       /* cannot allocate buffer */
 
