@@ -355,7 +355,7 @@ istrue(char *string)
 
 
 void
-states(char *string, char *q, char *r, char *h, char *w, char *t, char *e, int len)
+states(char *string, char *q, char *r, char *h, char *w, char *t, char *e, char *comp, int len)
   {
   char *c, *d, *f, *s, l;
 
@@ -379,6 +379,7 @@ states(char *string, char *q, char *r, char *h, char *w, char *t, char *e, int l
     else if (strcmp(s, "Waiting") == 0) d = w;
     else if (strcmp(s, "Transit") == 0) d = t;
     else if (strcmp(s, "Exiting") == 0) d = e;
+    else if (strcmp(s, "Complete") == 0) d = comp;
 
     c++;
 
@@ -846,6 +847,7 @@ display_statque(struct batch_status *status, int prtheader, int full, char *serv
   char wat[NUML+1];
   char trn[NUML+1];
   char ext[NUML+1];
+  char comp[NUML+1];
   char type[TYPEL+1];
   char format[80];
 
@@ -874,6 +876,7 @@ display_statque(struct batch_status *status, int prtheader, int full, char *serv
     strcpy(wat, "0");
     strcpy(trn, "0");
     strcpy(ext, "0");
+    strcpy(comp, "0");
     type[0] = '\0';
 
     if (full)
@@ -975,7 +978,7 @@ display_statque(struct batch_status *status, int prtheader, int full, char *serv
             }
           else if (strcmp(a->name, ATTR_count) == 0)
             {
-            states(e, que, run, hld, wat, trn, ext, NUML);
+            states(e, que, run, hld, wat, trn, ext, comp, NUML);
             }
           else if (strcmp(a->name, ATTR_qtype) == 0)
             {
@@ -1029,6 +1032,7 @@ display_statserver(struct batch_status *status, int prtheader, int full, int nod
   char wat[NUML+1];
   char trn[NUML+1];
   char ext[NUML+1];
+  char comp[NUML+1];
   char nod[NODESL+1];
   char stats[STATUSL+1];
   char format[80];
@@ -1054,6 +1058,7 @@ display_statserver(struct batch_status *status, int prtheader, int full, int nod
     strcpy(wat, "0");
     strcpy(trn, "0");
     strcpy(ext, "0");
+    strcpy(comp, "0");
     strcpy(nod, "-/-");
     stats[0] = '\0';
 
@@ -1143,7 +1148,7 @@ display_statserver(struct batch_status *status, int prtheader, int full, int nod
             }
           else if (strcmp(a->name, ATTR_count) == 0)
             {
-            states(e, que, run, hld, wat, trn, ext, NUML);
+            states(e, que, run, hld, wat, trn, ext, comp, NUML);
             }
           else if (strcmp(a->name, ATTR_status) == 0)
             {
@@ -1193,14 +1198,13 @@ display_statserver(struct batch_status *status, int prtheader, int full, int nod
   return;
   }
 
-static int
-getNumNodesInUse(int myconnection)
+static int getNumNodesInUse(
+    
+  int myconnection)
+
   {
-
   struct batch_status *j_status;
-
   struct batch_status *temp;
-
   struct attrl        *attr;
 
   struct attropl *run_list = 0;
@@ -1209,13 +1213,14 @@ getNumNodesInUse(int myconnection)
   int  nodect;
   int  cpuct;
   int  nodes;
+  int  local_errno = 0;
 
   set_attrop(&run_list, ATTR_state, (char *)NULL, "R", EQ);
-  j_status = pbs_selstat(myconnection, run_list, NULL);
+  j_status = pbs_selstat_err(myconnection, run_list, NULL, &local_errno);
 
   if (j_status == NULL)
     {
-    if (pbs_errno != PBSE_NONE)
+    if (local_errno != PBSE_NONE)
       {
       errmsg = pbs_geterrmsg(myconnection);
 
@@ -1225,7 +1230,7 @@ getNumNodesInUse(int myconnection)
         }
       else
         {
-        fprintf(stderr, "xpbs_datadump: Error (%d) selecting running jobs to obtain nodes in use value\n", pbs_errno);
+        fprintf(stderr, "xpbs_datadump: Error (%d) selecting running jobs to obtain nodes in use value\n", local_errno);
         }
 
       return(-1);
@@ -1274,15 +1279,15 @@ getNumNodesInUse(int myconnection)
   return(nodesInUse);
   }
 
-int
-main(  /* qstat */
-  int argc,
-  char **argv
-)
+int main(  /* qstat */
+
+  int    argc,
+  char **argv)
+
   {
   int c;
   int errflg = 0;
-  volatile int any_failed = 0;
+  int any_failed = 0;
 
   char server_out[MAXSERVERNAME];
   char full_server_name[MAXSERVERNAME];
@@ -1621,19 +1626,19 @@ main(  /* qstat */
 
     if (myconnection <= 0)
       {
-      fprintf(stderr, "xpbs_datadump: Can not myconnection to server %s (%d)\n",
-              server_out, pbs_errno);
+      fprintf(stderr, "xpbs_datadump: Can not connect to server %s \n",
+        server_out);
       any_failed = myconnection;
       continue;
       }
 
     /* Get server information */
-    p_status = pbs_statserver(myconnection, NULL, NULL);
+    p_status = pbs_statserver_err(myconnection, NULL, NULL, &any_failed);
 
     if (p_status == NULL)
       {
 
-      if (pbs_errno)
+      if (any_failed)
         {
         errmsg = pbs_geterrmsg(myconnection);
 
@@ -1642,11 +1647,9 @@ main(  /* qstat */
           fprintf(stderr, "qstat: %s ", errmsg);
           }
         else
-          fprintf(stderr, "xpbs_datadump: Error (%d) getting status of server ", pbs_errno);
+          fprintf(stderr, "xpbs_datadump: Error (%d) getting status of server ", any_failed);
 
         fprintf(stderr, "%s\n", server_out);
-
-        any_failed = pbs_errno;
         }
       }
     else
@@ -1663,11 +1666,11 @@ main(  /* qstat */
       }
 
     /* Get the queue information */
-    p_status = pbs_statque(myconnection, queue_name_out, NULL, NULL);
+    p_status = pbs_statque_err(myconnection, queue_name_out, NULL, NULL, &any_failed);
 
     if (p_status == NULL)
       {
-      if (pbs_errno)
+      if (any_failed)
         {
         errmsg = pbs_geterrmsg(myconnection);
 
@@ -1676,11 +1679,9 @@ main(  /* qstat */
           fprintf(stderr, "qstat: %s ", errmsg);
           }
         else
-          fprintf(stderr, "xpbs_datadump: Error (%d) getting status of queue ", pbs_errno);
+          fprintf(stderr, "xpbs_datadump: Error (%d) getting status of queue ", any_failed);
 
         fprintf(stderr, "%s\n", queue_name_out);
-
-        any_failed = pbs_errno;
         }
       }
     else
@@ -1696,11 +1697,11 @@ main(  /* qstat */
     /*
     ### Get Jobs summary info information for each of the servers
     */
-    p_status = pbs_selstat(myconnection, select_list, NULL);
+    p_status = pbs_selstat_err(myconnection, select_list, NULL, &any_failed);
 
     if (p_status == NULL)
       {
-      if (pbs_errno != PBSE_NONE)
+      if (any_failed != PBSE_NONE)
         {
         errmsg = pbs_geterrmsg(myconnection);
 
@@ -1710,10 +1711,8 @@ main(  /* qstat */
           }
         else
           {
-          fprintf(stderr, "xpbs_datadump: Error (%d) selecting jobs\n", pbs_errno);
+          fprintf(stderr, "xpbs_datadump: Error (%d) selecting jobs\n", any_failed);
           }
-
-        any_failed = pbs_errno;
         }
       }
     else     /* got some output */
