@@ -187,7 +187,7 @@ union attr_val    /* the attribute value */
   };
 
 
-struct attribute
+struct pbs_attribute
   {
 
 unsigned int at_flags:
@@ -198,7 +198,7 @@ unsigned int at_type:
   union  attr_val at_val;  /* the attribute value */
   };
 
-typedef struct attribute attribute;
+typedef struct pbs_attribute pbs_attribute;
 
 /*
  * The following structure is used to define an attribute for any parent
@@ -210,13 +210,13 @@ typedef struct attribute attribute;
 struct attribute_def
   {
   char *at_name;
-  int (*at_decode)(attribute *patr, char *name, char *rn, char *val, int perm);
-  int (*at_encode)(attribute *pattr, tlist_head *phead,
+  int (*at_decode)(pbs_attribute *patr, char *name, char *rn, char *val, int perm);
+  int (*at_encode)(pbs_attribute *pattr, tlist_head *phead,
                       char *aname, char *rsname, int mode, int perm);
-  int (*at_set)(attribute *pattr, attribute *new, enum batch_op);
-  int (*at_comp)(attribute *pattr, attribute *with);
-  void (*at_free)(attribute *pattr);
-  int (*at_action)(attribute *pattr, void *pobject, int actmode);
+  int (*at_set)(pbs_attribute *pattr, pbs_attribute *new, enum batch_op);
+  int (*at_comp)(pbs_attribute *pattr, pbs_attribute *with);
+  void (*at_free)(pbs_attribute *pattr);
+  int (*at_action)(pbs_attribute *pattr, void *pobject, int actmode);
 
   unsigned int at_flags:
   ATRFLAG; /* flags: perms, ...  */
@@ -335,108 +335,108 @@ struct array_strings
  * specific attribute value function prototypes
  */
 
-extern void clear_attr(attribute *pattr, attribute_def *pdef);
+extern void clear_attr(pbs_attribute *pattr, attribute_def *pdef);
 extern int  find_attr(attribute_def *attrdef, char *name, int limit);
 extern int  recov_attr(int fd, void *parent, attribute_def *padef,
-			   attribute *pattr, int limit, int unknown, int do_actions);
-extern long attr_ifelse_long(attribute *, attribute *, long);
-extern void free_null(attribute *attr);
-extern void free_noop(attribute *attr);
+			   pbs_attribute *pattr, int limit, int unknown, int do_actions);
+extern long attr_ifelse_long(pbs_attribute *, pbs_attribute *, long);
+extern void free_null(pbs_attribute *attr);
+extern void free_noop(pbs_attribute *attr);
 extern svrattrl *attrlist_alloc(int szname, int szresc, int szval);
 extern svrattrl *attrlist_create(char *aname, char *rname, int szval);
 extern void free_attrlist(tlist_head *attrhead);
-extern int  attr_atomic_set(svrattrl *plist, attribute *old,
-                                  attribute *new, attribute_def *pdef, int limit,
+extern int  attr_atomic_set(svrattrl *plist, pbs_attribute *old,
+                                  pbs_attribute *new, attribute_def *pdef, int limit,
                                   int unkn, int privil, int *badattr);
-extern int  attr_atomic_node_set(svrattrl *plist, attribute *old,
-                                       attribute *new, attribute_def *pdef, int limit,
+extern int  attr_atomic_node_set(svrattrl *plist, pbs_attribute *old,
+                                       pbs_attribute *new, attribute_def *pdef, int limit,
                                        int unkn, int privil, int *badattr);
-extern void attr_atomic_kill(attribute *temp, attribute_def *pdef, int);
+extern void attr_atomic_kill(pbs_attribute *temp, attribute_def *pdef, int);
 
-int  decode_b(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_c(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_l(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_ll(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_size(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_str(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_time(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_arst(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_arst_direct(attribute *patr, char *val);
-int  decode_arst_merge(attribute *,char *,char *,char *);
-int  decode_resc(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_depend(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_hold(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_uacl(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_unkn(attribute *patr, char *name, char *rn, char *val, int);
-int  decode_tv(attribute *patr, char *name,  char *rescn,	char *val, int);
+int  decode_b(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_c(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_l(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_ll(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_size(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_str(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_time(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_arst(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_arst_direct(pbs_attribute *patr, char *val);
+int  decode_arst_merge(pbs_attribute *,char *,char *,char *);
+int  decode_resc(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_depend(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_hold(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_uacl(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_unkn(pbs_attribute *patr, char *name, char *rn, char *val, int);
+int  decode_tv(pbs_attribute *patr, char *name,  char *rescn,	char *val, int);
  
-int  encode_b(attribute *attr, tlist_head *phead, char *atname,
+int  encode_b(pbs_attribute *attr, tlist_head *phead, char *atname,
                            char *rsname, int mode, int perm);
-int  encode_c(attribute *attr, tlist_head *phead, char *atname,
+int  encode_c(pbs_attribute *attr, tlist_head *phead, char *atname,
                            char *rsname, int mode, int perm);
-int encode_l(attribute *attr, tlist_head *phead, char *atname,
+int encode_l(pbs_attribute *attr, tlist_head *phead, char *atname,
                            char *rsname, int mode, int perm);
-int encode_ll(attribute *attr, tlist_head *phead, char *atname,
+int encode_ll(pbs_attribute *attr, tlist_head *phead, char *atname,
                            char *rsname, int mode, int perm);
-int encode_size(attribute *attr, tlist_head *phead, char *atname,
+int encode_size(pbs_attribute *attr, tlist_head *phead, char *atname,
                               char *rsname, int mode, int perm);
-int encode_str(attribute *attr, tlist_head *phead, char *atname,
+int encode_str(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_time(attribute *attr, tlist_head *phead, char *atname,
+int encode_time(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_arst(attribute *attr, tlist_head *phead, char *atname,
+int encode_arst(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_resc(attribute *attr, tlist_head *phead, char *atname,
+int encode_resc(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_inter(attribute *attr, tlist_head *phead, char *atname,
+int encode_inter(pbs_attribute *attr, tlist_head *phead, char *atname,
                               char *rsname, int mode, int perm);
-int encode_unkn(attribute *attr, tlist_head *phead, char *atname,
+int encode_unkn(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_depend(attribute *attr, tlist_head *phead, char *atname,
+int encode_depend(pbs_attribute *attr, tlist_head *phead, char *atname,
                                char *rsname, int mode, int perm);
-int encode_hold(attribute *attr, tlist_head *phead, char *atname,
+int encode_hold(pbs_attribute *attr, tlist_head *phead, char *atname,
                              char *rsname, int mode, int perm);
-int encode_tv(attribute *attr, tlist_head *phead, char *atname,
+int encode_tv(pbs_attribute *attr, tlist_head *phead, char *atname,
 							char *rsname, int mode, int perm);
 
 
-extern int set_b(attribute *attr, attribute *new, enum batch_op);
-extern int set_c(attribute *attr, attribute *new, enum batch_op);
-extern int set_l(attribute *attr, attribute *new, enum batch_op);
-extern int set_ll(attribute *attr, attribute *new, enum batch_op);
-extern int set_size(attribute *attr, attribute *new, enum batch_op);
-extern int set_str(attribute *attr, attribute *new, enum batch_op);
-extern int set_arst(attribute *attr, attribute *new, enum batch_op);
-extern int set_resc(attribute *attr, attribute *new, enum batch_op);
-extern int set_hostacl(attribute *attr, attribute *new, enum batch_op);
-extern int set_uacl(attribute *attr, attribute *new, enum batch_op);
-extern int set_unkn(attribute *attr, attribute *new, enum batch_op);
-extern int set_depend(attribute *attr, attribute *new, enum batch_op);
-extern int set_tv(struct attribute *attr, struct attribute *new, enum batch_op op);
+extern int set_b(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_c(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_l(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_ll(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_size(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_str(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_arst(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_resc(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_hostacl(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_uacl(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_unkn(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_depend(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int set_tv(struct pbs_attribute *attr, struct pbs_attribute *new, enum batch_op op);
 
 enum compare_types { LESS, EQUAL, GREATER, NOT_COMPARED };
 
-extern int comp_b(attribute *, attribute *);
-extern int comp_c(attribute *, attribute *);
-extern int comp_l(attribute *, attribute *);
-extern int comp_ll(attribute *, attribute *);
-extern int comp_size(attribute *, attribute *);
-extern int comp_str(attribute *, attribute *);
-extern int comp_arst(attribute *, attribute *);
-extern int comp_resc(attribute *, attribute *);
-extern int comp_resc2(attribute *, attribute *, int, char *, enum compare_types);
-extern int comp_unkn(attribute *, attribute *);
-extern int comp_depend(attribute *, attribute *);
-extern int comp_hold(attribute *, attribute *);
-int comp_tv(struct attribute *attr, struct attribute *with);
+extern int comp_b(pbs_attribute *, pbs_attribute *);
+extern int comp_c(pbs_attribute *, pbs_attribute *);
+extern int comp_l(pbs_attribute *, pbs_attribute *);
+extern int comp_ll(pbs_attribute *, pbs_attribute *);
+extern int comp_size(pbs_attribute *, pbs_attribute *);
+extern int comp_str(pbs_attribute *, pbs_attribute *);
+extern int comp_arst(pbs_attribute *, pbs_attribute *);
+extern int comp_resc(pbs_attribute *, pbs_attribute *);
+extern int comp_resc2(pbs_attribute *, pbs_attribute *, int, char *, enum compare_types);
+extern int comp_unkn(pbs_attribute *, pbs_attribute *);
+extern int comp_depend(pbs_attribute *, pbs_attribute *);
+extern int comp_hold(pbs_attribute *, pbs_attribute *);
+int comp_tv(struct pbs_attribute *attr, struct pbs_attribute *with);
 
-extern int action_depend(attribute *, void *, int);
+extern int action_depend(pbs_attribute *, void *, int);
 
-extern void free_str(attribute *);
-extern void free_arst(attribute *);
-extern void free_resc(attribute *);
-extern void free_depend(attribute *);
-extern void free_unkn(attribute *);
+extern void free_str(pbs_attribute *);
+extern void free_arst(pbs_attribute *);
+extern void free_resc(pbs_attribute *);
+extern void free_depend(pbs_attribute *);
+extern void free_unkn(pbs_attribute *);
 extern int   parse_equal_string(char *, char **, char **);
 extern char *parse_comma_string(char *,char **);
 
@@ -445,55 +445,55 @@ extern char *parse_comma_string(char *,char **);
 /* other associated funtions */
 struct dynamic_string;
 
-extern int   acl_check(attribute *, char *canidate, int type);
+extern int   acl_check(pbs_attribute *, char *canidate, int type);
 int          acl_check_my_array_string(struct array_strings *, char *, int);
-extern char *arst_string(char *str, attribute *pattr);
+extern char *arst_string(char *str, pbs_attribute *pattr);
 extern void  attrl_fixlink(tlist_head *svrattrl);
-extern void  recov_acl(attribute *, attribute_def *, char *, char *);
-extern int   save_acl(attribute *, attribute_def *,  char *, char *);
-extern int   save_attr(attribute_def *, attribute *, int, int, char *, size_t *, size_t);
-extern int   save_attr_xml(attribute_def *, attribute *, int, int);
+extern void  recov_acl(pbs_attribute *, attribute_def *, char *, char *);
+extern int   save_acl(pbs_attribute *, attribute_def *,  char *, char *);
+extern int   save_attr(attribute_def *, pbs_attribute *, int, int, char *, size_t *, size_t);
+extern int   save_attr_xml(attribute_def *, pbs_attribute *, int, int);
 extern int   write_buffer(char *,int,int);
 extern int   size_to_str(struct size_value,char *,int);
-extern int   attr_to_str(struct dynamic_string *ds, attribute_def *,struct attribute,int);
-extern int   str_to_attr(char *,char *,struct attribute *,struct attribute_def *);
+extern int   attr_to_str(struct dynamic_string *ds, attribute_def *,struct pbs_attribute,int);
+extern int   str_to_attr(char *,char *,struct pbs_attribute *,struct attribute_def *);
 
-extern int      encode_state(attribute *, tlist_head *, char *, char *, int, int);
-extern int      encode_props(attribute*, tlist_head*, char*, char*, int, int);
-extern int      encode_jobs(attribute*, tlist_head*, char*, char*, int, int);
-extern int      encode_ntype(attribute*, tlist_head*, char*, char*, int, int);
-extern int      decode_state(attribute*, char*, char*, char*, int);
-extern int      decode_props(attribute*, char*, char*, char*, int);
-extern int      decode_ntype(attribute*, char*, char*, char*, int);
-extern int      decode_null(attribute*, char*, char*, char*, int);
-extern int      comp_null(attribute*, attribute*);
+extern int      encode_state(pbs_attribute *, tlist_head *, char *, char *, int, int);
+extern int      encode_props(pbs_attribute*, tlist_head*, char*, char*, int, int);
+extern int      encode_jobs(pbs_attribute*, tlist_head*, char*, char*, int, int);
+extern int      encode_ntype(pbs_attribute*, tlist_head*, char*, char*, int, int);
+extern int      decode_state(pbs_attribute*, char*, char*, char*, int);
+extern int      decode_props(pbs_attribute*, char*, char*, char*, int);
+extern int      decode_ntype(pbs_attribute*, char*, char*, char*, int);
+extern int      decode_null(pbs_attribute*, char*, char*, char*, int);
+extern int      comp_null(pbs_attribute*, pbs_attribute*);
 extern int      count_substrings(char*, int*);
-extern int      set_node_state(attribute*, attribute*, enum batch_op);
-extern int      set_node_ntype(attribute*, attribute*, enum batch_op);
-extern int      set_node_props(attribute*, attribute*, enum batch_op);
-extern int      set_null(attribute*, attribute*, enum batch_op);
-extern int      node_state(attribute*, void*, int);
-extern int      node_np_action(attribute*, void*, int);
-extern int      node_mom_port_action(attribute*, void*, int);
-extern int      node_mom_rm_port_action(attribute*, void*, int);
-extern int      node_numa_action(attribute*, void*, int);
-extern int      node_gpus_action(attribute*, void*, int);
-extern int      gpu_str_action(attribute*, void*, int);
-extern int      numa_str_action(attribute *, void *,int);
-extern int      node_ntype(attribute*, void*, int);
-extern int      node_prop_list(attribute*, void*, int);
-extern int      node_status_list(attribute*, void*, int);
-extern int      node_gpustatus_list(attribute*, void*, int);
-extern int      node_note(attribute*, void*, int);
-extern int      node_alt_name(attribute*, void*, int);
-extern int      set_note_str(attribute *attr, attribute *new, enum batch_op);
-extern int      set_alt_name_str(attribute *attr, attribute *new, enum batch_op);
-extern void     replace_attr_string(attribute*, char*);
-extern int 		job_radix_action (attribute *new, void *pobj, int actmode);
+extern int      set_node_state(pbs_attribute*, pbs_attribute*, enum batch_op);
+extern int      set_node_ntype(pbs_attribute*, pbs_attribute*, enum batch_op);
+extern int      set_node_props(pbs_attribute*, pbs_attribute*, enum batch_op);
+extern int      set_null(pbs_attribute*, pbs_attribute*, enum batch_op);
+extern int      node_state(pbs_attribute*, void*, int);
+extern int      node_np_action(pbs_attribute*, void*, int);
+extern int      node_mom_port_action(pbs_attribute*, void*, int);
+extern int      node_mom_rm_port_action(pbs_attribute*, void*, int);
+extern int      node_numa_action(pbs_attribute*, void*, int);
+extern int      node_gpus_action(pbs_attribute*, void*, int);
+extern int      gpu_str_action(pbs_attribute*, void*, int);
+extern int      numa_str_action(pbs_attribute *, void *,int);
+extern int      node_ntype(pbs_attribute*, void*, int);
+extern int      node_prop_list(pbs_attribute*, void*, int);
+extern int      node_status_list(pbs_attribute*, void*, int);
+extern int      node_gpustatus_list(pbs_attribute*, void*, int);
+extern int      node_note(pbs_attribute*, void*, int);
+extern int      node_alt_name(pbs_attribute*, void*, int);
+extern int      set_note_str(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern int      set_alt_name_str(pbs_attribute *attr, pbs_attribute *new, enum batch_op);
+extern void     replace_attr_string(pbs_attribute*, char*);
+extern int 		job_radix_action (pbs_attribute *new, void *pobj, int actmode);
 
 /* Token manipulation functions */
 
-extern int  decode_tokens(attribute *, char *, char *, char *, int);
+extern int  decode_tokens(pbs_attribute *, char *, char *, char *, int);
 
 int timeval_subtract(struct timeval *result, struct timeval *x, struct timeval *y);
 
