@@ -85,6 +85,10 @@
  * POSIX Batch Extensions Working group is 1003.15
  */
 #ifndef PBSE_
+#include <pbs_constants.h>
+
+#define FALSE 0
+#define TRUE 1
 
 /* pbs error constants generator */
 /** @see pbs_error_db.h */
