@@ -115,6 +115,7 @@
 #define ATTR_reservation_id "reservation_id"
 #define ATTR_login_node_id "login_node_id"
 #define ATTR_login_prop "login_property"
+#define ATTR_external_nodes "external_nodes"
 #define ATTR_M "Mail_Users"
 #define ATTR_N "Job_Name"
 #define ATTR_S "Shell_Path_List"
@@ -327,6 +328,7 @@
 #define ATTR_nomailforce             "no_mail_force"
 #define ATTR_interactivejobscanroam  "interactive_jobs_can_roam" 
 #define ATTR_crayenabled             "cray_enabled"
+#define ATTR_maxuserqueuable         "max_user_queuable"
 /* additional node "attributes" names */
 
 #define ATTR_NODE_state            "state"
