@@ -247,6 +247,14 @@ struct grpcache
 
 #endif /* END NGROUPS_MAX */
 
+enum job_types
+  {
+  JOB_TYPE_normal,       /* no cray nodes involved */
+  JOB_TYPE_cray,         /* only cray nodes involved */
+  JOB_TYPE_login,        /* only cray login nodes involved */
+  JOB_TYPE_heterogeneous /* both cray computes and external nodes involved */
+  };
+
 /*
  * Job attributes/resources are maintained in one of two ways.
  * Most of the attributes are maintained in a decoded or parsed form.
@@ -369,6 +377,7 @@ enum job_atr
   JOB_ATR_reservation_id,
   JOB_ATR_login_node_id,
   JOB_ATR_login_prop,
+  JOB_ATR_external_nodes,
 #include "site_job_attr_enum.h"
 
   JOB_ATR_UNKN,  /* the special "unknown" type    */
@@ -482,6 +491,15 @@ typedef struct
   } pjobexec_t;
 
 
+/* on the server this array will replace many of the doubly linked-lists */
+typedef struct all_jobs
+  {
+  resizable_array *ra;
+  hash_table_t    *ht;
+
+  pthread_mutex_t *alljobs_mutex;
+  }all_jobs;
+
 
 
 
@@ -580,10 +598,15 @@ struct job
   int               ji_is_array_template;    /* set to TRUE if this is a "template job" for a job array*/
   int               ji_have_nodes_request; /* set to TRUE if node spec uses keyword nodes */
   int               ji_cold_restart; /* set to TRUE if this job has been loaded through a cold restart */
-#endif/* PBS_MOM */   /* END SERVER ONLY */
 
-  pthread_mutex_t *ji_mutex;
-  char    ji_being_recycled;
+  /* these three are only used for heterogeneous jobs */
+  struct job       *ji_external_clone; /* the sub-job on the external (to the cray) nodes */
+  struct job       *ji_cray_clone;     /* the sub-job on the cray nodes */
+  struct job       *ji_parent_job;     /* parent job (only populated on the sub-jobs */
+
+  pthread_mutex_t  *ji_mutex;
+  char              ji_being_recycled;
+#endif/* PBS_MOM */   /* END SERVER ONLY */
 
   /*
    * fixed size internal data - maintained via "quick save"
@@ -674,14 +697,8 @@ typedef struct job job;
 #define TOO_MANY_JOBS_IN_RECYCLER -1
 #define JOBS_TO_REMOVE             1000
 
-/* on the server this array will replace many of the doubly linked-lists */
-struct all_jobs
-  {
-  resizable_array *ra;
-  hash_table_t    *ht;
 
-  pthread_mutex_t *alljobs_mutex;
-  };
+
 
 void initialize_all_jobs_array(struct all_jobs *);
 int  insert_job(struct all_jobs *, job *);
@@ -1048,7 +1065,6 @@ extern void  depend_clrrdy(job *);
 extern int   depend_on_que(pbs_attribute *, void *, int);
 extern int   depend_on_exec(job *);
 extern int   depend_on_term(job *);
-extern job  *find_job(char *);
 job         *find_job_regular_jobs(char *);
 job         *find_job_array_jobs(char *);
 extern char *get_egroup(job *);
@@ -1059,7 +1075,10 @@ extern int   job_abt(job **, char *);
 extern job  *job_alloc();
 extern int   job_unlink_file(job *pjob, const char *name);
 #ifndef PBS_MOM
-extern job  *job_clone(job *,struct job_array *, int);
+job         *job_clone(job *,struct job_array *, int);
+job         *svr_find_job(char *jobid, int get_subjob);
+#else
+extern job  *mom_find_job(char *);
 #endif
 extern job  *job_recov(char *);
 extern int   job_save(job *, int, int);
@@ -1075,6 +1094,7 @@ extern void  svr_mailowner(job *, int, int, char *);
 extern void  set_resc_deflt(job *, pbs_attribute *, int);
 extern void  set_statechar(job *);
 extern int   svr_setjobstate(job *, int, int, int);
+int          split_job(job *);
 
 #ifdef BATCH_REQUEST_H
 extern job  *chk_job_request(char *, struct batch_request *);
@@ -1086,14 +1106,6 @@ extern struct batch_request *setup_cpyfiles(struct batch_request *, job *, char
 extern struct batch_request *cpy_checkpoint(struct batch_request *, job *, enum job_atr, int);
 #endif /* BATCH_REQUEST_H */
 
-#ifdef QUEUE_H
-extern int   count_user_queued_jobs(pbs_queue *,char *);
-extern int   svr_chkque(job *, pbs_queue *, char *, int, char *);
-extern int   default_router(job *, pbs_queue *, long);
-extern int   site_alt_router(job *, pbs_queue *, long);
-extern int   site_acl_check(job *, pbs_queue *);
-extern void  set_chkpt_deflt(job *, pbs_queue *);
-#endif /* QUEUE_H */
 
 #ifdef WORK_TASK_H
 int   issue_signal(job **, char *, void(*)(struct work_task *), void *);
