@@ -184,6 +184,7 @@ typedef struct node_job_add_info
   char                      node_name[PBS_MAXNODENAME + 1];
   int                       ppn_needed;
   int                       gpu_needed;
+  int                       is_external;
   struct node_job_add_info *next;
   } node_job_add_info;
 
@@ -327,11 +328,13 @@ struct pbsnode
   
   unsigned char         nd_is_alps_reporter;
   unsigned char         nd_is_alps_login;
+  resizable_array      *nd_ms_jobs;          /* the jobs this node is mother superior for */
   all_nodes             alps_subnodes;
 
   pthread_mutex_t      *nd_mutex;            /* semaphore for accessing this node's data */
   };
 
+extern struct pbsnode *alps_reporter;
 
 
 #define INITIAL_NODE_SIZE  20
@@ -343,6 +346,7 @@ int             insert_node(all_nodes *,struct pbsnode *);
 int             remove_node(all_nodes *,struct pbsnode *);
 struct pbsnode *next_node(all_nodes *,struct pbsnode *,node_iterator *);
 struct pbsnode *next_host(all_nodes *,int *,struct pbsnode *);
+int             copy_properties(struct pbsnode *dest, struct pbsnode *src);
 
 
 #define HELLO_RESEND_WAIT_TIME 10
@@ -495,6 +499,13 @@ enum nodeattr
 
 
 
+enum node_types
+  {
+  ND_TYPE_CRAY,
+  ND_TYPE_EXTERNAL,
+  ND_TYPE_LOGIN
+  };
+
 
 typedef struct node_check_info
   {
@@ -511,6 +522,7 @@ typedef struct node_check_info
 
 
 extern all_nodes allnodes; 
+extern struct pbsnode *alps_reporter;
 
 extern int    svr_totnodes;  /* number of nodes (hosts) */
 extern int    svr_tsnodes;  /* number of timeshared nodes */
@@ -523,6 +535,7 @@ extern int update_nodes_file(struct pbsnode *);
 extern void bad_node_warning(pbs_net_t, struct pbsnode *);
 
 struct pbsnode  *find_nodebyname(char *);
+struct pbsnode  *find_node_in_allnodes(all_nodes *an, char *nodename);
 int              create_partial_pbs_node(char *, unsigned long, int);
 struct pbssubn  *create_subnode(struct pbsnode *pnode);
 
