@@ -78,8 +78,12 @@
 */
 #include <pbs_config.h>   /* the master config generated by configure */
 
-char *
-discui_(char *cp, unsigned value, unsigned *ndigs)
+char *discui_(
+    
+  char     *cp,
+  unsigned  value,
+  unsigned *ndigs)
+
   {
   char  *ocp;
 
