@@ -112,7 +112,7 @@
 
 int diswsi(
 
-  int stream,
+  struct tcp_chan *chan,
   int value)
 
   {
@@ -124,13 +124,6 @@ int diswsi(
 
   int       rc;
   char		scratch[DIS_BUFSIZ+1];
-  int (*dis_puts)(int stream, const char *string, size_t count);
-  int (*disw_commit)(int stream, int commit);
-
-  assert(stream >= 0);
-  
-  dis_puts = tcp_puts;
-  disw_commit = tcp_wcommit;
 
   memset(scratch, 0, DIS_BUFSIZ+1);
 
@@ -154,12 +147,12 @@ int diswsi(
   while (ndigs > 1)
     cp = discui_(cp, ndigs, &ndigs);
 
-  retval = (*dis_puts)(
-             stream,
+  retval = tcp_puts(
+             chan,
              cp,
              strlen(cp)) < 0 ?  DIS_PROTO : DIS_SUCCESS;
 
-  rc = ((*disw_commit)(stream, retval == DIS_SUCCESS) < 0) ?
+  rc = (tcp_wcommit(chan, retval == DIS_SUCCESS) < 0) ?
        DIS_NOCOMMIT : retval;
 
   return(rc);
