@@ -170,8 +170,8 @@ int PBSD_commit_get_sid(
     return(PBSE_MEM_MALLOC);
     }
   else if ((rc = encode_DIS_ReqHdr(chan, PBS_BATCH_Commit, pbs_current_user)) ||
-      (rc = encode_DIS_JobId(chan, jobid)) ||
-      (rc = encode_DIS_ReqExtend(chan, NULL)))
+           (rc = encode_DIS_JobId(chan, jobid)) ||
+           (rc = encode_DIS_ReqExtend(chan, NULL)))
     {
     pthread_mutex_lock(connection[connect].ch_mutex);
     connection[connect].ch_errtxt = strdup(dis_emsg[rc]);
@@ -185,6 +185,7 @@ int PBSD_commit_get_sid(
     DIS_tcp_cleanup(chan);
     return(PBSE_PROTOCOL);
     }
+
   DIS_tcp_cleanup(chan);
 
   /* PBSD_rdrpy sets connection[connect].ch_errno */
@@ -193,23 +194,32 @@ int PBSD_commit_get_sid(
   pthread_mutex_lock(connection[connect].ch_mutex);
   rc = connection[connect].ch_errno;
   pthread_mutex_unlock(connection[connect].ch_mutex);
- 
-  /* read the sid if given and no error */
-  if (rc == PBSE_NONE)
-    {
-    if (reply->brp_choice == BATCH_REPLY_CHOICE_Text)
-      {
-      if (sid != NULL)
-        *sid = atol(reply->brp_un.brp_txt.brp_str);
-      }
-    else
-      /* (reply->brp_choice == BATCH_REPLY_CHOICE_NULL) */
-      {
-      *sid = reply->brp_code;
-      }
-    }
 
-  PBSD_FreeReply(reply);
+  if (reply == NULL)
+    {
+    /* couldn't read a response */
+    if (rc == PBSE_NONE)
+      rc = PBSE_PROTOCOL;
+    }
+  else
+    {
+    /* read the sid if given and no error */
+    if (rc == PBSE_NONE)
+      {
+      if (reply->brp_choice == BATCH_REPLY_CHOICE_Text)
+        {
+        if (sid != NULL)
+          *sid = atol(reply->brp_un.brp_txt.brp_str);
+        }
+      else
+        /* (reply->brp_choice == BATCH_REPLY_CHOICE_NULL) */
+        {
+        *sid = reply->brp_code;
+        }
+      }
+    
+    PBSD_FreeReply(reply);
+    }
 
   return(rc);
   } /* END PBSD_commit_get_sid() */
@@ -475,12 +485,11 @@ char *PBSD_queuejob(
   char           *extend)
 
   {
-
   struct batch_reply *reply;
-  char  *return_jobid = NULL;
-  int    rc;
-  int    sock;
-  struct tcp_chan *chan = NULL;
+  char               *return_jobid = NULL;
+  int                 rc;
+  int                 sock;
+  struct tcp_chan    *chan = NULL;
 
   pthread_mutex_lock(connection[connect].ch_mutex);
   sock = connection[connect].ch_socket;
@@ -566,30 +575,29 @@ int PBSD_QueueJob_hash(
 
   if ((chan = DIS_tcp_setup(sock)) == NULL)
     {
-    return PBSE_PROTOCOL;
+    return(PBSE_PROTOCOL);
     }
   /* first, set up the body of the Queue Job request */
-  else if ((rc = encode_DIS_ReqHdr(chan,PBS_BATCH_QueueJob,pbs_current_user)) ||
-      (rc = encode_DIS_QueueJob_hash(chan, jobid, destin, mm, job_attr, res_attr))||
-      (rc = encode_DIS_ReqExtend(chan, extend)))
+  else if ((rc = encode_DIS_ReqHdr(chan, PBS_BATCH_QueueJob, pbs_current_user)) ||
+           (rc = encode_DIS_QueueJob_hash(chan, jobid, destin, mm, job_attr, res_attr)) ||
+           (rc = encode_DIS_ReqExtend(chan, extend)))
     {
-
     pthread_mutex_lock(connection[connect].ch_mutex);
     if (connection[connect].ch_errtxt == NULL)
       {
       connection[connect].ch_errtxt = memmgr_strdup(mm, (char *)dis_emsg[rc], &tmp_size);
       }
     *msg = memmgr_strdup(mm, connection[connect].ch_errtxt, &tmp_size);
+
     pthread_mutex_unlock(connection[connect].ch_mutex);
-    /* rc = PBSE_PROTOCOL; */
+
     DIS_tcp_cleanup(chan);
-    return rc;
+
+    return(rc);
     }
 
   if ((rc = DIS_tcp_wflush(chan)))
     {
-    /* rc = PBSE_PROTOCOL; */
-    
     pthread_mutex_lock(connection[connect].ch_mutex);
     if (connection[connect].ch_errtxt == NULL)
       {
@@ -598,12 +606,13 @@ int PBSD_QueueJob_hash(
     pthread_mutex_unlock(connection[connect].ch_mutex);
 
     DIS_tcp_cleanup(chan);
-    return rc;
+
+    return(rc);
     }
+    
   DIS_tcp_cleanup(chan);
 
   /* read reply from stream into presentation element */
-
   reply = PBSD_rdrpy(&rc, connect);
 
   pthread_mutex_lock(connection[connect].ch_mutex);
@@ -631,6 +640,7 @@ int PBSD_QueueJob_hash(
     {
     *job_id = memmgr_strdup(mm, reply->brp_un.brp_jid, &tmp_size);
     }
+    
   pthread_mutex_unlock(connection[connect].ch_mutex);
 
   PBSD_FreeReply(reply);
