@@ -88,34 +88,69 @@
 #include "libpbs.h"
 #include "dis.h"
 
-int
-pbs_msgjob(int c, char *jobid, int fileopt, char *msg, char *extend)
+int pbs_msgjob_err(
+    
+  int   c,
+  char *jobid,
+  int   fileopt,
+  char *msg,
+  char *extend,
+  int  *local_errno)
+
   {
 
   struct batch_reply *reply;
-  int rc;
+  int                 rc;
 
   if ((jobid == (char *)0) || (*jobid == '\0') ||
       (msg == (char *)0) || (*msg == '\0'))
-    return (pbs_errno = PBSE_IVALREQ);
+    return(PBSE_IVALREQ);
 
   /* setup DIS support routines for following DIS calls */
 
 /*  DIS_tcp_setup(connection[c].ch_socket); */
 
+  pthread_mutex_lock(connection[c].ch_mutex);
+
   if ((rc = PBSD_msg_put(c, jobid, fileopt, msg, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
-    return (pbs_errno = PBSE_PROTOCOL);
+
+    pthread_mutex_unlock(connection[c].ch_mutex);
+
+    return(PBSE_PROTOCOL);
     }
 
   /* read reply */
 
-  reply = PBSD_rdrpy(c);
+  reply = PBSD_rdrpy(local_errno, c);
 
   rc = connection[c].ch_errno;
 
+  pthread_mutex_unlock(connection[c].ch_mutex);
+
   PBSD_FreeReply(reply);
 
-  return rc;
-  }
+  return(rc);
+  } /* END pbs_msgjob_err() */
+
+
+
+
+
+int pbs_msgjob(
+    
+  int   c,
+  char *jobid,
+  int   fileopt,
+  char *msg,
+  char *extend)
+
+  {
+  pbs_errno = 0;
+
+  return(pbs_msgjob_err(c, jobid, fileopt, msg, extend, &pbs_errno));
+  } /* END pbs_msgjob() */
+
+
+
