@@ -306,13 +306,11 @@ int DIS_tcp_wflush(
   struct tcp_chan *chan)  /* I */
 
   {
-  size_t ct;
-  int  i;
-  char *pb = NULL;
-  char *temp_pb = NULL;
-  char *orig_temp_pb = NULL;
-  char *pbs_debug = NULL;
-  int   rc = PBSE_NONE;
+  size_t  ct;
+  int     i;
+  char   *pb = NULL;
+  char   *pbs_debug = NULL;
+  int     rc = PBSE_NONE;
 
   struct tcpdisbuf *tp;
 
@@ -322,20 +320,10 @@ int DIS_tcp_wflush(
   pb = tp->tdis_thebuf;
   ct = tp->tdis_trailp - tp->tdis_thebuf;
 
-  if ((orig_temp_pb = calloc(1, ct + 1)) == NULL)
-    {
-    if (pbs_debug != NULL)
-      fprintf(stderr, "DIS_tcp_wflush failed to on calloc of temp_pb: %d, (%s)\n", errno, strerror(errno));
-    rc = -1;
-    }
-  else
-    memcpy(orig_temp_pb, pb, ct);
-  temp_pb = orig_temp_pb;
-
   if (rc != PBSE_NONE)
     return(-1);
  
-  while ((i = write(chan->sock, temp_pb, ct)) != (ssize_t)ct)
+  while ((i = write(chan->sock, pb, ct)) != (ssize_t)ct)
     {
     if (i == -1)
       {
@@ -350,22 +338,20 @@ int DIS_tcp_wflush(
         {
         fprintf(stderr,
             "TCP write of %d bytes (%.32s) [sock=%d] failed, errno=%d (%s)\n",
-          (int)ct, temp_pb, chan->sock, errno, strerror(errno));
+          (int)ct, pb, chan->sock, errno, strerror(errno));
         }
-      free(orig_temp_pb);
+      
       return(-1);
       }  /* END if (i == -1) */
     else
       {
       ct -= i;
-      temp_pb += i;
+      pb += i;
       }
     }  /* END while (i) */
 
   /* SUCCESS */
 
-  free(orig_temp_pb);
-
   tp->tdis_eod = tp->tdis_leadp;
 
   tcp_pack_buff(tp);
