@@ -147,6 +147,7 @@ char *msg_mombadmodify = "MOM rejected modify request, error: %d";
 char *msg_momsetlim = "Job start failed.  Can't set \"%s\" limit: %s.\n";
 char *msg_momnoexec1 = "Job cannot be executed\nSee Administrator for help";
 char *msg_momnoexec2 = "Job cannot be executed\nSee job standard error file";
+char *msg_momjoboverlimit = "Job exceeded some resource limit (walltime, mem, etc.). Job was aborted\nSee Administrator for help";
 char *msg_movejob = "Job moved to ";
 char *msg_norelytomom = "Server could not connect to MOM";
 char *msg_obitnojob  = "Job Obit notice received from %s has error %d";
@@ -167,7 +168,7 @@ char *msg_shutdown_op = "Shutdown request from %s@%s ";
 char *msg_shutdown_start = "Starting to shutdown the server, type is ";
 char *msg_startup1 = "Server %s started, initialization type = %d";
 char *msg_startup2 = "Server Ready, pid = %d, loglevel=%d";
-char *msg_startup3 = "%s %s: %s mode and %s exists, \ndo you wish to continue y/(n)?";
+char *msg_startup3 = "%s %s: %s mode and %s exist, \ndo you wish to continue y/(n)?";
 char *msg_svdbopen = "Unable to open server data base";
 char *msg_svdbnosv = "Unable to save server data base";
 char *msg_svrdown = "Server shutdown completed";
