@@ -91,7 +91,7 @@
 
 
 #define MINIMUM_STACK_SIZE 16777216
-extern int    LOGLEVEL;
+/*extern int    LOGLEVEL;*/
 sigset_t      fillset;
 
 threadpool_t *request_pool;
@@ -216,10 +216,10 @@ static void *work_thread(
   void             *arg;
   tp_work_t        *mywork;
   tp_working_t      working;
-  char             *tid = (char *)pthread_self();
+  /*char             *tid = (char *)pthread_self();*/
 
   struct timespec   ts;
-  char              log_buf[LOCAL_LOG_BUF_SIZE];
+  /*char              log_buf[LOCAL_LOG_BUF_SIZE];*/
 
   if (request_pool == NULL)
     {
@@ -297,20 +297,21 @@ static void *work_thread(
       pthread_cleanup_push(work_cleanup,NULL);
       free(mywork);
 
-      if (LOGLEVEL >= 7)
+/*      if (LOGLEVEL >= 7)
         {
         sprintf(log_buf,"starting work from thread %s", tid);
         log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_SERVER,id,log_buf);
-        }
+        }*/
 
       /* do the work */
       func(arg);
 
+      /*
       if (LOGLEVEL >= 7)
         {
         sprintf(log_buf,"finished work from thread %s", tid);
         log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_SERVER,id,log_buf);
-        }
+        }*/
 
       /* cleanup the work */
       pthread_cleanup_pop(1); /* calls work_cleanup(NULL) */
