@@ -163,9 +163,9 @@ static int   njob = 1;
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern unsigned int reqnum;
 extern char *ret_string;
@@ -180,15 +180,15 @@ extern  int      ignmem;
 /*
 ** local functions
 */
-static char *resi  A_((struct rm_attribute *attrib));
-static char *totmem  A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *availmem A_((struct rm_attribute *attrib));
-static char *walltime A_((struct rm_attribute *attrib));
-static char *ncpus  A_((struct rm_attribute *attrib));
+static char *resi     (struct rm_attribute *attrib);
+static char *totmem   (struct rm_attribute *attrib);
+static char *physmem  (struct rm_attribute *attrib);
+static char *availmem (struct rm_attribute *attrib);
+static char *walltime (struct rm_attribute *attrib);
+static char *ncpus    (struct rm_attribute *attrib);
 
-extern char *loadave A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
+extern char *loadave  (struct rm_attribute *attrib);
+extern char *nullproc (struct rm_attribute *attrib);
 
 /*
 ** local resource list storage
@@ -397,11 +397,11 @@ void dep_initialize(void)
     log_err(errno, id, "F_SETFD");
     }
 
-  if ((proc_tbl = malloc(ASIZE * sizeof(struct procsinfo))) == NULL)
+  if ((proc_tbl = calloc(1, ASIZE * sizeof(struct procsinfo))) == NULL)
     {
     /* FAILURE - cannot alloc memory */
 
-    log_err(errno,"dep_initialize","malloc failure");
+    log_err(errno,"dep_initialize","calloc failure");
 
     return;
     }
@@ -551,7 +551,7 @@ void dep_main_loop_cycle(void)
  */
 
 static int
-getsize(resource *pres, unsigned long *ret)
+mm_getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -587,7 +587,7 @@ getsize(resource *pres, unsigned long *ret)
  */
 
 static int
-gettime(resource *pres, unsigned long *ret)
+mm_gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -821,11 +821,9 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int
-mom_set_limits(
+int mom_set_limits(
   job *pjob,
-  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
-)
+  int set_mode) /* SET_LIMIT_SET or SET_LIMIT_ALTER */
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -861,7 +859,7 @@ mom_set_limits(
       if (igncput == FALSE)
         {
         /* cpu time - check, if less than pcput use it */
-        retval = gettime(pres, &value);
+        retval = mm_gettime(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -872,7 +870,7 @@ mom_set_limits(
       if (igncput == FALSE)
         {
         /* process cpu time - set */
-        retval = gettime(pres, &value);
+        retval = mm_gettime(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -888,7 +886,7 @@ mom_set_limits(
       {
       if (set_mode == SET_LIMIT_SET)
         {
-        retval = getsize(pres, &value);
+        retval = mm_getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -906,7 +904,7 @@ mom_set_limits(
       {
       if (ignvmem == FALSE)
         {
-        retval = getsize(pres, &value);
+        retval = mm_getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -921,7 +919,7 @@ mom_set_limits(
         {
         if (set_mode == SET_LIMIT_SET)
           {
-          retval = getsize(pres, &value);
+          retval = mm_getsize(pres, &value);
 
           if (retval != PBSE_NONE)
             return (error(pname, retval));
@@ -940,7 +938,7 @@ mom_set_limits(
         {
         if (set_mode == SET_LIMIT_SET)
           {
-          retval = getsize(pres, &value);
+          retval = mm_getsize(pres, &value);
 
           if (retval != PBSE_NONE)
             return (error(pname, retval));
@@ -954,7 +952,7 @@ mom_set_limits(
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
       {
-      retval = gettime(pres, &value);
+      retval = mm_gettime(pres, &value);
 
       if (retval != PBSE_NONE)
         return (error(pname, retval));
@@ -1046,7 +1044,7 @@ mom_open_poll(void)
 
   DBPRT(("%s: entered\n", id))
 
-  proc_tbl = malloc(ASIZE * sizeof(struct procsinfo));
+  proc_tbl = calloc(ASIZE, sizeof(struct procsinfo));
   proctot = ASIZE;
 
   return (PBSE_NONE);
@@ -1444,7 +1442,7 @@ mom_over_limit(job *pjob)
 
     if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
-      retval = gettime(pres, &value);
+      retval = mm_gettime(pres, &value);
 
       if (retval != PBSE_NONE)
         continue;
@@ -1459,7 +1457,7 @@ mom_over_limit(job *pjob)
       }
     else if (strcmp(pname, "vmem") == 0)
       {
-      retval = getsize(pres, &value);
+      retval = mm_getsize(pres, &value);
 
       if (retval != PBSE_NONE)
         continue;
@@ -1474,7 +1472,7 @@ mom_over_limit(job *pjob)
       }
     else if (strcmp(pname, "pvmem") == 0)
       {
-      retval = getsize(pres, &value);
+      retval = mm_getsize(pres, &value);
 
       if (retval != PBSE_NONE)
         continue;
@@ -1491,7 +1489,7 @@ mom_over_limit(job *pjob)
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
 
-      retval = gettime(pres, &value);
+      retval = mm_gettime(pres, &value);
 
       if (retval != PBSE_NONE)
         continue;
@@ -1520,8 +1518,8 @@ mom_over_limit(job *pjob)
  *
  * Assumes that the session ID attribute has already been set.
  */
-int
-mom_set_use(job *pjob)
+int mom_set_use(
+    job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
