@@ -88,6 +88,7 @@
 #include "dynamic_string.h"
 #include "utils.h"
 #include "alps_constants.h"
+#include "alps_functions.h"
 
 
 
@@ -384,7 +385,7 @@ int process_node(
 
   if (rsv_id != NULL)
     {
-    copy_to_end_of_dynamic_string(status, "reservation=");
+    copy_to_end_of_dynamic_string(status, "reservation_id=");
     append_dynamic_string(status, rsv_id);
 
     free(rsv_id);
@@ -463,6 +464,9 @@ int process_element(
     if (strcmp(str, success))
       {
       free(str);
+
+      find_error_type(node);
+
       return(ALPS_QUERY_FAILURE);
       }
     else
@@ -591,6 +595,11 @@ int generate_alps_status(
 
   free_dynamic_string(alps_output);
 
+  if (rc != PBSE_NONE)
+    {
+    log_err(-1, __func__, "Couldn't correctly get the alps inventory! System is down");
+    }
+
   return(rc);
   } /* END generate_alps_status() */
 
