@@ -103,7 +103,7 @@
 #include "log.h"
 #include "../lib/Liblog/pbs_log.h"
 #include "svrfunc.h"
-#include "mom_job_func.h" /* job_purge */
+#include "mom_job_func.h" /* mom_job_purge */
 
 #include "mom_func.h"
 #include "utils.h"
@@ -114,7 +114,6 @@
 
 extern int  reply_jid(char *);
 extern int  svr_authorize_jobreq(struct batch_request *, job *);
-extern int  svr_chkque(job *, pbs_queue *, char *, int, char *);
 int         reply_send_mom(struct batch_request *request);
 extern void check_state(int);
 extern void mom_server_all_update_stat();
@@ -179,8 +178,6 @@ static int user_account_read_user(char *);
 
 /*
  * req_quejob - Queue Job Batch Request processing routine
- *  NOTE:  calls svr_chkque() to validate queue access
- *
  */
 
 void req_quejob(
@@ -241,7 +238,7 @@ void req_quejob(
 
   /* does job already exist, check both old and new jobs */
 
-  if ((pj = find_job(jid)) == NULL)
+  if ((pj = mom_find_job(jid)) == NULL)
     {
     pj = (job *)GET_NEXT(svr_newjobs);
 
@@ -357,7 +354,7 @@ void req_quejob(
 
       /* didn`t recognize the name */
 
-      job_purge(pj);   /* CRI - 12/20/2004 */
+      mom_job_purge(pj);   /* CRI - 12/20/2004 */
 
       reply_badattr(PBSE_NOATTR, 1, psatl, preq);
 
@@ -372,7 +369,7 @@ void req_quejob(
       {
       /* FAILURE */
 
-      job_purge(pj);
+      mom_job_purge(pj);
 
       reply_badattr(PBSE_ATTRRO, 1, psatl, preq);
 
@@ -405,7 +402,7 @@ void req_quejob(
 
       /* all errors are fatal for MOM */
 
-      job_purge(pj);
+      mom_job_purge(pj);
 
       reply_badattr(rc, 1, psatl, preq);
 
@@ -423,7 +420,7 @@ void req_quejob(
 
         if (prdef == NULL)
           {
-          job_purge(pj);
+          mom_job_purge(pj);
 
           reply_badattr(rc, 1, psatl, preq);
 
@@ -497,7 +494,7 @@ void req_quejob(
 
     close_conn(sock, FALSE);
 
-    job_purge(pj);
+    mom_job_purge(pj);
 
     return;
     }
@@ -715,7 +712,7 @@ void req_mvjobfile(
   pj = locate_new_job(preq->rq_conn, NULL);
 
   if (pj == NULL)
-    pj = find_job(preq->rq_ind.rq_jobfile.rq_jobid);
+    pj = mom_find_job(preq->rq_ind.rq_jobfile.rq_jobid);
 
   if (pj == NULL)
     {
@@ -899,7 +896,7 @@ void req_rdytocommit(
 
     close_conn(sock, FALSE);
 
-    job_purge(pj);
+    mom_job_purge(pj);
 
     return;
     }
