@@ -273,7 +273,7 @@ static pid_t fork_to_user(
   if (EMsg != NULL)
     EMsg[0] = '\0';
 
-  if ((pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) &&
+  if ((pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) &&
       (pjob->ji_grpcache != 0) &&
       (preq->rq_ind.rq_cpyfile.rq_dir != CKPT_DIR_IN) &&
       (preq->rq_ind.rq_cpyfile.rq_dir != CKPT_DIR_OUT))
@@ -353,7 +353,7 @@ static pid_t fork_to_user(
       {
       hdir = pwdp->pw_dir;
       }
-    }    /* END if ((pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) && ...) */
+    }    /* END if ((pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) && ...) */
 
   if (hdir == NULL)
     {
@@ -456,7 +456,7 @@ static pid_t fork_to_user(
 
 #ifdef _CRAY
 
-  if ((pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) &&
+  if ((pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) &&
       (pjob->ji_grpcache != 0))
     {
     /* set account id */
@@ -1122,7 +1122,7 @@ void req_deletejob(
   job        *pjob;
   pjobexec_t *TJE = NULL;
 
-  pjob = find_job(preq->rq_ind.rq_delete.rq_objname);
+  pjob = mom_find_job(preq->rq_ind.rq_delete.rq_objname);
 
   if (pjob != NULL)
     {
@@ -1182,7 +1182,7 @@ void mom_req_holdjob(
   /* If checkpoint supported, do it and terminate the job */
   /* otherwise, return PBSE_NOSUP    */
 
-  if ((pjob = find_job(preq->rq_ind.rq_hold.rq_orig.rq_objname)) == NULL)
+  if ((pjob = mom_find_job(preq->rq_ind.rq_hold.rq_orig.rq_objname)) == NULL)
     {
     rc = PBSE_UNKJOBID;
     }
@@ -1228,7 +1228,7 @@ void req_checkpointjob(
   /* If checkpoint supported, do it and terminate the job */
   /* otherwise, return PBSE_NOSUP    */
 
-  pjob = find_job(preq->rq_ind.rq_manager.rq_objname);
+  pjob = mom_find_job(preq->rq_ind.rq_manager.rq_objname);
 
   if (pjob == NULL)
     {
@@ -1469,7 +1469,7 @@ void req_messagejob(
   int   ret = 0;
   job  *pjob;
 
-  pjob = find_job(preq->rq_ind.rq_message.rq_jid);
+  pjob = mom_find_job(preq->rq_ind.rq_message.rq_jid);
 
   if ((preq->rq_ind.rq_message.rq_file == PBS_BATCH_FileOpt_Default) ||
       (preq->rq_ind.rq_message.rq_file & PBS_BATCH_FileOpt_OFlg))
@@ -1600,7 +1600,7 @@ void req_modifyjob(
 
   char           tmpLine[1024];
 
-  pjob = find_job(preq->rq_ind.rq_modify.rq_objname);
+  pjob = mom_find_job(preq->rq_ind.rq_modify.rq_objname);
 
   if (pjob == NULL)
     {
@@ -2214,7 +2214,7 @@ void req_signaljob(
 
   extern struct   sig_tbl sig_tbl[];
 
-  pjob = find_job(preq->rq_ind.rq_signal.rq_jid);
+  pjob = mom_find_job(preq->rq_ind.rq_signal.rq_jid);
 
   if (pjob == NULL)
     {
@@ -2538,7 +2538,7 @@ int req_stat_job(
     {
     all = 0;
 
-    pjob = find_job(name);
+    pjob = mom_find_job(name);
 
     if (pjob == NULL)
       {
@@ -2747,7 +2747,8 @@ static int del_files(
         }
 
 #ifdef HAVE_WORDEXP
-      if (setuserenv && (pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) != NULL)
+      if (setuserenv && 
+          (pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) != NULL)
         {
         InitUserEnv(pjob, NULL, NULL, NULL, NULL);
 
@@ -2931,7 +2932,7 @@ void req_rerunjob(
   int            rc;
   int            retrycnt = 0;
 
-  pjob = find_job(preq->rq_ind.rq_rerun);
+  pjob = mom_find_job(preq->rq_ind.rq_rerun);
 
   if (pjob == NULL)
     {
@@ -3023,7 +3024,7 @@ void req_returnfiles(
   int          sock;
   int          retry_attempts = 0;
 
-  pjob = find_job(preq->rq_ind.rq_returnfiles.rq_jobid);
+  pjob = mom_find_job(preq->rq_ind.rq_returnfiles.rq_jobid);
 
   if (pjob != NULL)
     {
@@ -3400,7 +3401,7 @@ void req_cpyfile(
 
     char *wdir;
 
-    if ((pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) == NULL)
+    if ((pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) == NULL)
       {
       wdir = NULL;
       }
@@ -3443,7 +3444,7 @@ void req_cpyfile(
 #ifdef HAVE_WORDEXP
   faketmpdir[0] = '\0';
 
-  if ((pjob = find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) == NULL)
+  if ((pjob = mom_find_job(preq->rq_ind.rq_cpyfile.rq_jobid)) == NULL)
     {
     /* This is a stagein which happens before the job struct to sent to MOM
      * or a checkpoint file coming in.
