@@ -97,14 +97,16 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 4430 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 4431 $";
 
 /* Global Variables */
 
-extern int  exiting_tasks;
-extern char  mom_host[];
-extern tlist_head svr_alljobs;
-extern int  termin_child;
+extern int          exiting_tasks;
+extern char         mom_host[];
+extern tlist_head   svr_alljobs;
+extern int          termin_child;
+extern int          multi_mom;
+extern unsigned int pbs_rm_port;
 
 /* Private variables */
 
@@ -207,6 +209,7 @@ scan_for_terminated(void)
   job  *pjob;
   task  *ptask;
   int  statloc;
+  unsigned int momport = 0;
 
   /* update the latest intelligence about the running jobs;         */
   /* must be done before we reap the zombies, else we lose the info */
@@ -283,7 +286,12 @@ scan_for_terminated(void)
 
       pjob->ji_momsubt = 0;
 
-      (void)job_save(pjob, SAVEJOB_QUICK);
+      if(multi_mom)
+        {
+        momport = pbs_rm_port;
+        }
+
+      (void)job_save(pjob, SAVEJOB_QUICK, momport);
       continue;
       }
 
