@@ -115,6 +115,9 @@
 #include "pbs_error.h"
 #include "pbs_ifl.h"
 #include "log.h"
+#include "../lib/Liblog/pbs_log.h"
+#include "../lib/Liblog/setup_env.h"
+#include "../lib/Liblog/chk_file_sec.h"
 #include "resmon.h"
 #include "sched_cmds.h"
 #include "server_limits.h"
@@ -123,7 +126,6 @@
 #include "rm.h"
 #include "libpbs.h"
 
-extern int pbs_errno;
 int  connector;
 int  server_sock;
 
@@ -176,7 +178,9 @@ void die(
                id, "abnormal termination");
     }
 
+  pthread_mutex_lock(log_mutex);
   log_close(1);
+  pthread_mutex_unlock(log_mutex);
 
   exit(1);
   }  /* END die() */
@@ -244,7 +248,7 @@ static int server_disconnect(
 
   connection[connect].ch_errno = 0;
 
-  connection[connect].ch_inuse = 0;
+  connection[connect].ch_inuse = FALSE;
 
   return(0);
   }  /* END server_disconnect() */
@@ -336,22 +340,25 @@ int
 socket_to_conn(int sock)
   {
   int     i;
+  pthread_mutexattr_t t_attr;
+  pthread_mutexattr_init(&t_attr);
+  pthread_mutexattr_settype(&t_attr, PTHREAD_MUTEX_ERRORCHECK);
 
   for (i = 0; i < NCONNECTS; i++)
     {
-    if (connection[i].ch_inuse == 0)
+    if (connection[i].ch_inuse == FALSE)
       {
-
-      connection[i].ch_inuse = 1;
+      connection[i].ch_mutex = (pthread_mutex_t *)malloc(sizeof(pthread_mutex_t));
+      pthread_mutex_init(connection[i].ch_mutex, &t_attr);
+      connection[i].ch_inuse = TRUE;
       connection[i].ch_errno = 0;
       connection[i].ch_socket = sock;
       connection[i].ch_errtxt = NULL;
+
       return (i);
       }
     }
 
-  pbs_errno = PBSE_NOCONNECTS;
-
   return (-1);
   }
 
@@ -570,8 +577,10 @@ restart(int sig)
 
   if (sig)
     {
+    pthread_mutex_lock(log_mutex);
     log_close(1);
     log_open(logfile, path_log);
+    pthread_mutex_unlock(log_mutex);
     sprintf(log_buffer, "restart on signal %d", sig);
     }
   else
@@ -780,6 +789,7 @@ int main(
 
   glob_argv = argv;
   alarm_time = 180;
+  log_init(NULL, NULL);
 
   /* The following is code to reduce security risks                */
   /* move this to a place where nss_ldap doesn't hold a socket yet */
@@ -812,8 +822,7 @@ int main(
           {
           errflg = 1;
           }
-
-        if (!strcmp(optarg, "version"))
+        else if (!strcmp(optarg, "version"))
           {
           fprintf(stderr, "version: %s\n", PACKAGE_VERSION);
           exit(0);
@@ -971,11 +980,14 @@ int main(
 #endif /* not _CRAY */
 #endif /* DEBUG */
 
+  pthread_mutex_lock(log_mutex);
   if (log_open(logfile, path_log) == -1)
     {
+    pthread_mutex_unlock(log_mutex);
     fprintf(stderr, "%s: logfile could not be opened\n", argv[0]);
     exit(1);
     }
+  pthread_mutex_unlock(log_mutex);
 
   if (gethostname(host, sizeof(host)) == -1)
     {
