@@ -76,7 +76,7 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
-/* $Id: getqueues.c 2367 2008-09-03 17:17:34Z josh $ */
+/* $Id: getqueues.c 5178 2011-10-11 21:46:02Z dbeer $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -149,6 +149,7 @@ schd_get_queue_limits(Queue *queue)
   {
   char   *id = "schd_get_queue_limits";
   int     istrue;
+  int     local_errno = 0;
   Batch_Status *bs;
   AttrList *attr;
   static AttrList alist[] =
@@ -239,10 +240,10 @@ schd_get_queue_limits(Queue *queue)
 
   /* Ask the server for information about the specified queue. */
 
-  if ((bs = pbs_statque(connector, queue->qname, alist, NULL)) == NULL)
+  if ((bs = pbs_statque_err(connector, queue->qname, alist, NULL, &local_errno)) == NULL)
     {
     sprintf(log_buffer, "pbs_statque failed, \"%s\" %d",
-            queue->qname, pbs_errno);
+            queue->qname, local_errno);
     log_record(PBSEVENT_ERROR, PBS_EVENTCLASS_SERVER, id, log_buffer);
     DBPRT(("%s: %s\n", id, log_buffer));
     return (-1);
@@ -884,6 +885,7 @@ get_node_status(void)
   {
   char *id = "get_node_status";
   QueueList *qptr;
+  int        local_errno = 0;
   Batch_Status *bs, *bsp;
   AttrList *attr;
   static AttrList alist[] = {{NULL, ATTR_NODE_state, "", ""}};
@@ -892,9 +894,9 @@ get_node_status(void)
    * info in the appropraite queue struct.
    */
 
-  if ((bs = pbs_statnode(connector, NULL, alist, NULL)) == NULL)
+  if ((bs = pbs_statnode_err(connector, NULL, alist, NULL, &local_errno)) == NULL)
     {
-    sprintf(log_buffer, "pbs_statnode failed: %d", pbs_errno);
+    sprintf(log_buffer, "pbs_statnode failed: %d", local_errno);
     log_record(PBSEVENT_ERROR, PBS_EVENTCLASS_SERVER, id, log_buffer);
     DBPRT(("%s: %s\n", id, log_buffer));
     return (-1);
