@@ -132,13 +132,14 @@ job_info **query_jobs(int pbs_sd, queue_info *qinfo)
   /* number of jobs in jinfo_arr */
   int num_jobs = 0;
   int i;
+  int local_errno = 0;
 
   opl.value = qinfo -> name;
 
-  if ((jobs = pbs_selstat(pbs_sd, &opl, NULL)) == NULL)
+  if ((jobs = pbs_selstat_err(pbs_sd, &opl, NULL, &local_errno)) == NULL)
     {
-    if (pbs_errno > 0)
-      fprintf(stderr, "pbs_selstat failed: %d\n", pbs_errno);
+    if (local_errno > 0)
+      fprintf(stderr, "pbs_selstat failed: %d\n", local_errno);
 
     return NULL;
     }
@@ -686,6 +687,7 @@ int update_job_comment(int pbs_sd, job_info *jinfo, char *comment)
     NULL, ATTR_comment, NULL, NULL, 0
     };
 
+  int         local_errno = 0;
   static char clone[UDC_CLONEBUFSIZ];
   
   if (jinfo == NULL)
@@ -708,7 +710,7 @@ int update_job_comment(int pbs_sd, job_info *jinfo, char *comment)
 
     attr.value = clone;
 
-    pbs_alterjob(pbs_sd, jinfo -> name, &attr, NULL);
+    pbs_alterjob_err(pbs_sd, jinfo -> name, &attr, NULL, &local_errno);
 
     return 0;
     }
@@ -784,6 +786,7 @@ job_info **job_filter(job_info** jobs, int size,
                       int (*filter_func)(job_info*, void*), void *arg)
   {
   job_info **new_jobs = NULL;   /* new array of jobs */
+  job_info **tmp = NULL;
   int i, j = 0;
 
   if ((new_jobs = malloc((size + 1) * sizeof(job_info *))) == NULL)
@@ -801,11 +804,13 @@ job_info **job_filter(job_info** jobs, int size,
       }
     }
 
-  if ((new_jobs = realloc(new_jobs, (j + 1) * sizeof(job_info *))) == NULL)
+  if ((tmp = realloc(new_jobs, (j + 1) * sizeof(job_info *))) == NULL)
     {
+    free(new_jobs);
     perror("Memory Allocation Error");
     return NULL;
     }
+  new_jobs = tmp;
 
   new_jobs[j] = NULL;
 
