@@ -88,7 +88,6 @@
 #include "node_info.h"
 #include "misc.h"
 #include "globals.h"
-#include "dis.h" /* DIS_tcp_setup */
 
 
 
@@ -433,7 +432,6 @@ int talk_with_mom(
       return 1;
       }
 
-    DIS_tcp_setup(mom_sd);
     for (i = 0; i < num_resget; i++)
       addreq_err(mom_sd, &local_errno, (char *) res_to_get[i]);
 
