@@ -76,7 +76,7 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
-/* $Id: schedule.c 2367 2008-09-03 17:17:34Z josh $ */
+/* $Id: schedule.c 5178 2011-10-11 21:46:02Z dbeer $ */
 
 /*
  * This is the main loop for the scheduler.  The scheduler receives a
@@ -481,6 +481,7 @@ schedule_restart(Job *joblist)
   Job    *job, *nextjob;
   QueueList *qptr;
   int     found, changed;
+  int     local_errno = 0;
 
   changed = found = 0;
 
@@ -531,11 +532,11 @@ schedule_restart(Job *joblist)
     else /* (SCHED_RESTART_ACTION == SCHD_RESTART_RESUBMIT) */
       {
       /* Move the job back to its originating queue. */
-      if (pbs_movejob(connector, job->jobid, job->oqueue, NULL) != 0)
+      if (pbs_movejob_err(connector, job->jobid, job->oqueue, NULL, &local_errno) != 0)
         {
         (void)sprintf(log_buffer,
                       "failed to move %s to queue %s, %d", job->jobid,
-                      job->oqueue, pbs_errno);
+                      job->oqueue, local_errno);
         log_record(PBSEVENT_SYSTEM, PBS_EVENTCLASS_SERVER, id,
                    log_buffer);
         DBPRT(("%s: %s\n", id, log_buffer));
@@ -762,13 +763,14 @@ int schd_get_max_ncpus(void)
   AttrList *attr;
   static AttrList alist[] = {{NULL, ATTR_rescmax, "", ""}};
   int ret = 0;
+  int local_errno = 0;
 
 
   /* Query the server for status of the max ncpus attribute */
 
-  if ((bs = pbs_statserver(connector, alist, NULL)) == NULL)
+  if ((bs = pbs_statserver_err(connector, alist, NULL, &local_errno)) == NULL)
     {
-    sprintf(log_buffer, "pbs_statserver failed: %d", pbs_errno);
+    sprintf(log_buffer, "pbs_statserver failed: %d", local_errno);
     log_record(PBSEVENT_ERROR, PBS_EVENTCLASS_SERVER, id, log_buffer);
     DBPRT(("%s: %s\n", id, log_buffer));
     return (ret);
