@@ -76,7 +76,7 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
-/* $Id: qschedule.c 2367 2008-09-03 17:17:34Z josh $ */
+/* $Id: qschedule.c 5178 2011-10-11 21:46:02Z dbeer $ */
 
 /* Print the published start time of all queued jobs */
 
@@ -429,6 +429,7 @@ void
 list_start_times(void)
   {
   int ret;
+  int local_errno = 0;
   Job    *joblist = NULL, *jobtail = NULL, *new, *this;
   Batch_Status *pbs_head, *pbs_ptr;
 
@@ -436,11 +437,11 @@ list_start_times(void)
   connector = pbs_connect(NULL);
 
   /* Ask PBS for the list of jobs requested */
-  pbs_head = pbs_selstat(connector, NULL, NULL);
+  pbs_head = pbs_selstat_err(connector, NULL, NULL, &local_errno);
 
-  if ((pbs_head == NULL) && (pbs_errno))
+  if ((pbs_head == NULL) && (local_errno))
     {
-    fprintf(stderr, "ERROR: pbs_selstat failed, %d\n", pbs_errno);
+    fprintf(stderr, "ERROR: pbs_selstat failed, %d\n", local_errno);
     exit(-1);
     }
 
@@ -455,8 +456,7 @@ list_start_times(void)
 
     if (new == NULL)
       {
-      fprintf(stderr, "ERROR: malloc of new job struct failed: %d\n",
-              pbs_errno);
+      fprintf(stderr, "ERROR: malloc of new job struct failed\n");
       joblist = NULL;
       break;
       }
@@ -864,8 +864,8 @@ schd_val2byte(char *val)
 
   if (val[0] == '?')
     {
-    fprintf(stderr, "error from getreq(physmem): %s: [%d, %d]",
-            val, pbs_errno, errno);
+    fprintf(stderr, "error from getreq(physmem): %s: [%d]",
+            val, errno);
     return (0);
     }
 
