@@ -76,7 +76,7 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
-/* $Id: schedule.c 2367 2008-09-03 17:17:34Z josh $ */
+/* $Id: schedule.c 5178 2011-10-11 21:46:02Z dbeer $ */
 
 /*
  * This is the main loop for the scheduler.  The scheduler receives a
@@ -453,6 +453,7 @@ schedule_restart(Job *joblist)
   Job    *job, *nextjob;
   QueueList *qptr;
   int     found, changed;
+  int     local_errno = 0;
 
   changed = found = 0;
 
@@ -503,11 +504,11 @@ schedule_restart(Job *joblist)
     else /* (SCHED_RESTART_ACTION == SCHD_RESTART_RESUBMIT) */
       {
       /* Move the job back to its originating queue. */
-      if (pbs_movejob(connector, job->jobid, job->oqueue, NULL) != 0)
+      if (pbs_movejob_err(connector, job->jobid, job->oqueue, NULL, &local_errno) != 0)
         {
         (void)sprintf(log_buffer,
                       "failed to move %s to queue %s, %d", job->jobid,
-                      job->oqueue, pbs_errno);
+                      job->oqueue, local_errno);
         log_record(PBSEVENT_SYSTEM, PBS_EVENTCLASS_SERVER, id,
                    log_buffer);
         DBPRT(("%s: %s\n", id, log_buffer));
