@@ -126,7 +126,6 @@
 #include "rm.h"
 
 
-extern int pbs_errno;
 extern int connector;
 int  server_sock;
 
@@ -210,7 +209,7 @@ server_disconnect(int connect)
 
   connection[connect].ch_errno = 0;
 
-  connection[connect].ch_inuse = 0;
+  connection[connect].ch_inuse = FALSE;
 
   return 0;
   }
@@ -297,10 +296,10 @@ socket_to_conn(
 
   for (i = 0; i < NCONNECTS; i++)
     {
-    if (connection[i].ch_inuse == 0)
+    if (connection[i].ch_inuse == FALSE)
       {
 
-      connection[i].ch_inuse = 1;
+      connection[i].ch_inuse = TRUE;
       connection[i].ch_errno = 0;
       connection[i].ch_socket = sock;
       connection[i].ch_errtxt = NULL;
@@ -308,8 +307,6 @@ socket_to_conn(
       }
     }
 
-  pbs_errno = PBSE_NOCONNECTS;
-
   return (-1);
   }
 
@@ -759,13 +756,10 @@ char *argv[];
   fd_set  fdset;
 
 #ifndef DEBUG
-
-  if ((geteuid() != 0) || (getuid() != 0))
+  if (IamRoot() == 0)
     {
-    fprintf(stderr, "%s: Must be run by root\n", argv[0]);
-    return (1);
+        return (1);
     }
-
 #endif /* DEBUG */
 
   glob_argv = argv;
