@@ -1,6 +1,5 @@
 #include <pbs_config.h>
 
-#include <sys/types.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -8,6 +7,7 @@
 
 
 #include "array.h"
+#include "../lib/Liblog/pbs_log.h"
 
 
 extern char *path_arrays;
@@ -34,14 +34,21 @@ struct array_info_v1
   
 
 
-int array_upgrade(job_array *pa, int fds, int version, int *old_version)
+int array_upgrade(
+    
+  job_array *pa,
+  int        fds,
+  int        version,
+  int       *old_version)
+
   {
+  char log_buf[LOCAL_LOG_BUF_SIZE];
 
   /* reset the file descriptor */
   if (lseek(fds, 0, SEEK_SET) != 0)
     {
-    sprintf(log_buffer, "unable to reset fds\n");
-    log_err(-1, "array_upgrade", log_buffer);
+    sprintf(log_buf, "unable to reset fds\n");
+    log_err(-1, "array_upgrade", log_buf);
 
     return -1;
     }
@@ -64,14 +71,21 @@ int array_upgrade(job_array *pa, int fds, int version, int *old_version)
        about the incompatibility and inability to upgrade, print a quick and 
        dirty error message and exit */
        
-    sprintf(log_buffer, "WARNING, unable to upgrade job array\n"
+    sprintf(log_buf, "WARNING, unable to upgrade job array\n"
             "structs from versions prior to 2.5.0.\n"
             "Please downgrade TORQUE and upgrade once no job arrays are queued\n");
-    log_err(-1, "array_upgrade", log_buffer);
+    log_err(-1, "array_upgrade", log_buf);
     exit(1);
     }
   else
     {
+    if(version == 3)
+      {
+      /* Between version 3 and version 4 the element ai_qs.num_purged
+         was added. We need to account for the new element from version
+         3 arrays. */
+      return 0;
+      }
     return 1;
     }
   }
@@ -111,7 +125,7 @@ int array_upgrade_v1(job_array *pa, int fds, int version, int *old_version)
 
   if (old_array_info.num_cloned < old_array_info.array_size)
     {
-    rn = (array_request_node*)malloc(sizeof(array_request_node));
+    rn = (array_request_node*)calloc(1, sizeof(array_request_node));
     rn->start = old_array_info.num_cloned - 1;
     rn->end = old_array_info.array_size - 1;
 
