@@ -118,8 +118,8 @@ extern int LOGLEVEL;
 
 static char *geteusernam(
 
-  job       *pjob,
-  attribute *pattr) /* pointer to User_List attribute */
+  job           *pjob,
+  pbs_attribute *pattr) /* pointer to User_List pbs_attribute */
 
   {
   int  rule3 = 0;
@@ -132,7 +132,7 @@ static char *geteusernam(
   char  username[PBS_MAXUSER + 1];
   char *ret_user;
 
-  /* search the user-list attribute */
+  /* search the user-list pbs_attribute */
 
   if ((pattr->at_flags & ATR_VFLAG_SET) &&
       (parst = pattr->at_val.at_arst))
@@ -205,8 +205,8 @@ static char *geteusernam(
 
 static char *getegroup(
 
-  job       *pjob,  /* I */
-  attribute *pattr) /* I group_list attribute */
+  job           *pjob,  /* I */
+  pbs_attribute *pattr) /* I group_list pbs_attribute */
 
   {
   char *hit = 0;
@@ -218,7 +218,7 @@ static char *getegroup(
   char  groupname[PBS_MAXUSER + 1];
   char *ret_group;
 
-  /* search the group-list attribute */
+  /* search the group-list pbs_attribute */
 
   if ((pattr->at_flags & ATR_VFLAG_SET) &&
       (parst = pattr->at_val.at_arst))
@@ -287,19 +287,18 @@ static char *getegroup(
 
 int set_jobexid(
 
-  job       *pjob,    /* I */
-  attribute *attrry,  /* I */
-  char      *EMsg)    /* O (optional,minsize=1024) */
+  job           *pjob,    /* I */
+  pbs_attribute *attrry,  /* I */
+  char          *EMsg)    /* O (optional,minsize=1024) */
 
   {
   int             addflags = 0;
-  attribute      *pattr;
+  pbs_attribute  *pattr;
   char          **pmem;
 
   struct group   *gpent;
   int             free_puser = FALSE;
   char           *puser = NULL;
-  char           *id = "set_jobexid";
   char           *at;
   char           *usr_at_host = NULL;
   int             len;
@@ -381,9 +380,7 @@ int set_jobexid(
 
       free_puser = TRUE;
 
-      sprintf(tmpLine, "%s",
-
-              puser);
+      sprintf(tmpLine, "%s", puser);
 
       /* end of change to use userlist instead of owner 10/17/2007 */
       }
@@ -421,7 +418,7 @@ int set_jobexid(
         "User %s does not exist in server password file\n",
         puser);
 
-      log_err(errno, id, log_buf);
+      log_err(errno, __func__, log_buf);
 
       if (EMsg != NULL)
         snprintf(EMsg,1024,"%s",log_buf);
@@ -453,7 +450,7 @@ int set_jobexid(
             "User %s does not exist in server password file\n",
             puser);
 
-          log_err(errno, id, log_buf);
+          log_err(errno, __func__, log_buf);
 
           if (EMsg != NULL)
             snprintf(EMsg,1024,"%s",log_buf);
@@ -491,6 +488,9 @@ int set_jobexid(
             snprintf(EMsg, 1024, "root user %s fails ACL check",
                      puser);
 
+          if (free_puser == TRUE)
+            free(puser);
+
           return(PBSE_BADUSER); /* root not allowed */
           }
         }
@@ -499,6 +499,9 @@ int set_jobexid(
         if (EMsg != NULL)
           snprintf(EMsg, 1024, "root user %s not allowed",
                    puser);
+          
+        if (free_puser == TRUE)
+          free(puser);
 
         return(PBSE_BADUSER); /* root not allowed */
         }
@@ -519,12 +522,18 @@ int set_jobexid(
         puser,
         pjob->ji_wattr[JOB_ATR_proxy_user].at_val.at_str);
       log_err(PBSE_BADUSER, __func__, log_buf);
+          
+      if (free_puser == TRUE)
+        free(puser);
 
       return(PBSE_BADUSER);
       }
 
     if (site_check_user_map(pjob, puser, EMsg, LOGLEVEL) == -1)
       {
+      if (free_puser == TRUE)
+        free(puser);
+
       return(PBSE_BADUSER);
       }
 
@@ -631,7 +640,7 @@ int set_jobexid(
       }
     else
       {
-      log_err(errno, id, "getpwnam failed");
+      log_err(errno, __func__, "getpwnam failed");
 
       if (EMsg != NULL)
         snprintf(EMsg, 1024, "user does not exist in server password file");
@@ -707,7 +716,7 @@ int set_jobexid(
           puser,
           pgrpn);
 
-        log_err(-1,id,log_buf);
+        log_err(-1, __func__, log_buf);
 
         if (EMsg != NULL)
           snprintf(EMsg, 1024, "%s",log_buf);
