@@ -113,6 +113,7 @@
 #include "process_request.h" /* dispatch_request */
 #include "svr_connect.h" /* svr_disconnect_sock */
 #include "node_manager.h" /* tfind_addr */
+#include "ji_mutex.h"
 
 
 /* Global Data Items: */
@@ -129,8 +130,6 @@ extern char *msg_err_malloc;
 extern unsigned int pbs_mom_port;
 extern unsigned int pbs_server_port_dis;
 
-extern struct  connection svr_conn[];
-
 extern int       LOGLEVEL;
 
 int issue_to_svr(char *, struct batch_request *, void (*f)(struct work_task *));
@@ -218,13 +217,13 @@ int relay_to_mom(
     }
 
   strcpy(jobid, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
   request->rq_orgconn = request->rq_conn; /* save client socket */
 
   rc = issue_Drequest(handle, request, func, NULL);
 
-  *pjob_ptr = find_job(jobid);
+  *pjob_ptr = svr_find_job(jobid, TRUE);
 
   return(rc);
   }  /* END relay_to_mom() */
@@ -423,6 +422,10 @@ void release_req(
  * CONNECTION (connection handle not socket) and FREE THE REQUEST
  * STRUCTURE.  The connection (non-negative if open) is in wt_event
  * and the pointer to the request structure is in wt_parm1.
+ * If issue_Drequest fails before creating the work task then the 
+ * batch request needs to be freed. The bottom line is that the 
+ * batch request will always be freed after a call to issue_Drequest
+ * either within issue_Drequest or in the work_task.
  */
 
 int issue_Drequest(
@@ -468,7 +471,7 @@ int issue_Drequest(
       log_err(PBSE_MEM_MALLOC, __func__,
           "Could not allocate memory for socket buffer");
       close_conn(sock, FALSE);
-
+      free_br(request);
       return(PBSE_MEM_MALLOC);
       }
     }
@@ -498,7 +501,7 @@ int issue_Drequest(
 
       if (chan != NULL)
         DIS_tcp_cleanup(chan);
-
+      free_br(request);
       return(PBSE_MEM_MALLOC);
       }
     }
@@ -711,6 +714,18 @@ int issue_Drequest(
 
       break;
 
+    case PBS_BATCH_DeleteReservation:
+
+      if ((rc = encode_DIS_ReqHdr(chan, PBS_BATCH_DeleteReservation, msg_daemonname)))
+        break;
+
+      if ((rc = encode_DIS_ReqExtend(chan, request->rq_extend)))
+        break;
+
+      rc = DIS_tcp_wflush(chan);
+      
+      break;
+
 #else /* PBS_MOM */
 
     case PBS_BATCH_JobObit:
