@@ -1122,6 +1122,18 @@ attribute_def job_attr_def[] =
    ATR_TYPE_STR,
    PARENT_TYPE_JOB},
 
+  /* JOB_ATR_external_nodes */
+  {ATTR_external_nodes, /* external_nodes */
+   decode_str,
+   encode_str,
+   set_str,
+   comp_str,
+   free_str,
+   NULL_FUNC,
+   READ_WRITE,
+   ATR_TYPE_STR,
+   PARENT_TYPE_JOB},
+
   /* Site defined attributes if any, see site_job_attr_*.h  */
 #include "site_job_attr_def.h"
 
