@@ -85,7 +85,7 @@
  *   job_alloc    allocate job struct and initialize defaults
  *   job_free   free space allocated to the job structure and its
  *    childern structures.
- *   job_purge   purge job from server
+ *   svr_job_purge   purge job from server
  *
  *   job_clone    clones a job (for use with job_arrays)
  *   job_clone_wt work task for cloning a job
@@ -93,7 +93,7 @@
  * Include private function:
  *   job_init_wattr() initialize job working pbs_attribute array to "unspecified"
  *
- * NOTE: for multi-threaded TORQUE, all functions in here except find_job assume that
+ * NOTE: for multi-threaded TORQUE, all functions in here except svr_find_job assume that
  * the caller holds any relevant mutexes
  */
 
@@ -147,6 +147,8 @@
 #include "track_alps_reservations.h"
 #include "req_signal.h" /* issue_signal */
 #include "issue_request.h" /* release_req */
+#include "ji_mutex.h"
+#include "user_info.h"
 
 
 #ifndef TRUE
@@ -428,6 +430,10 @@ int job_abt(
   old_state = pjob->ji_qs.ji_state;
   old_substate = pjob->ji_qs.ji_substate;
 
+
+
+  if (LOGLEVEL >= 6)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
   /* notify user of abort if notification was requested */
 
   if (text != NULL)
@@ -471,7 +477,7 @@ int job_abt(
         if (pjob->ji_wattr[JOB_ATR_depend].at_flags & ATR_VFLAG_SET)
           {
           depend_on_term(pjob);
-          pjob = find_job(job_id);
+          pjob = svr_find_job(job_id, TRUE);
           }
         
         /* update internal array bookeeping values */
@@ -485,7 +491,7 @@ int job_abt(
             {
             job_atr_hold = pjob->ji_wattr[JOB_ATR_hold].at_val.at_long;
             job_exit_status = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
-            pthread_mutex_unlock(pjob->ji_mutex);
+            unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
             update_array_values(pa,old_state,aeTerminate,
                 job_id, job_atr_hold, job_exit_status);
             
@@ -495,12 +501,12 @@ int job_abt(
               log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, log_buf);
               }
             pthread_mutex_unlock(pa->ai_mutex);
-            pjob = find_job(job_id);
+            pjob = svr_find_job(job_id, TRUE);
             }
           }
       
         if (pjob != NULL)
-          job_purge(pjob);
+          svr_job_purge(pjob);
 
         *pjobp = NULL;
         }
@@ -515,7 +521,7 @@ int job_abt(
       pjob->ji_qs.ji_jobid,
       old_substate);
     log_err(-1, myid, log_buf);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
     }
   else
     {
@@ -532,7 +538,7 @@ int job_abt(
       {
       strcpy(job_id, pjob->ji_qs.ji_jobid);
       depend_on_term(pjob);
-      pjob = find_job(job_id);
+      pjob = svr_find_job(job_id, TRUE);
       }
 
     /* update internal array bookeeping values */
@@ -546,7 +552,7 @@ int job_abt(
         {
         job_atr_hold = pjob->ji_wattr[JOB_ATR_hold].at_val.at_long;
         job_exit_status = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
         update_array_values(pa,old_state,aeTerminate,
             job_id, job_atr_hold, job_exit_status);
         
@@ -556,12 +562,12 @@ int job_abt(
           log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, log_buf);
           }
         pthread_mutex_unlock(pa->ai_mutex);
-        pjob = find_job(job_id);
+        pjob = svr_find_job(job_id, TRUE);
         }
       }
 
     if (pjob != NULL)
-      job_purge(pjob);
+      svr_job_purge(pjob);
 
     *pjobp = NULL;
     }
@@ -665,7 +671,7 @@ job *job_alloc(void)
 
   pj->ji_mutex = (pthread_mutex_t *)calloc(1, sizeof(pthread_mutex_t));
   pthread_mutex_init(pj->ji_mutex,NULL);
-  pthread_mutex_lock(pj->ji_mutex);
+  lock_ji_mutex(pj, __func__, NULL, LOGLEVEL);
 
   pj->ji_qs.qs_version = PBS_QS_VERSION;
 
@@ -706,6 +712,21 @@ void job_free(
     log_record(PBSEVENT_DEBUG,PBS_EVENTCLASS_JOB,pj->ji_qs.ji_jobid,log_buf);
     }
 
+  if (pj->ji_cray_clone != NULL)
+    {
+    lock_ji_mutex(pj->ji_cray_clone, __func__, NULL, 0);
+    job_free(pj->ji_cray_clone, TRUE);
+    }
+
+  if (pj->ji_external_clone != NULL)
+    {
+    lock_ji_mutex(pj->ji_external_clone, __func__, NULL, 0);
+    job_free(pj->ji_external_clone, TRUE);
+    }
+
+  if (pj->ji_qs.ji_state != JOB_STATE_TRANSIT)
+    decrement_queued_jobs(&users, pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
+
   /* remove any calloc working pbs_attribute space */
   for (i = 0;i < JOB_ATR_LAST;i++)
     {
@@ -734,11 +755,13 @@ void job_free(
   if (use_recycle)
     {
     insert_into_recycler(pj);
-    pthread_mutex_unlock(pj->ji_mutex);
+    sprintf(log_buf, "1: jobid = %s", pj->ji_qs.ji_jobid);
+    unlock_ji_mutex(pj, __func__, log_buf, LOGLEVEL);
     }
   else
     {
-    pthread_mutex_unlock(pj->ji_mutex);
+    sprintf(log_buf, "2: jobid = %s", pj->ji_qs.ji_jobid);
+    unlock_ji_mutex(pj, __func__, log_buf, LOGLEVEL);
     pthread_mutex_destroy(pj->ji_mutex);
     memset(pj, 254, sizeof(job));
     free(pj);
@@ -749,6 +772,49 @@ void job_free(
 
 
 
+job *copy_job(
+
+  job       *parent)
+
+  {
+  job           *pnewjob;
+
+  int            i;
+
+  if ((pnewjob = job_alloc()) == NULL)
+    {
+    log_err(errno, __func__, "no memory");
+
+    return(NULL);
+    }
+
+  job_init_wattr(pnewjob);
+
+  /* new job structure is allocated,
+     now we need to copy the old job, but modify based on taskid */
+  CLEAR_HEAD(pnewjob->ji_rejectdest);
+  pnewjob->ji_modified = 1;   /* struct changed, needs to be saved */
+
+  /* copy the fixed size quick save information */
+  memcpy(&pnewjob->ji_qs, &parent->ji_qs, sizeof(struct jobfix));
+
+  /* copy job attributes. some of these are going to have to be modified */
+  for (i = 0; i < JOB_ATR_LAST; i++)
+    {
+    if (parent->ji_wattr[i].at_flags & ATR_VFLAG_SET)
+      {
+      job_attr_def[i].at_set(
+        &(pnewjob->ji_wattr[i]),
+        &(parent->ji_wattr[i]),
+        SET);
+      }
+    }
+
+  return(pnewjob);
+  } /* END copy_job() */
+
+
+
 
 
 /*
@@ -896,7 +962,8 @@ job *job_clone(
 
   for (i = 0; i < JOB_ATR_LAST; i++)
     {
-    if (template_job->ji_wattr[i].at_flags & ATR_VFLAG_SET)
+    if ((template_job->ji_wattr[i].at_flags & ATR_VFLAG_SET) &&
+        (i != JOB_ATR_job_array_request))
       {
       if ((i == JOB_ATR_errpath) || (i == JOB_ATR_outpath) || (i == JOB_ATR_jobname))
         {
@@ -1042,13 +1109,13 @@ void *job_clone_wt(
     }
 
   /* don't call get_jobs_array because the template job isn't part of the array */
-  if (((template_job = find_job(jobid)) == NULL) ||
+  if (((template_job = svr_find_job(jobid, TRUE)) == NULL) ||
       ((pa = get_jobs_array(&template_job)) == NULL))
     {
     free(jobid);
 
     if (template_job != NULL)
-      pthread_mutex_unlock(template_job->ji_mutex);
+      unlock_ji_mutex(template_job, __func__, "1", LOGLEVEL);
     return(NULL);
     }
 
@@ -1056,7 +1123,7 @@ void *job_clone_wt(
 
   snprintf(namebuf, sizeof(namebuf), "%s%s.AR",
     path_jobs, template_job->ji_qs.ji_fileprefix);
-  pthread_mutex_unlock(template_job->ji_mutex);
+  unlock_ji_mutex(template_job, __func__, "2", LOGLEVEL);
 
   while ((rn = (array_request_node *)GET_NEXT(pa->request_tokens)) != NULL)
     {
@@ -1065,9 +1132,9 @@ void *job_clone_wt(
 
     for (i = start; i <= end; i++)
       {
-      pthread_mutex_lock(template_job->ji_mutex);
+      lock_ji_mutex(template_job, __func__, NULL, LOGLEVEL);
       pjobclone = job_clone(template_job, pa, i);
-      pthread_mutex_unlock(template_job->ji_mutex);
+      unlock_ji_mutex(template_job, __func__, "3", LOGLEVEL);
 
       if (pjobclone == NULL)
         {
@@ -1093,7 +1160,7 @@ void *job_clone_wt(
         pthread_mutex_unlock(pa->ai_mutex);
 
         if (rc != PBSE_JOB_RECYCLED)
-          job_purge(pjobclone);
+          svr_job_purge(pjobclone);
 
         pthread_mutex_lock(pa->ai_mutex);
         continue;
@@ -1103,7 +1170,7 @@ void *job_clone_wt(
         {
         /* XXX need more robust error handling */
         pthread_mutex_unlock(pa->ai_mutex);
-        job_purge(pjobclone);
+        svr_job_purge(pjobclone);
         pthread_mutex_lock(pa->ai_mutex);
         continue;
         }
@@ -1115,7 +1182,7 @@ void *job_clone_wt(
       rn->start++;
       
       if (prev_index != -1)
-        pthread_mutex_unlock(pjobclone->ji_mutex);
+        unlock_ji_mutex(pjobclone, __func__, "4", LOGLEVEL);
       }  /* END for (i) */
 
     if (rn->start > rn->end)
@@ -1135,7 +1202,7 @@ void *job_clone_wt(
     
     actual_job_count++;
     
-    if ((pjob = find_job(pa->job_ids[i])) == NULL)
+    if ((pjob = svr_find_job(pa->job_ids[i], TRUE)) == NULL)
       {
       free(pa->job_ids[i]);
       pa->job_ids[i] = NULL;
@@ -1170,7 +1237,7 @@ void *job_clone_wt(
       svr_evaljobstate(pjob, &newstate, &newsub, 1);
       svr_setjobstate(pjob, newstate, newsub, FALSE);
       
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
       }
     }
 
@@ -1583,15 +1650,15 @@ int record_jobinfo(
 
 
 /*
- * job_purge - purge job from system
+ * svr_job_purge - purge job from system
  *
+ * pjob->ji_mutex comes into this function locked but 
+ * will always exit unlocked.
  * The job is dequeued; the job control file, script file and any spooled
  * output files are unlinked, and the job structure is freed.
- * If we are MOM, the task files and checkpoint files are also
- * removed.
  */
 
-int job_purge(
+int svr_job_purge(
 
   job *pjob)  /* I (modified) */
 
@@ -1617,6 +1684,9 @@ int job_purge(
   job_has_arraystruct = ((pjob->ji_arraystruct == NULL)?FALSE:TRUE);
   job_has_checkpoint_file = pjob->ji_wattr[JOB_ATR_checkpoint_name].at_flags;
 
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+
   /* check to see if we are keeping a log of all jobs completed */
   get_svr_attr_l(SRV_ATR_RecordJobInfo, &record_job_info);
   if (record_job_info)
@@ -1655,10 +1725,13 @@ int job_purge(
     if (pjob != NULL)
       {
       /* erase the pointer to this job in the job array */
-      free(pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long]);
-      pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long] = NULL;
+      if (pa->job_ids != NULL)
+        {
+        free(pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long]);
+        pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long] = NULL;
+        }
       
-      /* if there are no more jobs in the arry,
+      /* if there are no more jobs in the array,
        * then we can clean that up too */
       pa->ai_qs.num_purged++;
       if (pa->ai_qs.num_purged == pa->ai_qs.num_jobs)
@@ -1679,7 +1752,9 @@ int job_purge(
         }
       }
     else
-      return PBSE_JOBNOTFOUND;
+      {
+      return(PBSE_JOBNOTFOUND);
+      }
     }
 
 
@@ -1688,7 +1763,7 @@ int job_purge(
     {
     int need_deque = !pjob->ji_cold_restart;
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     /* jobs that are being deleted after a cold restart
      * haven't been queued */
@@ -1702,7 +1777,7 @@ int job_purge(
       if (pjob->ji_being_recycled == FALSE)
         job_free(pjob, TRUE);
       else
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       }
     }
   else
@@ -1814,7 +1889,7 @@ int job_purge(
     }
 
   return(PBSE_NONE);
-  }  /* END job_purge() */
+  }  /* END svr_job_purge() */
 
 
 
@@ -2031,14 +2106,20 @@ char *get_correct_jobname(
   return(correct);
   } /* END get_correct_jobname() */
 
+
+
+
+
 /*
  * Searches the array passed in for the job_id
+ * @parent svr_find_job()
  */
 
 job *find_job_by_array(
     
   struct all_jobs *aj,
-  char *job_id)
+  char            *job_id,
+  int              get_subjob)
 
   {
   job *pj = NULL;
@@ -2051,15 +2132,25 @@ job *find_job_by_array(
   if (i >= 0)
     pj = (job *)aj->ra->slots[i].item;
   if (pj != NULL)
-    pthread_mutex_lock(pj->ji_mutex);
+    lock_ji_mutex(pj, __func__, NULL, LOGLEVEL);
   
   pthread_mutex_unlock(aj->alljobs_mutex);
   
   if (pj != NULL)
     {
+    if (get_subjob == TRUE)
+      {
+      if (pj->ji_cray_clone != NULL)
+        {
+        pj = pj->ji_cray_clone;
+        unlock_ji_mutex(pj->ji_parent_job, __func__, NULL, LOGLEVEL);
+        lock_ji_mutex(pj, __func__, NULL, LOGLEVEL);
+        }
+      }
+
     if (pj->ji_being_recycled == TRUE)
       {
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
       pj = NULL;
       }
     }
@@ -2071,25 +2162,47 @@ job *find_job_by_array(
 
 
 /*
- * find_job() - find job by jobid
+ * svr_find_job() - find job by jobid
  *
  * Search list of all server jobs for one with same job id
  * Return NULL if not found or pointer to job struct if found
+ * @param jobid - get the job whose jobid matches jobid
+ * @param get_subjob - whether or not we should return the sub
+ * job (for heterogeneous jobs) if there is one
  */
 
-job *find_job(
+job *svr_find_job(
 
-  char *jobid)
+  char *jobid,      /* I */
+  int   get_subjob) /* I */
 
   {
   char *at;
   char *comp;
   int   different = FALSE;
+  char *dash = NULL;
+  char  without_dash[PBS_MAXSVRJOBID + 1];
 
   job  *pj = NULL;
 
-  if ((at = strchr(jobid, (int)'@')) != NULL)
-    * at = '\0'; /* strip off @server_name */
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, jobid);
+
+  if ((at = strchr(jobid, '@')) != NULL)
+    *at = '\0'; /* strip off @server_name */
+
+  /* jobid-0.server indicates the external sub-job of a heterogeneous
+   * job. For this case we want to get jobid.server, find that, and 
+   * the get the external sub-job */
+  if (get_subjob == TRUE)
+    {
+    if ((dash = strchr(jobid, '-')) != NULL)
+      {
+      *dash = '\0';
+      snprintf(without_dash, sizeof(without_dash), "%s%s", jobid, dash + 2);
+      jobid = without_dash;
+      }
+    }
 
   if ((is_svr_attr_set(SRV_ATR_display_job_server_suffix)) ||
       (is_svr_attr_set(SRV_ATR_job_suffix_alias)))
@@ -2107,7 +2220,10 @@ job *find_job(
 
   if (strstr(jobid,"[]") == NULL)
     {
-    pj = find_job_by_array(&alljobs, comp);
+    /* if we're searching for the external we want find_job_by_array to 
+     * return the parent, but if we're searching for the cray subjob then
+     * we want find_job_by_array to return the sub job */
+    pj = find_job_by_array(&alljobs, comp, (dash != NULL) ? FALSE : get_subjob);
     }
 
   /* when remotely routing jobs, they are removed from the 
@@ -2115,16 +2231,47 @@ job *find_job(
    * Attempt to find them there if NULL
    * OR it's an array, try to find the job */
   if (pj == NULL)
-    pj = find_job_by_array(&array_summary, comp);
+    {
+    /* see the comment on the above call to find_job_by_array() */
+    pj = find_job_by_array(&array_summary, comp, (dash != NULL) ? FALSE : get_subjob);
+    }
 
   if (at)
     *at = '@'; /* restore @server_name */
 
+  if ((get_subjob == TRUE) &&
+      (pj != NULL))
+    {
+    if (dash != NULL)
+      {
+      *dash = '-';
+      
+      if (pj->ji_external_clone != NULL)
+        {
+        pj = pj->ji_external_clone;
+        
+        lock_ji_mutex(pj, __func__, NULL, 0);
+        unlock_ji_mutex(pj->ji_parent_job, __func__, NULL, 0);
+
+        if (pj->ji_being_recycled == TRUE)
+          {
+          unlock_ji_mutex(pj, __func__, NULL, 0);
+          pj = NULL;
+          }
+        }
+      else
+        {
+        unlock_ji_mutex(pj, __func__, NULL, 0);
+        pj = NULL;
+        }
+      }
+    }
+
   if (different)
     free(comp);
 
   return(pj);  /* may be NULL */
-  }   /* END find_job() */
+  }   /* END svr_find_job() */
 
 
 
@@ -2139,7 +2286,7 @@ void initialize_all_jobs_array(
   aj->ht = create_hash(INITIAL_HASH_SIZE);
 
   aj->alljobs_mutex = calloc(1, sizeof(pthread_mutex_t));
-  pthread_mutex_init(aj->alljobs_mutex,NULL);
+  pthread_mutex_init(aj->alljobs_mutex, NULL);
   } /* END initialize_all_jobs_array() */
 
 
@@ -2303,14 +2450,14 @@ int get_jobs_index(
 
   if (pthread_mutex_trylock(aj->alljobs_mutex))
     {
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     pthread_mutex_lock(aj->alljobs_mutex);
-    pthread_mutex_lock(pjob->ji_mutex);
+    lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
       pthread_mutex_unlock(aj->alljobs_mutex);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       return(-1);
       }
     }
@@ -2341,14 +2488,14 @@ int has_job(
 
   if (pthread_mutex_trylock(aj->alljobs_mutex))
     {
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     pthread_mutex_lock(aj->alljobs_mutex);
-    pthread_mutex_lock(pjob->ji_mutex);
+    lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
       pthread_mutex_unlock(aj->alljobs_mutex);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
       return(PBSE_JOB_RECYCLED);
       }
@@ -2384,16 +2531,18 @@ int  remove_job(
   int rc = PBSE_NONE;
   int index;
 
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
   if (pthread_mutex_trylock(aj->alljobs_mutex))
     {
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     pthread_mutex_lock(aj->alljobs_mutex);
-    pthread_mutex_lock(pjob->ji_mutex);
+    lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
       pthread_mutex_unlock(aj->alljobs_mutex);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       return(PBSE_JOB_RECYCLED);
       }
     }
@@ -2433,7 +2582,7 @@ job *next_job(
 
   if (pjob != NULL)
     {
-    pthread_mutex_lock(pjob->ji_mutex);
+    lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
@@ -2444,7 +2593,7 @@ job *next_job(
         log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
         }
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
       pjob = next_job(aj,iter);
       }
@@ -2469,7 +2618,7 @@ job *next_job_from_back(
 
   pjob = (job *)next_thing_from_back(aj->ra,iter);
   if (pjob != NULL)
-    pthread_mutex_lock(pjob->ji_mutex);
+    lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
   pthread_mutex_unlock(aj->alljobs_mutex);
 
@@ -2477,7 +2626,7 @@ job *next_job_from_back(
     {
     if (pjob->ji_being_recycled == TRUE)
       {
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
       pjob = next_job_from_back(aj,iter);
       }
@@ -2554,20 +2703,21 @@ job_array *get_jobs_array(
       {
       strcpy(jobid, pjob->ji_qs.ji_jobid);
       
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       if (LOGLEVEL >=7)
         {
         sprintf(log_buf, "locking ai_mutex: %s", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
+        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, jobid, log_buf);
         }
+
       pthread_mutex_lock(pa->ai_mutex);
       if (LOGLEVEL >=7)
         {
         sprintf(log_buf, "locked ai_mutex: %s", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
+        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, jobid, log_buf);
         }
       
-      if ((pjob = find_job(jobid)) == NULL)
+      if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
         {
         pthread_mutex_unlock(pa->ai_mutex);
         pa = NULL;
@@ -2587,12 +2737,227 @@ pbs_queue *get_jobs_queue(
 
   {
   job       *pjob = *pjob_ptr;
-  pbs_queue *pque = lock_queue_with_job_held(pjob->ji_qhdr, pjob_ptr);
+  pbs_queue *pque;
+
+  pque = lock_queue_with_job_held(pjob->ji_qhdr, pjob_ptr);
 
   return(pque);
   } /* END get_jobs_queue() */
 
 
 
+
+int hostname_in_externals(
+
+  char *hostname,
+  char *externals)
+
+  {
+  char *ptr = strstr(externals, hostname);
+  int   found = FALSE;
+  char *end_word;
+
+  if (ptr != NULL)
+    {
+    end_word = ptr + strlen(hostname);
+
+    if ((ptr > externals) &&
+        (*(ptr - 1) != '+'))
+      found = FALSE;
+    else if ((*end_word != '\0') &&
+             (*end_word != '+'))
+      found = FALSE;
+    else
+      found = TRUE;
+    }
+
+  return(found);
+  } /* END hostname_in_externals() */
+
+
+
+
+int fix_external_exec_hosts(
+
+  job *pjob) /* the external sub-job */
+
+  {
+  dynamic_string *external_execs;
+  char           *exec_host = pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str;
+  char           *externals = pjob->ji_wattr[JOB_ATR_external_nodes].at_val.at_str;
+  char           *exec_ptr;
+  char           *plus;
+  char           *slash;
+
+  if ((exec_host == NULL) ||
+      (externals == NULL))
+    return(-2);
+
+  /* wipe out the current destination */
+  pjob->ji_qs.ji_destin[0] = '\0';
+
+  external_execs = get_dynamic_string(-1, NULL);
+  exec_ptr = exec_host;
+
+  while (exec_ptr != NULL)
+    {
+    /* remove the extra parts after the hostname and get the point we'll advance to.
+     * exec_host strings are in the format hostname/index[hostname/index[+...]] */
+    if ((plus = strchr(exec_ptr, '+')) != NULL)
+      {
+      *plus = '\0';
+      plus++;
+      }
+
+    if ((slash = strchr(exec_ptr, '/')) != NULL)
+      *slash = '\0';
+
+    /* if we find a match, copy in that exec host entry */
+    if (hostname_in_externals(exec_ptr, externals) == TRUE)
+      {
+      /* capture the first external as my mother superior */
+      if (pjob->ji_qs.ji_destin[0] == '\0')
+        snprintf(pjob->ji_qs.ji_destin, sizeof(pjob->ji_qs.ji_destin), "%s", exec_ptr);
+
+      if (slash != NULL)
+        *slash = '/';
+
+      /* delimit with + */
+      if (external_execs->used != 0)
+        append_dynamic_string(external_execs, "+");
+
+      append_dynamic_string(external_execs, exec_ptr);
+      }
+
+    exec_ptr = plus;
+    }
+
+  /* also remove the login attributes */
+  if (pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str != NULL)
+    {
+    free(pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str);
+    pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str = NULL;
+    pjob->ji_wattr[JOB_ATR_login_node_id].at_flags &= ~ATR_VFLAG_SET;
+    }
+
+  if (pjob->ji_wattr[JOB_ATR_login_prop].at_val.at_str != NULL)
+    {
+    free(pjob->ji_wattr[JOB_ATR_login_prop].at_val.at_str);
+    pjob->ji_wattr[JOB_ATR_login_prop].at_val.at_str = NULL;
+    pjob->ji_wattr[JOB_ATR_login_prop].at_flags &= ~ATR_VFLAG_SET;
+    }
+
+  free(exec_host);
+  pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str = strdup(external_execs->str);
+
+  free_dynamic_string(external_execs);
+
+  return(PBSE_NONE);
+  } /* END fix_external_exec_hosts() */
+
+
+
+
+int fix_cray_exec_hosts(
+
+  job *pjob)
+
+  {
+  char *external = pjob->ji_wattr[JOB_ATR_external_nodes].at_val.at_str;
+  char *exec = pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str;
+  char *new_exec = calloc(1, strlen(exec) + 1);
+  char *exec_ptr = exec;
+  char *plus;
+  char *slash;
+
+  while (exec_ptr != NULL)
+    {
+    if ((plus = strchr(exec_ptr, '+')) != NULL)
+      {
+      *plus = '\0';
+      plus++;
+      }
+
+    if ((slash = strchr(exec_ptr, '/')) != NULL)
+      *slash = '\0';
+
+    /* if the hostname isn't in the externals, copy it in */
+    if (hostname_in_externals(exec_ptr, external) == FALSE)
+      {
+      if (slash != NULL)
+        *slash = '/';
+
+      if (*new_exec != '\0')
+        strcat(new_exec, "+");
+
+      strcat(new_exec, exec_ptr);
+      }
+
+    exec_ptr = plus;
+    }
+
+  free(exec);
+  pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str = new_exec;
+
+  return(PBSE_NONE);
+  } /* END fix_cray_exec_hosts() */
+
+
+
+
+int change_external_job_name(
+
+  job *pjob)
+
+  {
+  char  tmp_jobid[PBS_MAXSVRJOBID + 1];
+  char *dot = strchr(pjob->ji_qs.ji_jobid, '.');
+
+  if (dot != NULL)
+    *dot = '\0';
+
+  snprintf(tmp_jobid, sizeof(tmp_jobid), "%s-0.%s",
+    pjob->ji_qs.ji_jobid, dot + 1);
+
+  strcpy(pjob->ji_qs.ji_jobid, tmp_jobid);
+
+  return(PBSE_NONE);
+  } /* END change_external_job_name() */
+
+
+
+
+int split_job(
+
+  job *pjob)
+
+  {
+  job            *external;
+  job            *cray;
+
+  if (pjob->ji_external_clone == NULL)
+    {
+    external = copy_job(pjob);
+    fix_external_exec_hosts(external);
+    change_external_job_name(external);
+    external->ji_parent_job = pjob;
+    pjob->ji_external_clone = external;
+    unlock_ji_mutex(external, __func__, NULL, 0);
+    }
+
+  if (pjob->ji_cray_clone == NULL)
+    {
+    cray = copy_job(pjob);
+    fix_cray_exec_hosts(cray);
+    cray->ji_parent_job     = pjob;
+    pjob->ji_cray_clone     = cray;
+    unlock_ji_mutex(cray, __func__, NULL, 0);
+    }
+
+  return(PBSE_NONE);
+  } /* END split_job() */
+
+
+
 /* END job_func.c */
 
