@@ -120,6 +120,7 @@
 #else
 #include "../resmom/mom_job_func.h" /* mom_job_free */
 #endif
+#include "ji_mutex.h"
 
 #ifndef TRUE
 #define TRUE 1
@@ -145,6 +146,9 @@ extern int LOGLEVEL;
 /* data global only to this file */
 
 static const unsigned int quicksize = sizeof(struct jobfix);
+#ifndef PBS_MOM
+int add_to_ms_list(char *node_name, job *pjob);
+#endif
 
 /*
  * job_save() - Saves (or updates) a job structure image on disk
@@ -446,7 +450,7 @@ job *job_recov(
     log_err(errno, __func__, log_buf);
 
 #ifndef PBS_MOM
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     free(pj->ji_mutex);
 #endif
 
@@ -467,7 +471,7 @@ job *job_recov(
     log_err(errno, __func__, log_buf);
 
 #ifndef PBS_MOM
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
     free(pj->ji_mutex);
 #endif
 
@@ -496,7 +500,7 @@ job *job_recov(
       log_err(-1, __func__, log_buf);
 
 #ifndef PBS_MOM
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "3", LOGLEVEL);
       free(pj->ji_mutex);
 #endif
 
@@ -525,7 +529,7 @@ job *job_recov(
     log_err(-1, __func__, log_buf);
 
 #ifndef PBS_MOM
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "4", LOGLEVEL);
     free(pj->ji_mutex);
 #endif
 
@@ -552,7 +556,7 @@ job *job_recov(
     log_err(-1, __func__, log_buf);
 
 #ifndef PBS_MOM
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "5", LOGLEVEL);
     job_free(pj, FALSE);
 #else
     mom_job_free(pj);
@@ -564,6 +568,25 @@ job *job_recov(
     return(NULL);
     }
 
+#ifndef PBS_MOM
+  if (pj->ji_wattr[JOB_ATR_exec_host].at_val.at_str != NULL)
+    {
+    /* add job to the mother superior list for it's node */
+    char *ms = strdup(pj->ji_wattr[JOB_ATR_exec_host].at_val.at_str);
+    char *end = strchr(ms, '/');
+
+    if (end != NULL)
+      *end = '\0';
+
+    if ((end = strchr(ms, '+')) != NULL)
+      *end = '\0';
+
+    add_to_ms_list(ms, pj);
+
+    free(ms);
+    }
+#endif
+
 #ifdef PBS_MOM
   /* read in tm sockets and ips */
 
@@ -576,9 +599,9 @@ job *job_recov(
     log_err(-1, __func__, log_buf);
     }
 
-#else /* PBS_MOM */
+#else /* not PBS_MOM */
 
-  if (pj->ji_wattr[JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET)
+  if (strchr(pj->ji_qs.ji_jobid, '[') != NULL)
     {
     /* job is part of an array.  We need to put a link back to the server
     job array struct for this array. We also have to link this job into
