@@ -113,6 +113,7 @@
 #if __STDC__ != 1
 #include <memory.h>
 #endif
+#include "ji_mutex.h"
 
 #define ROUTE_RETRY_TIME 30
 
@@ -128,6 +129,8 @@ void queue_route(pbs_queue *);
 /* Global Data */
 extern char *msg_routexceed;
 extern char *msg_err_malloc;
+extern char *msg_err_noqueue;
+extern int LOGLEVEL;
 
 /*
  * Add an entry to the list of bad destinations for a job.
@@ -194,161 +197,6 @@ badplace *is_bad_dest(
   }  /* END is_bad_dest() */
 
 
-/* int initialize_procct - set pjob->procct plus the resource
- * procct in the Resource_List
- *  
- * Assumes the nodes resource has been set on the Resource_List. This should 
- * have been done in req_quejob with the set_nodes_attr() function or in 
- * set_node_ct and/or set_proc_ct. 
- *  
- * Returns 0 on success. Non-zero on failure
- */ 
-int initialize_procct(
-    
-  job *pjob)
-
-  { 
-  resource      *pnodesp = NULL;
-  resource_def  *pnodes_def = NULL;
-  resource      *pprocsp = NULL;
-  resource_def  *pprocs_def = NULL;
-  resource      *procctp = NULL;
-  resource_def  *procct_def = NULL;
-  pbs_attribute *pattr = NULL;
-  char           log_buf[LOCAL_LOG_BUF_SIZE];
-
-  pattr = &pjob->ji_wattr[JOB_ATR_resource];
-  if (pattr == NULL)
-    {
-    /* Something is really wrong. ji_wattr[JOB_ATR_resource] should always be set
-       by the time this function is called */
-    sprintf(log_buf, "%s: Resource_List is NULL. Cannot proceed", __func__);
-    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-
-    return(ROUTE_PERM_FAILURE);
-    }
-
-  /* Has nodes been initialzed */
-  if (pattr->at_flags & ATR_VFLAG_SET)
-    {
-    /* get the node spec from the nodes resource */
-    pnodes_def = find_resc_def(svr_resc_def, "nodes", svr_resc_size);
-    if (pnodes_def == NULL)
-      {
-      sprintf(log_buf, "%s: Could not get nodes resource definition. Cannot proceed", __func__);
-      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-      return(ROUTE_PERM_FAILURE);
-      }
-
-    pnodesp = find_resc_entry(pattr, pnodes_def);
-
-    /* Get the procs count if the procs resource pbs_attribute is set */
-    pprocs_def = find_resc_def(svr_resc_def, "procs", svr_resc_size);
-    if (pprocs_def != NULL)
-      {
-      /* if pprocs_def is NULL we just go on. Otherwise we will get its value now */
-      pprocsp = find_resc_entry(pattr, pprocs_def);
-      /* We will evaluate pprocsp later. If it is null we do not care */
-      }
-
-    /* if neither pnodesp nor pprocsp are set, terminate */
-    if (pnodesp == NULL && pprocsp == NULL)
-      {
-      /* nodes and procs were not set. Hopefully req_quejob set procct to 1 for us already */
-      procct_def = find_resc_def(svr_resc_def, "procct", svr_resc_size);
-      if (procct_def == NULL)
-        {
-        sprintf(log_buf, "%s: Could not get procct resource definition. Cannot proceed", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-        return(ROUTE_PERM_FAILURE);
-        }
-
-      procctp = find_resc_entry(pattr, procct_def);
-      if (procctp == NULL)
-        {
-        sprintf(log_buf, "%s: Could not get nodes nor procs entry from Resource_List. Cannot proceed", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-        return(ROUTE_PERM_FAILURE);
-        }
-      }
-
-    /* we now set pjob->procct and we also set the resource pbs_attribute procct */
-    procct_def = find_resc_def(svr_resc_def, "procct", svr_resc_size);
-    if (procct_def == NULL)
-      {
-      sprintf(log_buf, "%s: Could not get procct resource definition. Cannot proceed", __func__);
-      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-      return(ROUTE_PERM_FAILURE);
-      }
-    procctp = find_resc_entry(pattr, procct_def);
-    if (procctp == NULL)
-      {
-      procctp = add_resource_entry(pattr, procct_def);
-      if (procctp == NULL)
-        {
-        sprintf(log_buf, "%s: Could not add procct resource. Cannot proceed", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-        return(ROUTE_PERM_FAILURE);
-        }
-      }
-
-    /* Finally the moment of truth. We have the nodes and procs resources. Add them
-       to the procct resoruce*/
-    procctp->rs_value.at_val.at_long = 0;
-    if (pnodesp != NULL)
-      {
-      procctp->rs_value.at_val.at_long = count_proc(pnodesp->rs_value.at_val.at_str);
-      }
-
-    if (pprocsp != NULL)
-      {
-      procctp->rs_value.at_val.at_long += pprocsp->rs_value.at_val.at_long;
-      }
-
-    procctp->rs_value.at_flags |= ATR_VFLAG_SET;
-    }
-  else
-    {
-    /* Something is really wrong. ji_wattr[JOB_ATR_resource] should always be set
-       by the time this function is called */
-    sprintf(log_buf, "%s: Resource_List not set. Cannot proceed", __func__);
-    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-    return(ROUTE_PERM_FAILURE);
-    }
-
-  return(PBSE_NONE);
-  } /* END initialize_procct */
-
-
-int remove_procct(
-
-  job *pjob)
-
-  {
-  pbs_attribute *pattr;
-  resource_def  *pctdef;
-  resource      *pctresc;
-  char           log_buf[LOCAL_LOG_BUF_SIZE];
-
-  pattr = &pjob->ji_wattr[JOB_ATR_resource];
-  if (pattr == NULL)
-    {
-    /* Something is really wrong. ji_wattr[JOB_ATR_resource] should always be set
-       by the time this function is called */
-    sprintf(log_buf, "%s: Resource_List is NULL. Cannot proceed", __func__);
-    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
-    return(ROUTE_PERM_FAILURE);
-    }
-
-  /* unset the procct resource if it has been set */
-  pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
-  
-  if ((pctresc = find_resc_entry(pattr, pctdef)) != NULL)
-    pctdef->rs_free(&pctresc->rs_value);
-
-  return(PBSE_NONE);
-  } /* END remove_procct */
-
 
 
 
@@ -372,7 +220,6 @@ int default_router(
   char                 *destination;
   int                   last;
   int                   local_errno = 0;
-  int                   rc = 0;
 
   if (qp->qu_attr[QR_ATR_RouteDestin].at_flags & ATR_VFLAG_SET)
     {
@@ -420,28 +267,10 @@ int default_router(
     if (is_bad_dest(jobp, destination))
       continue;
 
-    /* We need to manage the procct resource which is 
-       part of the Resource_List pbs_attribute. At this point 
-       we need to remember what the procct value is and also
-	     make sure it is in the Resource_List before calling
-	     svr_movejob. See ROUTE_RETRY to see what is done
-	     if the job stays in the routing queue. */
-    rc = initialize_procct(jobp);
-    if (rc != PBSE_NONE)
-      {
-      return(rc);
-      }
-
     switch (svr_movejob(jobp, destination, &local_errno, NULL, TRUE))
       {
-
       case ROUTE_PERM_FAILURE: /* permanent failure */
 
-        if ((rc = remove_procct(jobp)) != PBSE_NONE)
-          {
-          return(rc);
-          }
-
         add_dest(jobp);
 
         break;
@@ -457,17 +286,7 @@ int default_router(
         break;
 
       case ROUTE_RETRY:  /* failed, but try destination again */
-      /* There are no available queues for this job so it is 
-         going to stay in the routing queue. But we need to remove
-         procct from the Resource_List so it does not get sent
-         to the scheduler as part of the job. procct is for 
-         TORQUE use only. */
-        rc = remove_procct(jobp);
-        if(rc != PBSE_NONE)
-          {
-          return(rc);
-          }
-
+        
         jobp->ji_retryok = 1;
 
         break;
@@ -512,6 +331,9 @@ int job_route(
   struct pbs_queue *qp = jobp->ji_qhdr;
   long              retry_time;
 
+  if (qp == NULL)
+    return(PBSE_QUENOEN);
+
   /* see if the job is able to be routed */
   switch (jobp->ji_qs.ji_state)
     {
@@ -639,7 +461,7 @@ void *reroute_job(
   jobid = (char *)vp;
 
   if ((jobid != NULL) &&
-      ((pjob = find_job(jobid)) != NULL))
+      ((pjob = svr_find_job(jobid, FALSE)) != NULL))
     {
     pque = get_jobs_queue(&pjob);
 
@@ -654,12 +476,15 @@ void *reroute_job(
         job_abt(&pjob, pbse_to_txt(PBSE_ROUTEREJ));
       else if (rc == PBSE_ROUTEEXPD)
         job_abt(&pjob, msg_routexceed);
+      else if (rc == PBSE_QUENOEN)
+        job_abt(&pjob, msg_err_noqueue);
+
       }
     else if (pque != NULL)
       unlock_queue(pque, __func__, NULL, 0);
 
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
   return(NULL);      
@@ -700,7 +525,7 @@ void queue_route(
       enqueue_threadpool_request(reroute_job, strdup(pjob->ji_qs.ji_jobid));
       }
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
   return;
