@@ -33,8 +33,6 @@ int is_compose(struct tcp_chan *chan, int command);
 
 void stream_eof(int stream, u_long addr, uint16_t port, int ret);
 
-int add_cluster_addrs(struct tcp_chan *chan, struct pbsnode *held);
-
 void *check_nodes_work(void *vp);
 
 void check_nodes(struct work_task *ptask);
@@ -85,8 +83,6 @@ int MSNPrintF(char **BPtr, int *BSpace, char *Format, ...);
 
 int procs_available(int proc_ct);
 
-/* static int node_spec(char *spec, int early, int exactmatch, char *ProcBMStr, char *FailNode, char *EMsg); */
-
 #ifdef GEOMETRY_REQUESTS
 int get_bitmap(job *pjob, int ProcBMSize, char *ProcBMPtr);
 
@@ -119,8 +115,6 @@ char *find_ts_node(void);
 
 void free_nodes(job *pjob);
 
-/* static void set_one_old(char *name, job *pjob, int shared); */
-
 void set_old_nodes(job *pjob);
 
 job *get_job_from_jobinfo(struct jobinfo *jp, struct pbsnode *pnode);
