@@ -125,8 +125,10 @@
 #include "svr_func.h" /* get_svr_attr_* */
 #include "login_nodes.h"
 #include "track_alps_reservations.h"
-#include "job_func.h" /* job_purge */
+#include "job_func.h" /* svr_job_purge */
 #include "net_cache.h"
+#include "ji_mutex.h"
+#include "user_info.h"
 
 /*#ifndef SIGKILL*/
 /* there is some weird stuff in gcc include files signal.h & sys/params.h */
@@ -244,7 +246,7 @@ void  change_logs(int);
 void  change_log_level(int);
 int   chk_save_file(char *);
 int   pbsd_init_job(job *, int);
-void  pbsd_init_reque(job *, int);
+int   pbsd_init_reque(job *, int);
 void  resume_net_move(struct work_task *);
 void  rm_files(char *);
 void  stop_me(int);
@@ -1237,6 +1239,8 @@ int initialize_data_structures_and_mutexes()
   initialize_task_recycler();
   initialize_queue_recycler();
 
+  initialize_user_info_holder(&users);
+
   CLEAR_HEAD(svr_newnodes);
 
   initialize_all_arrays_array();
@@ -1663,7 +1667,7 @@ int handle_job_recovery(
             if (type == RECOV_COLD)
               pjob->ji_cold_restart = TRUE;
             
-            pthread_mutex_unlock(pjob->ji_mutex);
+            unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
             }
 
           continue;
@@ -1684,7 +1688,7 @@ int handle_job_recovery(
           if (type == RECOV_COLD)
             pjob->ji_cold_restart = TRUE;
 
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
           }
         else
           {
@@ -1716,9 +1720,11 @@ int handle_job_recovery(
       {
       job *pjob = (job *)Array.Data[Index];
 
-      pthread_mutex_lock(pjob->ji_mutex);
+      lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
-      if (pbsd_init_job(pjob, type) == FAILURE)
+      rc = pbsd_init_job(pjob, type);
+
+      if (rc == FAILURE)
         {
         log_event(
           PBSEVENT_ERROR | PBSEVENT_SYSTEM | PBSEVENT_ADMIN | PBSEVENT_JOB | PBSEVENT_FORCE,
@@ -1726,14 +1732,14 @@ int handle_job_recovery(
           pjob->ji_qs.ji_jobid,
           msg_script_open);
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
 
         continue;
         }
 
       if ((type != RECOV_COLD) &&
           (type != RECOV_CREATE) &&
-          (!(pjob->ji_wattr[JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET)) &&
+          (pjob->ji_arraystruct == NULL) &&
           (pjob->ji_qs.ji_svrflags & JOB_SVFLG_SCRIPT))
         {
         snprintf(basen, sizeof(basen), "%s%s", pjob->ji_qs.ji_fileprefix, JOB_SCRIPT_SUFFIX);
@@ -1750,11 +1756,11 @@ int handle_job_recovery(
           }
         else
           {
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
           }
         }
       else
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "6", LOGLEVEL);
       }
 
     DArrayFree(&Array);
@@ -1791,7 +1797,7 @@ int handle_job_recovery(
       
       job_save(pjob, SAVEJOB_FULL, 0);
       
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "7", LOGLEVEL);
       }
     }
 
@@ -1822,17 +1828,17 @@ int cleanup_recovered_arrays()
       log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pa->ai_qs.parent_id, log_buf);
       }
      
-    if ((pjob = find_job(pa->ai_qs.parent_id)) != NULL)
+    if ((pjob = svr_find_job(pa->ai_qs.parent_id, FALSE)) != NULL)
       {
       job_template_exists = TRUE;
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       }
 
     /* if no jobs were recovered, delete this array */
     if (pa->jobs_recovered == 0)
       {
-      if ((pjob = find_job(pa->ai_qs.parent_id)) != NULL)
-        job_purge(pjob);
+      if ((pjob = svr_find_job(pa->ai_qs.parent_id, FALSE)) != NULL)
+        svr_job_purge(pjob);
 
       array_delete(pa);
 
@@ -1862,10 +1868,10 @@ int cleanup_recovered_arrays()
           {
           if (pa->job_ids[i] != NULL)
             {
-            if ((pjob = find_job(pa->job_ids[i])) != NULL)
+            if ((pjob = svr_find_job(pa->job_ids[i], FALSE)) != NULL)
               {
               pthread_mutex_unlock(pa->ai_mutex);
-              job_purge(pjob);
+              svr_job_purge(pjob);
               pthread_mutex_lock(pa->ai_mutex);
               }
             }
@@ -2186,13 +2192,14 @@ int pbsd_init_job(
 
   {
   unsigned int      d;
-
+  int               rc = PBSE_NONE;
   time_t            time_now = time(NULL);
   char              log_buf[LOCAL_LOG_BUF_SIZE];
   int               local_errno = 0;
-  char  job_id[PBS_MAXSVRJOBID+1];
-  long  job_atr_hold;
-  int   job_exit_status;
+  char              job_id[PBS_MAXSVRJOBID+1];
+  long              job_atr_hold;
+  int               job_exit_status;
+  long              cray_enabled = FALSE;
 
   pjob->ji_momhandle = -1;
 
@@ -2243,7 +2250,7 @@ int pbsd_init_job(
         pjob->ji_qs.ji_state = JOB_STATE_QUEUED;
         pjob->ji_qs.ji_substate = JOB_SUBSTATE_QUEUED;
 
-        pbsd_init_reque(pjob, CHANGE_STATE);
+        rc = pbsd_init_reque(pjob, CHANGE_STATE);
         }
       else
         {
@@ -2267,7 +2274,7 @@ int pbsd_init_job(
 
       /* requeue as queued */
 
-      pbsd_init_reque(pjob, CHANGE_STATE);
+      rc = pbsd_init_reque(pjob, CHANGE_STATE);
 
       break;
 
@@ -2275,7 +2282,7 @@ int pbsd_init_job(
 
       /* requeue as is - rdy to cmt */
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       /* resend rtc */
 
@@ -2311,13 +2318,13 @@ int pbsd_init_job(
 
     case JOB_SUBSTATE_ARRAY_TEMP:
 
-      pbsd_init_reque(pjob, CHANGE_STATE);
+      rc = pbsd_init_reque(pjob, CHANGE_STATE);
 
       break;
 
     case JOB_SUBSTATE_RUNNING:
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_RescAssn;
 
@@ -2341,7 +2348,7 @@ int pbsd_init_job(
 
       depend_clrrdy(pjob);
 
-      pbsd_init_reque(pjob, CHANGE_STATE);
+      rc = pbsd_init_reque(pjob, CHANGE_STATE);
 
       break;
 
@@ -2362,7 +2369,7 @@ int pbsd_init_job(
 
       set_task(WORK_Immed, 0, on_job_exit, strdup(pjob->ji_qs.ji_jobid), FALSE);
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       break;
 
@@ -2371,7 +2378,7 @@ int pbsd_init_job(
       /* Completed jobs are no longer purged on startup */
       set_task(WORK_Immed, 0, on_job_exit, strdup(pjob->ji_qs.ji_jobid), FALSE);
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       /* do array bookeeping */
       if ((pjob->ji_arraystruct != NULL) &&
@@ -2384,7 +2391,7 @@ int pbsd_init_job(
           strcpy(job_id, pjob->ji_qs.ji_jobid);
           job_atr_hold = pjob->ji_wattr[JOB_ATR_hold].at_val.at_long;
           job_exit_status = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
           update_array_values(pa,JOB_STATE_RUNNING,aeTerminate,
               job_id, job_atr_hold, job_exit_status);
           
@@ -2394,7 +2401,7 @@ int pbsd_init_job(
             log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, log_buf);
             }
           pthread_mutex_unlock(pa->ai_mutex);
-          pjob = find_job(job_id);
+          pjob = svr_find_job(job_id, FALSE);
           }
          
         }
@@ -2406,7 +2413,7 @@ int pbsd_init_job(
       if (pjob->ji_qs.ji_state == JOB_STATE_EXITING)
         set_task(WORK_Immed, 0, on_job_rerun, strdup(pjob->ji_qs.ji_jobid), FALSE);
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       break;
 
@@ -2416,7 +2423,7 @@ int pbsd_init_job(
 
       set_task(WORK_Immed, 0, on_job_rerun, strdup(pjob->ji_qs.ji_jobid), FALSE);
 
-      pbsd_init_reque(pjob, KEEP_STATE);
+      rc = pbsd_init_reque(pjob, KEEP_STATE);
 
       break;
 
@@ -2447,7 +2454,17 @@ int pbsd_init_job(
       {
       if (pjob->ji_wattr[JOB_ATR_exec_host].at_flags & ATR_VFLAG_SET)
         {
-        char *tmp = parse_servername(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str, &d);
+        char *tmp;
+        get_svr_attr_l(SRV_ATR_CrayEnabled, &cray_enabled);
+
+        if ((cray_enabled == TRUE) &&
+            (pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str != NULL))
+          {
+          tmp = parse_servername(pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str, &d);
+          }
+        else
+          tmp = parse_servername(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str, &d);
+
         pjob->ji_qs.ji_un.ji_exect.ji_momaddr = get_hostaddr(&local_errno, tmp);
         free(tmp);
         }
@@ -2458,14 +2475,14 @@ int pbsd_init_job(
       }
     }
 
-  return(SUCCESS);
+  return(rc);
   }  /* END pbsd_init_job() */
 
 
 
 
 
-void pbsd_init_reque(
+int pbsd_init_reque(
 
   job *pjob,         /* I (modified/possibly freed) */
   int  change_state) /* I */
@@ -2511,7 +2528,8 @@ void pbsd_init_reque(
   else
     {
     /* Oops, this should never happen */
-    if (rc != PBSE_JOB_RECYCLED)
+    if ((rc != PBSE_JOB_RECYCLED) &&
+        (rc != PBSE_BADDEPEND))
       {
       sprintf(logbuf, "%s; job %s queue %s",
         msg_err_noqueue,
@@ -2523,7 +2541,8 @@ void pbsd_init_reque(
 
     unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
 
-    if (rc != PBSE_JOB_RECYCLED)
+    if ((rc != PBSE_JOB_RECYCLED) &&
+        (rc != PBSE_BADDEPEND))
       job_abt(&pjob, logbuf);
 
     lock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
@@ -2533,6 +2552,7 @@ void pbsd_init_reque(
 
   sprintf(log_buf, "%s:1", __func__);
   unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
+  return(rc);
   }  /* END pbsd_init_reque() */
 
 
@@ -2750,11 +2770,11 @@ void resume_net_move(
 
   if (jobid != NULL)
     {
-    pjob = find_job(jobid);
+    pjob = svr_find_job(jobid, FALSE);
   
     net_move(pjob, 0);
     
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     free(jobid);
     }
@@ -2852,10 +2872,10 @@ void init_abt_job(
 
   svr_mailowner(pjob, MAIL_ABORT, MAIL_NORMAL, msg_init_abt);
 
-  job_purge(pjob);
+  svr_job_purge(pjob);
 
   return;
-  }
+  } /* END init_abt_job() */
 
 
 
