@@ -137,6 +137,7 @@
 #include "process_request.h" /* process_request */
 #include "net_connect.h" /* set_localhost_name */
 #include "tcp.h" /* tcp_chan */
+#include "ji_mutex.h"
 
 #define TASK_CHECK_INTERVAL    10
 #define HELLO_WAIT_TIME        600
@@ -382,10 +383,10 @@ int process_pbs_server_port(
   int is_scheduler_port)
  
   {
-  int          proto_type;
-  int          rc = PBSE_NONE;
-  int          version;
-  char         log_buf[LOCAL_LOG_BUF_SIZE];
+  int              proto_type;
+  int              rc = PBSE_NONE;
+  int              version;
+  char             log_buf[LOCAL_LOG_BUF_SIZE];
   struct tcp_chan *chan = NULL;
    
   if ((chan = DIS_tcp_setup(sock)) == NULL)
@@ -409,7 +410,7 @@ int process_pbs_server_port(
       if (rc != DIS_SUCCESS)
         {
         log_err(-1,  __func__, "Cannot read version - skipping this request.\n");
-        close_conn(sock,FALSE);
+        rc = PBSE_SOCKET_CLOSE; 
         break;
         }
       
@@ -426,7 +427,7 @@ int process_pbs_server_port(
       if (getpeername(sock, &s_addr, &len) == 0)
         {
         addr = (struct sockaddr_in *)&s_addr;
-
+        
         if (proto_type == 0)
           {
           /* 
@@ -435,21 +436,26 @@ int process_pbs_server_port(
            */
           if (!is_scheduler_port)
             {
-            snprintf(log_buf, sizeof(log_buf),
-                "Socket (%d) close detected from %s", sock, netaddr(addr));
-            log_err(-1, __func__, log_buf);
+            if (LOGLEVEL >= 8)
+              {
+              snprintf(log_buf, sizeof(log_buf),
+                "proto_type: %d: Socket (%d) close detected from %s", proto_type, sock, netaddr(addr));
+              log_event(PBSEVENT_SYSTEM, PBS_EVENTCLASS_REQUEST, __func__, log_buf);
+              }
             }
+
+          rc = PBSE_SOCKET_CLOSE;
           }
         else
           {
           snprintf(log_buf,sizeof(log_buf),
               "Socket (%d) Unknown protocol %d from %s", sock, proto_type, netaddr(addr));
           log_err(-1, __func__, log_buf);
+          rc = PBSE_SOCKET_DATA;
           }
-
         }
-
-      rc = PBSE_SOCKET_DATA;
+      else
+        rc = PBSE_SOCKET_CLOSE;
 
       break;
       }
@@ -480,8 +486,11 @@ void process_pbs_server_port_scheduler(
   int rc = PBSE_NONE;
   int sock = *new_sock;
 
-  while ((rc != PBSE_SOCKET_DATA) && (rc != PBSE_SOCKET_INFORMATION)
-        && (rc != PBSE_INTERNAL) && (rc != PBSE_SYSTEM)  && (rc != PBSE_SOCKET_CLOSE))
+  while ((rc != PBSE_SOCKET_DATA) && 
+         (rc != PBSE_SOCKET_INFORMATION) &&
+         (rc != PBSE_INTERNAL) &&
+         (rc != PBSE_SYSTEM) &&
+         (rc != PBSE_SOCKET_CLOSE))
     {
     netcounter_incr();
     rc = process_pbs_server_port(sock, TRUE);
@@ -1104,7 +1113,7 @@ static int start_hot_jobs(void)
       ct++;
       }
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
   return(ct);
@@ -1489,7 +1498,7 @@ void main_loop(void)
     if (pjob->ji_modified)
       job_save(pjob, SAVEJOB_FULL, 0);
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
   if (svr_chngNodesfile)
