@@ -144,8 +144,9 @@
 #include "req_rerun.h" /* req_rerunjob */
 #include "req_select.h" /* req_selectjobs */
 #include "req_register.h" /* req_register, req_registerarray */
-#include "job_func.h" /* job_purge */
+#include "job_func.h" /* svr_job_purge */
 #include "tcp.h" /* tcp_chan */
+#include "ji_mutex.h"
 
 /*
  * process_request - this function gets, checks, and invokes the proper
@@ -337,6 +338,7 @@ int process_request(
   conn_socktype = svr_conn[sfds].cn_socktype;
   conn_authen = svr_conn[sfds].cn_authen;
   conn_addr = svr_conn[sfds].cn_addr;
+  svr_conn[sfds].cn_lasttime = time_now;
   pthread_mutex_unlock(svr_conn[sfds].cn_mutex);
 
   if ((request = alloc_br(0)) == NULL)
@@ -596,7 +598,7 @@ int process_request(
         *dptr = '\0';
         }
       
-      if ((pjob = find_job(request->rq_ind.rq_modify.rq_objname)) != (job *)0)
+      if ((pjob = svr_find_job(request->rq_ind.rq_modify.rq_objname, FALSE)) != (job *)0)
         {
         if (pjob->ji_qs.ji_state == JOB_STATE_RUNNING)
           {
@@ -612,7 +614,7 @@ int process_request(
             }
 
           }
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
       
       if (!skip)
@@ -624,7 +626,7 @@ int process_request(
       {
       request->rq_perm = svr_get_privilege(request->rq_user, request->rq_host);
       }
-    }  /* END else (svr_conn[sfds].cn_authen == PBS_NET_CONN_FROM_PRIVIL) */
+    }  /* END else (conn_authen == PBS_NET_CONN_FROM_PRIVIL) */
 
   /* if server shutting down, disallow new jobs and new running */
   get_svr_attr_l(SRV_ATR_State, &state);
@@ -1018,14 +1020,19 @@ int close_quejob_by_jobid(
   int  rc = PBSE_NONE;
   job *pjob = NULL;
 
-  if ((pjob = find_job(job_id)) == NULL)
+  if (LOGLEVEL >= 10)
+    {
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, job_id);
+    }
+
+  if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
     {
     rc = PBSE_JOBNOTFOUND;
     }
   else if (pjob->ji_qs.ji_substate != JOB_SUBSTATE_TRANSICM)
     {
     remove_job(&newjobs,pjob);
-    job_purge(pjob);
+    svr_job_purge(pjob);
     pjob = NULL;
     }
   else if (pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE)
@@ -1045,7 +1052,7 @@ int close_quejob_by_jobid(
     }
 
   if (pjob != NULL)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   return(rc);
   } /* close_quejob_by_jobid() */
