@@ -114,6 +114,7 @@
 #include "queue_recycler.h"
 #include "svrfunc.h"
 #include "svr_func.h" /* get_svr_attr_* */
+#include "ji_mutex.h"
 
 
 #define MSG_LEN_LONG 160
@@ -140,20 +141,20 @@ int lock_queue(
   int rc = PBSE_NONE;
   char *err_msg = NULL;
 
-  if (logging >= 6)
+  if (logging >= 10)
     { 
     err_msg = (char *)calloc(1, MSG_LEN_LONG);
     snprintf(err_msg, MSG_LEN_LONG, "locking %s in method %s", the_queue->qu_qs.qu_name, id);
-    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
     }
 
   if (pthread_mutex_lock(the_queue->qu_mutex) != 0)
     { 
-    if (logging >= 6) 
+    if (logging >= 10) 
       {
       snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock queue %s mutex in method %s",
           the_queue->qu_qs.qu_name, id);
-      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
       }
     rc = PBSE_MUTEX;
     } 
@@ -176,22 +177,22 @@ int unlock_queue(
   char *err_msg = NULL;
   char stub_msg[] = "no pos";
 
-  if (logging >= 7)
+  if (logging >= 10)
     {
     err_msg = (char *)calloc(1, MSG_LEN_LONG);
     if (msg == NULL)
       msg = stub_msg;
     snprintf(err_msg, MSG_LEN_LONG, "unlocking %s in method %s-%s", the_queue->qu_qs.qu_name, id, msg);
-    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
     }
 
   if (pthread_mutex_unlock(the_queue->qu_mutex) != 0)
     {
-    if (logging >= 7)
+    if (logging >= 10)
       {
       snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock queue %s mutex in method %s",
           the_queue->qu_qs.qu_name, id);
-      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
       }
     rc = PBSE_MUTEX;
     }
@@ -247,7 +248,7 @@ pbs_queue *que_alloc(
   initialize_all_jobs_array(pq->qu_jobs);
   initialize_all_jobs_array(pq->qu_jobs_array_sum);
   pthread_mutex_init(pq->qu_mutex,NULL);
-  lock_queue(pq, "que_alloc", NULL, LOGLEVEL);
+  lock_queue(pq, __func__, NULL, LOGLEVEL);
 
   strncpy(pq->qu_qs.qu_name, name, PBS_MAXQUEUENAME);
 
@@ -259,6 +260,10 @@ pbs_queue *que_alloc(
   if (sv_qs_mutex_held == FALSE)
     unlock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
+  /* set up the user info struct */
+  pq->qu_uih = calloc(1, sizeof(user_info_holder));
+  initialize_user_info_holder(pq->qu_uih);
+
   /* set the working attributes to "unspecified" */
 
   for (i = 0; i < QA_ATR_LAST; i++)
@@ -311,6 +316,8 @@ void que_free(
   if (sv_qs_mutex_held == FALSE)
     unlock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
+  free_user_info_holder(pq->qu_uih);
+
   remove_queue(&svr_queues, pq);
   pq->q_being_recycled = TRUE;
   insert_into_queue_recycler(pq);
@@ -369,13 +376,20 @@ pbs_queue *find_queuebyname(
   char *quename) /* I */
 
   {
-  char  *pc;
+  char      *pc;
   pbs_queue *pque = NULL;
-  char   qname[PBS_MAXDEST + 1];
-  int    i;
+  char       qname[PBS_MAXDEST + 1];
+  char       log_buf[LOCAL_LOG_BUF_SIZE+1];
+  int        i;
 
   snprintf(qname, sizeof(qname), "%s", quename);
 
+  if (LOGLEVEL >= 7)
+    {
+    sprintf(log_buf, "%s", quename);
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   pc = strchr(qname, (int)'@'); /* strip off server (fragment) */
 
   if (pc != NULL)
@@ -579,13 +593,20 @@ int get_parent_dest_queues(
   pbs_queue *pque_parent;
   pbs_queue *pque_dest;
   char       jobid[PBS_MAXSVRJOBID + 1];
+  char       log_buf[LOCAL_LOG_BUF_SIZE + 1];
   job       *pjob = *pjob_ptr;
   int        index_parent;
   int        index_dest;
   int        rc = PBSE_NONE;
 
+  if (LOGLEVEL >= 7)
+    {
+    sprintf(log_buf, "%s", pjob->ji_qs.ji_jobid);
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   strcpy(jobid, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   unlock_queue(*parent, __func__, NULL, 0);
 
@@ -627,7 +648,7 @@ int get_parent_dest_queues(
 
   pthread_mutex_unlock(svr_queues.allques_mutex);
 
-  if ((*pjob_ptr = find_job(jobid)) == NULL)
+  if ((*pjob_ptr = svr_find_job(jobid, TRUE)) == NULL)
     rc = -1;
 
   return(rc);
@@ -652,10 +673,10 @@ pbs_queue *lock_queue_with_job_held(
       {
       /* if fail */
       strcpy(jobid, pjob->ji_qs.ji_jobid);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       lock_queue(pque, __func__, NULL, LOGLEVEL);
 
-      if ((pjob = find_job(jobid)) == NULL)
+      if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
         {
         unlock_queue(pque, __func__, NULL, 0);
         pque = NULL;
@@ -665,7 +686,7 @@ pbs_queue *lock_queue_with_job_held(
     }
 
   return(pque);
-  } /* END get_jobs_queue() */
+  } /* END lock_queue_with_job_held() */
 
 
 
