@@ -112,7 +112,8 @@
 #include "array.h"
 #include "utils.h"
 #include "svr_func.h" /* get_svr_attr_* */
-#include "job_func.h" /* job_purge */
+#include "job_func.h" /* svr_job_purge */
+#include "ji_mutex.h"
 
 #define PURGE_SUCCESS 1
 #define MOM_DELETE    2
@@ -241,7 +242,7 @@ void force_purge_work(
     }
   
   if (pjob != NULL)
-    job_purge(pjob);
+    svr_job_purge(pjob);
   } /* END force_purge_work() */
 
 
@@ -260,7 +261,7 @@ void ensure_deleted(
 
   if (jobid != NULL)
     {
-    if ((pjob = find_job(jobid)) != NULL)
+    if ((pjob = svr_find_job(jobid, FALSE)) != NULL)
       {
       force_purge_work(pjob);
       }
@@ -306,7 +307,7 @@ int execute_job_delete(
     /* see note in req_delete - not sure this is possible still,
      * but the deleted code is irrelevant now. I will leave this
      * part --dbeer */
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     return(-1);
     }
@@ -363,7 +364,7 @@ int execute_job_delete(
 
     pwtnew = set_task(WORK_Timed,time_now + 1,post_delete_route,preq,FALSE);
     
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
     if (pwtnew == NULL)
       {
@@ -437,7 +438,7 @@ jump:
 
     if (pjob->ji_has_delete_nanny == TRUE)
       {
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
 
       req_reject(PBSE_IVALREQ, 0, preq, NULL, "job cancel in progress");
 
@@ -465,7 +466,7 @@ jump:
       sprintf(log_buf, msg_delrunjobsig, sigt);
       log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,pjob->ji_qs.ji_jobid,log_buf);
   
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
       }
 
     return(-1);
@@ -506,7 +507,7 @@ jump:
         if (!strcmp(pa->job_ids[i], pjob->ji_qs.ji_jobid))
           continue;
 
-        if ((tmp = find_job(pa->job_ids[i])) == NULL)
+        if ((tmp = svr_find_job(pa->job_ids[i], FALSE)) == NULL)
           {
           free(pa->job_ids[i]);
           pa->job_ids[i] = NULL;
@@ -526,12 +527,12 @@ jump:
             svr_setjobstate(tmp, newstate, newsub, FALSE);
             job_save(tmp, SAVEJOB_FULL, 0);
 
-            pthread_mutex_unlock(tmp->ji_mutex);
+            unlock_ji_mutex(tmp, __func__, "5", LOGLEVEL);
             
             break;
             }
 
-          pthread_mutex_unlock(tmp->ji_mutex);
+          unlock_ji_mutex(tmp, __func__, "6", LOGLEVEL);
           }
         }
 
@@ -613,7 +614,7 @@ jump:
     }  /* END else if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHECKPOINT_FILE) != 0) */
 
   if (has_mutex == TRUE)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "7", LOGLEVEL);
 
   return(PBSE_NONE);
   } /* END execute_job_delete() */
@@ -626,20 +627,30 @@ struct batch_request *duplicate_request(
   struct batch_request *preq)
 
   {
-  struct batch_request *preq_tmp = alloc_br(PBS_BATCH_DeleteJob);
+  struct batch_request *preq_tmp = alloc_br(preq->rq_type);
+
   preq_tmp->rq_perm = preq->rq_perm;
   preq_tmp->rq_ind.rq_manager.rq_cmd = preq->rq_ind.rq_manager.rq_cmd;
   preq_tmp->rq_ind.rq_manager.rq_objtype = preq->rq_ind.rq_manager.rq_objtype;
   preq_tmp->rq_fromsvr = preq->rq_fromsvr;
   preq_tmp->rq_extsz = preq->rq_extsz;
   preq_tmp->rq_conn = preq->rq_conn;
+
   memcpy(preq_tmp->rq_ind.rq_manager.rq_objname,
     preq->rq_ind.rq_manager.rq_objname, PBS_MAXSVRJOBID + 1);
+
   memcpy(preq_tmp->rq_user, preq->rq_user, PBS_MAXUSER + 1);
   memcpy(preq_tmp->rq_host, preq->rq_host, PBS_MAXHOSTNAME + 1);
+
   if (preq->rq_extend != NULL)
     preq_tmp->rq_extend = strdup(preq->rq_extend);
 
+  if (preq->rq_type == PBS_BATCH_RunJob)
+    {
+    if (preq->rq_ind.rq_run.rq_destin)
+      preq_tmp->rq_ind.rq_run.rq_destin = strdup(preq->rq_ind.rq_run.rq_destin);
+    }
+
   return(preq_tmp);
   } /* END duplicate_request() */
 
@@ -679,7 +690,7 @@ int handle_delete_all(
 
     if (pjob->ji_qs.ji_state >= JOB_STATE_EXITING)
       {
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       
       continue;
       }
@@ -749,7 +760,7 @@ int handle_single_delete(
   {
   int   rc= -1;
   char *jobid = preq->rq_ind.rq_delete.rq_objname;
-  job  *pjob = find_job(jobid);
+  job  *pjob = svr_find_job(jobid, FALSE);
 
   if (pjob == NULL)
     {
@@ -1009,7 +1020,7 @@ static void post_delete_mom1(
   if (preq_clt == NULL)
     return;
 
-  pjob = find_job(preq_clt->rq_ind.rq_delete.rq_objname);
+  pjob = svr_find_job(preq_clt->rq_ind.rq_delete.rq_objname, FALSE);
 
   if (pjob == NULL)
     {
@@ -1038,7 +1049,7 @@ static void post_delete_mom1(
 
       set_resc_assigned(pjob, DECR);
 
-      job_purge(pjob);
+      svr_job_purge(pjob);
 
       reply_ack(preq_clt);
       }
@@ -1046,7 +1057,7 @@ static void post_delete_mom1(
       {
       req_reject(rc, 0, preq_clt, NULL, NULL);
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       }
 
     return;
@@ -1089,7 +1100,7 @@ static void post_delete_mom1(
    */
   apply_job_delete_nanny(pjob, time_now + delay + 60);
 
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
   }  /* END post_delete_mom1() */
 
 
@@ -1116,7 +1127,7 @@ static void post_delete_mom2(
     return;
     }
 
-  pjob = find_job(jobid);
+  pjob = svr_find_job(jobid, FALSE);
   free(jobid);
 
   if (pjob != NULL)
@@ -1133,7 +1144,7 @@ static void post_delete_mom2(
       }
     
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
   }  /* END post_delete_mom2() */
 
@@ -1174,7 +1185,7 @@ static int forced_jobpurge(
         /* FAILURE */
         req_reject(PBSE_PERM, 0, preq, NULL, NULL);
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
         return(-1);
         }
@@ -1278,7 +1289,7 @@ static void job_delete_nanny(
     
     if (jobid != NULL)
       {
-      pjob = find_job(jobid);
+      pjob = svr_find_job(jobid, FALSE);
       
       if (pjob != NULL)
         {
@@ -1298,7 +1309,7 @@ static void job_delete_nanny(
           {
           apply_job_delete_nanny(pjob, time_now + 60);
   
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
           }
         }
       }
@@ -1357,7 +1368,7 @@ static void post_job_delete_nanny(
     }
 
   /* extract job id from task */
-  pjob = find_job(preq_sig->rq_ind.rq_signal.rq_jid);
+  pjob = svr_find_job(preq_sig->rq_ind.rq_signal.rq_jid, FALSE);
 
   if (pjob == NULL)
     {
@@ -1377,12 +1388,12 @@ static void post_job_delete_nanny(
   
     free_br(preq_sig);
 
-    job_purge(pjob);
+    svr_job_purge(pjob);
 
     return;
     }
   
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   /* free task */
   free_br(preq_sig);
@@ -1460,7 +1471,7 @@ void purge_completed_jobs(
       job_save(pjob, SAVEJOB_FULL, 0); 
       }
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
 
