@@ -109,6 +109,7 @@
 #include "svrfunc.h"
 #include "array.h"
 #include "svr_func.h" /* get_svr_attr_* */
+#include "ji_mutex.h"
 
 #define CHK_HOLD 1
 #define CHK_CONT 2
@@ -184,7 +185,7 @@ static void post_modify_req(
     {
     if (preq->rq_reply.brp_code == PBSE_UNKJOBID)
       {
-      if ((pjob = find_job(preq->rq_ind.rq_modify.rq_objname)) == NULL)
+      if ((pjob = svr_find_job(preq->rq_ind.rq_modify.rq_objname, FALSE)) == NULL)
         {
         req_reject(preq->rq_reply.brp_code, 0, preq, NULL, NULL);
         return;
@@ -202,7 +203,7 @@ static void post_modify_req(
           log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,pjob->ji_qs.ji_jobid,log_buf);
           }
         
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
       }
 
@@ -244,7 +245,7 @@ void mom_cleanup_checkpoint_hold(
     return;
     }
 
-  pjob = find_job(jobid);
+  pjob = svr_find_job(jobid, FALSE);
   if (pjob == NULL)
     {
     if (LOGLEVEL >= 3)
@@ -296,7 +297,7 @@ void mom_cleanup_checkpoint_hold(
           
           log_err(rc, __func__, log_buf);
           
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
           }
 
         return;
@@ -319,7 +320,7 @@ void mom_cleanup_checkpoint_hold(
     }
 
   if (pjob != NULL)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
   } /* END mom_cleanup_checkpoint_hold() */
 
 
@@ -348,7 +349,7 @@ void chkpt_xfr_hold(
       (preq->rq_extra == NULL))
     return;
 
-  if ((pjob = find_job(preq->rq_extra)) == NULL)
+  if ((pjob = svr_find_job(preq->rq_extra, FALSE)) == NULL)
     return;
 
   if (LOGLEVEL >= 7)
@@ -365,7 +366,7 @@ void chkpt_xfr_hold(
 
   set_task(WORK_Immed, 0, mom_cleanup_checkpoint_hold, strdup(pjob->ji_qs.ji_jobid), FALSE);
 
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   return;
   }  /* END chkpt_xfr_hold() */
@@ -857,7 +858,7 @@ int modify_whole_array(
     if (pa->job_ids[i] == NULL)
       continue;
 
-    if ((pjob = find_job(pa->job_ids[i])) == NULL)
+    if ((pjob = svr_find_job(pa->job_ids[i], FALSE)) == NULL)
       {
       free(pa->job_ids[i]);
       pa->job_ids[i] = NULL;
@@ -865,7 +866,16 @@ int modify_whole_array(
     else
       {
       /* NO_MOM_RELAY will prevent modify_job from calling relay_to_mom */
+      pthread_mutex_unlock(pa->ai_mutex);
       rc = modify_job((void **)&pjob, plist, preq, checkpoint_req, NO_MOM_RELAY);
+      pa = get_jobs_array(&pjob);
+
+      if ((pjob == NULL) &&
+          (pa != NULL))
+        {
+        pa->job_ids[i] = NULL;
+        continue;
+        }
 
       if (rc == PBSE_RELAYED_TO_MOM)
         {
@@ -875,7 +885,7 @@ int modify_whole_array(
         rc = copy_batchrequest(&array_req, preq, 0, i);
         if (rc != 0)
           {
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
           return(rc);
           }
 
@@ -895,7 +905,7 @@ int modify_whole_array(
               "Unable to relay information to mom for job '%s'\n",
               pjob->ji_qs.ji_jobid);
             log_err(rc, __func__, log_buf);
-            pthread_mutex_unlock(pjob->ji_mutex);
+            unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
             }
 
           return(rc); /* unable to get to MOM */
@@ -903,7 +913,7 @@ int modify_whole_array(
         }
 
       if (pjob != NULL)
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
       }
     } /* END foreach job in array */
 
@@ -1069,7 +1079,7 @@ void *req_modifyarray(
         sprintf(log_buf, "%s: unlocked ai_mutex", __func__);
         log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
         }
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
       req_reject(rc,0,preq,NULL,NULL);
       return(NULL);
@@ -1083,12 +1093,12 @@ void *req_modifyarray(
         sprintf(log_buf, "%s: unlocked ai_mutex", __func__);
         log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
         }
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       
       return(NULL);
       }
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
     }
 
   /* SUCCESS */
@@ -1143,7 +1153,7 @@ void *req_modifyjob(
     reply_ack(preq);
 
     /* SUCCESS */
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     return(NULL);
     }
@@ -1177,7 +1187,7 @@ void *req_modifyjob(
       reply_badattr(rc,1,plist,preq);
     else if ( rc == PBSE_RELAYED_TO_MOM )
       {
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       
       return(NULL);
       }
@@ -1187,7 +1197,7 @@ void *req_modifyjob(
   else
     reply_ack(preq);
 
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
   
   return(NULL);
   }  /* END req_modifyjob() */
@@ -1225,9 +1235,13 @@ int modify_job_attr(
 
     unlock_queue(pque, __func__, NULL, LOGLEVEL);
     }
+  else if (pjob->ji_parent_job != NULL)
+    {
+    allow_unkn = JOB_ATR_UNKN;
+    }
   else
     {
-    log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+    log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 5");
     return(PBSE_JOBNOTFOUND);
     }
 
@@ -1283,7 +1297,7 @@ int modify_job_attr(
           }
         else if (pjob == NULL)
           {
-          log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+          log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 6");
           return(PBSE_JOBNOTFOUND);
           }
         else
@@ -1438,9 +1452,12 @@ int modify_job_attr(
 
   pjob->ji_modified = 1;
 
-  return(0);
+  return(PBSE_NONE);
   }  /* END modify_job_attr() */
 
+
+
+
 /*
  * post_modify_arrayreq - clean up after sending modify request to MOM
  */
@@ -1489,7 +1506,7 @@ void post_modify_arrayreq(
     {
     if (preq->rq_reply.brp_code == PBSE_UNKJOBID)
       {
-      if ((pjob = find_job(preq->rq_ind.rq_modify.rq_objname)) == NULL)
+      if ((pjob = svr_find_job(preq->rq_ind.rq_modify.rq_objname, FALSE)) == NULL)
         {
         parent_req->rq_refcount--;
 
@@ -1518,7 +1535,7 @@ void post_modify_arrayreq(
           log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,pjob->ji_qs.ji_jobid,log_buf);
           }
         
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
       }
 
