@@ -123,11 +123,11 @@
 #include "svr_func.h" /* get_svr_attr_* */
 #include "array_func.h" /* setup_array_struct */
 #include "threadpool.h"
-#include "job_func.h" /* job_purge */
+#include "job_func.h" /* svr_job_purge */
 #include "pbs_nodes.h"
 #include "../lib/Libutils/u_lock_ctl.h" /* lock_node, unlock_node */
-
-
+#include "ji_mutex.h"
+#include "user_info.h"
 #include "work_task.h"
 
 
@@ -609,7 +609,7 @@ int req_quejob(
 
   /* does job already exist, check both old and new jobs */
 
-  if ((pj = find_job(jid)) == NULL)
+  if ((pj = svr_find_job(jid, FALSE)) == NULL)
     {
     int  iter = -1;
 
@@ -618,7 +618,7 @@ int req_quejob(
       if (!strcmp(pj->ji_qs.ji_jobid, jid))
         break;
       
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
       }
     }
 
@@ -629,7 +629,7 @@ int req_quejob(
     rc = PBSE_JOBEXIST;
     log_err(rc, __func__, "cannot queue new job, job already exists");
     req_reject(rc, 0, preq, NULL, NULL);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
     return rc;
     }
 
@@ -642,7 +642,7 @@ int req_quejob(
     /* use default queue */
     pque = get_dfltque();
 
-    rc   = PBSE_QUENODFLT;
+    rc = PBSE_QUENODFLT;
     }
   else
     {
@@ -780,7 +780,7 @@ int req_quejob(
       {
       /* FAILURE */
       rc = PBSE_ATTRRO;
-      job_purge(pj);
+      svr_job_purge(pj);
       reply_badattr(rc, 1, psatl, preq);
       return(rc);
       }
@@ -815,7 +815,7 @@ int req_quejob(
           {
           /* FAILURE */
           /* any other error is fatal */
-          job_purge(pj);
+          svr_job_purge(pj);
           reply_badattr(rc, 1, psatl, preq);
           return(rc);
           }
@@ -845,7 +845,7 @@ int req_quejob(
         if (pque->qu_qs.qu_type == QTYPE_Execution)
           {
           /* FAILURE */
-          job_purge(pj);
+          svr_job_purge(pj);
           reply_badattr(rc, 1, psatl, preq);
           return(rc);
           }
@@ -854,7 +854,7 @@ int req_quejob(
         {
         /* FAILURE */
         /* any other error is fatal */
-        job_purge(pj);
+        svr_job_purge(pj);
         reply_badattr(rc, 1, psatl, preq);
         return(rc);
         }
@@ -884,7 +884,7 @@ int req_quejob(
 
       if (rc)
         {
-        job_purge(pj);
+        svr_job_purge(pj);
         req_reject(rc, i, preq, NULL, "cannot execute attribute action");
         return(rc);
         }
@@ -925,7 +925,7 @@ int req_quejob(
           (pj->ji_wattr[JOB_ATR_priority].at_val.at_long > 1024))
         {
         rc = PBSE_BADATVAL;
-        job_purge(pj);
+        svr_job_purge(pj);
         req_reject(rc, 0, preq, NULL, "invalid job priority");
         return rc;
         }
@@ -949,12 +949,12 @@ int req_quejob(
         }
 
       /* make sure the job id doesn't already exist */
-      if ((tmpjob = find_job(tmp_job_id)) != NULL)
+      if ((tmpjob = svr_find_job(tmp_job_id, FALSE)) != NULL)
         {
-        pthread_mutex_unlock(tmpjob->ji_mutex);
+        unlock_ji_mutex(tmpjob, __func__, "3", LOGLEVEL);
 
         /* not unique, reject job */
-        job_purge(pj);
+        svr_job_purge(pj);
        
         rc = PBSE_JOBEXIST; 
         snprintf(log_buf,sizeof(log_buf),
@@ -1184,7 +1184,7 @@ int req_quejob(
         (pj->ji_wattr[JOB_ATR_errpath].at_val.at_str == NULL))
       {
       rc = PBSE_NOATTR;
-      job_purge(pj);
+      svr_job_purge(pj);
       req_reject(rc, 0, preq, NULL, "no output/error file specified");
       return rc;
       }
@@ -1259,7 +1259,7 @@ int req_quejob(
             pj->ji_wattr[JOB_ATR_account].at_val.at_str) == 0)
         {
         rc = PBSE_BADACCT;
-        job_purge(pj);
+        svr_job_purge(pj);
         req_reject(rc, 0, preq, NULL, "invalid account");
         return rc;
         }
@@ -1279,7 +1279,7 @@ int req_quejob(
         {
         /* no default found */
         rc = PBSE_BADACCT;
-        job_purge(pj);
+        svr_job_purge(pj);
         req_reject(rc, 0, preq, NULL, "no default account available");
         return rc;
         }
@@ -1297,7 +1297,7 @@ int req_quejob(
       {
       rc = PBSE_IVALREQ;
       snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "no job owner specified");
-      job_purge(pj);
+      svr_job_purge(pj);
       log_err(rc, __func__, log_buf);
       req_reject(rc, 0, preq, NULL, log_buf);
       return rc;
@@ -1308,7 +1308,7 @@ int req_quejob(
     if (++pj->ji_wattr[JOB_ATR_hopcount].at_val.at_long > PBS_MAX_HOPCOUNT)
       {
       rc = PBSE_HOPCOUNT;
-      job_purge(pj);
+      svr_job_purge(pj);
       req_reject(rc, 0, preq, NULL, "max job hop reached");
       return rc;
       }
@@ -1323,6 +1323,28 @@ int req_quejob(
     server_name,
     resc_access_perm);
 
+  /* make sure its okay to submit this job */
+  if (can_queue_new_job(pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str, pj) == FALSE)
+    {
+    long max_queuable;
+
+    get_svr_attr_l(SRV_ATR_MaxUserQueuable, &max_queuable);
+    snprintf(log_buf, sizeof(log_buf),
+      "Job %s violates the global server limit of %ld jobs queued per user",
+      pj->ji_qs.ji_jobid,
+      max_queuable);
+
+    svr_job_purge(pj);
+
+    req_reject(PBSE_MAXQUED, 0, preq, NULL, log_buf);
+    
+    return(PBSE_MAXQUED);
+    }
+  else
+    {
+    increment_queued_jobs(&users, pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str, pj);
+    }
+
   /*
    * See if the job is qualified to go into the requested queue.
    * Note, if an execution queue, then ji_qs.ji_un.ji_exect is set up
@@ -1361,7 +1383,7 @@ int req_quejob(
 
   if ((rc = svr_chkque(pj, pque, preq->rq_host, MOVE_TYPE_Move, EMsg)))
     {
-    job_purge(pj);
+    svr_job_purge(pj);
     req_reject(rc, 0, preq, NULL, EMsg);
     return(rc);
     }
@@ -1398,7 +1420,7 @@ int req_quejob(
     {
     /* reply failed, purge the job and close the connection */
     rc = PBSE_SOCKET_WRITE; /* Re-write reply_jobid to return the error */
-    job_purge(pj);
+    svr_job_purge(pj);
     return rc;
     }
 
@@ -1406,7 +1428,7 @@ int req_quejob(
   insert_job(&newjobs,pj);
 
   *pjob_id = strdup(pj->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "4", LOGLEVEL);
 
   return rc;
   }  /* END req_quejob() */
@@ -1443,12 +1465,12 @@ int req_jobcredential(
     {
     rc = PBSE_PERM;
     req_reject(rc, 0, preq, NULL, "job request not authorized");
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     return rc;
     }
 
   reply_ack(preq);
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
   return rc;
   }  /* END req_jobcredential() */
 
@@ -1510,7 +1532,7 @@ int req_jobscript(
       }
     log_err(rc, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     return(rc);
     }
 
@@ -1522,7 +1544,7 @@ int req_jobscript(
         preq->rq_ind.rq_jobfile.rq_jobid, errno, strerror(errno));
     log_err(rc, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
     return rc;
     }
 
@@ -1549,7 +1571,7 @@ int req_jobscript(
              msg_script_open);
     log_err(rc, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "3", LOGLEVEL);
     return rc;
     }
 
@@ -1567,7 +1589,7 @@ int req_jobscript(
     log_err(rc, __func__, log_buf);
     req_reject(PBSE_INTERNAL, 0, preq, NULL, log_buf);
     close(fds);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "4", LOGLEVEL);
     return rc;
     }
 
@@ -1581,7 +1603,7 @@ int req_jobscript(
     (pj->ji_qs.ji_svrflags & ~JOB_SVFLG_CHECKPOINT_FILE) | JOB_SVFLG_SCRIPT;
 
   /* SUCCESS */
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "5", LOGLEVEL);
 
   reply_ack(preq);
 
@@ -1616,7 +1638,7 @@ int req_mvjobfile(
   pj = locate_new_job(preq->rq_conn, NULL);
 
   if (pj == NULL)
-    pj = find_job(preq->rq_ind.rq_jobfile.rq_jobid);
+    pj = svr_find_job(preq->rq_ind.rq_jobfile.rq_jobid, FALSE);
 
   if ((preq->rq_fromsvr == 0) || (pj == NULL))
     {
@@ -1626,7 +1648,7 @@ int req_mvjobfile(
     log_err(rc, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, NULL);
     if (pj != NULL)
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     return(rc);
     }
 
@@ -1660,7 +1682,7 @@ int req_mvjobfile(
           pj->ji_qs.ji_jobid, errno, strerror(errno));
       log_err(rc, __func__, log_buf);
       req_reject(rc, 0, preq, NULL, log_buf);
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
       return(rc);
       break;
     }
@@ -1681,7 +1703,7 @@ int req_mvjobfile(
         namebuf, pj->ji_qs.ji_jobid, errno, strerror(errno), msg_script_open);
     log_err(errno, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "3", LOGLEVEL);
     return(rc);
     }
 
@@ -1697,7 +1719,7 @@ int req_mvjobfile(
     log_err(rc, "req_jobfile", log_buf);
     req_reject(PBSE_SYSTEM, 0, preq, NULL, log_buf);
     close(fds);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "4", LOGLEVEL);
     return(rc);
     }
 
@@ -1719,7 +1741,7 @@ int req_mvjobfile(
 
   reply_ack(preq);
 
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "5", LOGLEVEL);
 
   return(rc);
   }  /* END req_mvjobfile() */
@@ -1782,7 +1804,7 @@ int req_rdytocommit(
         preq->rq_ind.rq_rdytocommit, errno, strerror(errno));
     log_err(rc, __func__, log_buf);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     return(rc);
     }
 
@@ -1792,7 +1814,7 @@ int req_rdytocommit(
     snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "can not authorize job req %s",
         preq->rq_ind.rq_rdytocommit);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "2", LOGLEVEL);
     return(rc);
     }
 
@@ -1840,7 +1862,7 @@ int req_rdytocommit(
     pj->ji_wattr[JOB_ATR_state].at_flags = OrigFlags;
 
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "3", LOGLEVEL);
     return(rc);
     }
 
@@ -1848,7 +1870,7 @@ int req_rdytocommit(
   strcpy(jobid, pj->ji_qs.ji_jobid);
 
   /* unlock now to prevent a potential deadlock */
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "4", LOGLEVEL);
 
   if (reply_jobid(preq, jobid, BATCH_REPLY_CHOICE_RdytoCom) != 0)
     {
@@ -1861,8 +1883,10 @@ int req_rdytocommit(
       errno,
       strerror(errno));
     log_err(rc, __func__, log_buf);
-    if ((pj = find_job(jobid)) != NULL)
-      job_purge(pj);
+
+    if ((pj = svr_find_job(jobid, FALSE)) != NULL)
+      svr_job_purge(pj);
+
     return(rc);
     }
 
@@ -1994,6 +2018,9 @@ int req_commit(
     return(rc);
     }
 
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pj->ji_qs.ji_jobid);
+
 #ifdef QUICKCOMMIT
   if (pj->ji_qs.ji_substate != JOB_SUBSTATE_TRANSIN)
     {
@@ -2003,7 +2030,7 @@ int req_commit(
         errno, strerror(errno));
     log_err(rc, __func__, log_buf);
     req_reject(PBSE_IVALREQ, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "5", LOGLEVEL);
     return(rc);
     }
 
@@ -2036,7 +2063,7 @@ int req_commit(
         errno, strerror(errno));
     log_err(rc, __func__, "cannot commit job in unexpected state");
     req_reject(rc, 0, preq, NULL, NULL);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "6", LOGLEVEL);
     return(rc);
     }
 
@@ -2048,7 +2075,7 @@ int req_commit(
     req_reject(rc, 0, preq, NULL, log_buf);
     if (LOGLEVEL >= 6)
       log_record(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pj->ji_qs.ji_jobid, log_buf);
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "7", LOGLEVEL);
     return(rc);
     }
 
@@ -2088,11 +2115,11 @@ int req_commit(
         req_reject(rc, 0, preq, NULL, NULL);
         }
 
-      pthread_mutex_unlock(pj->ji_mutex);
+      unlock_ji_mutex(pj, __func__, "8", LOGLEVEL);
 
       return(rc);
       }
-    }  /* end if (pj->ji_wattr[JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET) */
+    }  /* end if (pj->ji_is_array_template) */
 
   svr_evaljobstate(pj, &newstate, &newsub, 1);
   svr_setjobstate(pj, newstate, newsub, FALSE);
@@ -2115,7 +2142,7 @@ int req_commit(
         log_record(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pj->ji_qs.ji_jobid, log_buf);
         }
 
-      job_purge(pj);
+      svr_job_purge(pj);
       }
 
     req_reject(rc, 0, preq, NULL, log_buf);
@@ -2134,7 +2161,7 @@ int req_commit(
       log_record(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pj->ji_qs.ji_jobid, log_buf);
       }
 
-    job_purge(pj);
+    svr_job_purge(pj);
     req_reject(rc, 0, preq, NULL, log_buf);
     return(rc);
     }
@@ -2162,7 +2189,7 @@ int req_commit(
           log_record(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pj->ji_qs.ji_jobid,
             log_buf);
           }
-        job_purge(pj);
+        svr_job_purge(pj);
         req_reject(rc, 0, preq, NULL, log_buf);
         return(rc);
         }
@@ -2226,7 +2253,7 @@ int req_commit(
     issue_track(pj);
     }
 
-  pthread_mutex_unlock(pj->ji_mutex);
+  unlock_ji_mutex(pj, __func__, "9", LOGLEVEL);
 
 #ifdef AUTORUN_JOBS
   /* If we are auto running jobs with start_count = 0 then the
@@ -2309,7 +2336,7 @@ static job *locate_new_job(
 
       break;
       }
-    pthread_mutex_unlock(pj->ji_mutex);
+    unlock_ji_mutex(pj, __func__, "1", LOGLEVEL);
     }  /* END while(pj != NULL) */
 
   /* return job slot located (NULL on FAILURE) */
