@@ -102,6 +102,7 @@
 #include "svrfunc.h"
 #include "array.h"
 #include "svr_func.h" /* get_svr_attr_* */
+#include "ji_mutex.h"
 
 #define SYNC_SCHED_HINT_NULL 0
 #define SYNC_SCHED_HINT_FIRST 1
@@ -197,7 +198,7 @@ int req_register(
 
   /* find the "parent" job specified in the request */
 
-  if ((pjob = find_job(preq->rq_ind.rq_register.rq_parent)) == NULL)
+  if ((pjob = svr_find_job(preq->rq_ind.rq_register.rq_parent, TRUE)) == NULL)
     {
     /*
      * job not found... if server is initializing, it may not
@@ -255,7 +256,7 @@ int req_register(
     rc = PBSE_BADSTATE;
     req_reject(rc, 0, preq, NULL, NULL);
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     
     return(rc);
     }
@@ -606,7 +607,7 @@ int req_register(
     }
 
   if (pjob != NULL)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
   return(rc);
   }  /* END req_register() */
@@ -944,7 +945,7 @@ void set_array_depend_holds(
 
     while (pdj != NULL)
       {
-      pjob = find_job(pdj->dc_child);
+      pjob = svr_find_job(pdj->dc_child, TRUE);
 
       if (pjob != NULL)
         {
@@ -976,7 +977,7 @@ void set_array_depend_holds(
           set_depend_hold(pjob,&pjob->ji_wattr[JOB_ATR_depend]);
           }
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
 
       pdj = (struct array_depend_job *)GET_NEXT(pdj->dc_link);
@@ -1022,7 +1023,7 @@ static void post_doq(
     snprintf(log_buf, sizeof(log_buf), "%s%s", msg_regrej, preq->rq_ind.rq_register.rq_parent);
     log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, jobid, log_buf);
 
-    pjob = find_job(jobid);
+    pjob = svr_find_job(jobid, TRUE);
 
     if ((msg = pbse_to_txt(preq->rq_reply.brp_code)) != NULL)
       {
@@ -1056,7 +1057,7 @@ static void post_doq(
 
         set_depend_hold(pjob, pattr);
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
       }
     }
@@ -1091,7 +1092,7 @@ static void alter_unreg(
   char               job_id[PBS_MAXSVRJOBID+1];
 
   strcpy(job_id, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
   pjob = NULL;
 
   for (poldd = (struct depend *)GET_NEXT(old->at_val.at_list);
@@ -1110,8 +1111,9 @@ static void alter_unreg(
         {
         if ((pnewd == 0) || (find_dependjob(pnewd, oldjd->dc_child) == 0))
           {
-          if ((pjob = find_job(job_id)) == NULL)
+          if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
               return;
+
           send_depend_req(
             pjob,
             oldjd,
@@ -1164,7 +1166,7 @@ int depend_on_que(
     {
     if (pjob == NULL)
       {
-      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 8");
       return(PBSE_JOBNOTFOUND);
       }
     else
@@ -1185,7 +1187,7 @@ int depend_on_que(
     /* if there are dependencies being removed, unregister them */
 
     alter_unreg(pjob, &(pjob)->ji_wattr[JOB_ATR_depend], pattr);
-    if ((pjob = find_job(job_id)) == NULL)
+    if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
       return PBSE_JOBNOTFOUND;
     }
 
@@ -1218,13 +1220,14 @@ int depend_on_que(
 
       while (pparent)
         {
-        if ((pjob == NULL) && ((pjob = find_job(job_id)) == NULL))
+        if ((pjob == NULL) &&
+            ((pjob = svr_find_job(job_id, TRUE)) == NULL))
           {
           return PBSE_JOBNOTFOUND;
           }
         if ((rc = send_depend_req(pjob, pparent, type, JOB_DEPEND_OP_REGISTER, SYNC_SCHED_HINT_NULL, post_doq)) != PBSE_NONE)
           {
-          pjob = find_job(job_id);
+          pjob = svr_find_job(job_id, TRUE);
           return(rc);
           }
         pjob = NULL;
@@ -1268,7 +1271,7 @@ static void post_doe(
 
   jobid = preq->rq_ind.rq_register.rq_child;
 
-  pjob = find_job(jobid);
+  pjob = svr_find_job(jobid, TRUE);
 
   if (pjob != NULL)
     {
@@ -1286,7 +1289,7 @@ static void post_doe(
       del_depend(pdep);
       }
     
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
 
   free_br(preq);
@@ -1334,7 +1337,7 @@ int depend_on_exec(
         post_doe);
       pjob = NULL; /* send_depend_req returns unlocked, NULL--> unlocked */
 
-      if ((pjob = find_job(jobid)) == NULL)
+      if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
         return PBSE_JOBNOTFOUND;
 
       pdj = (struct depend_job *)GET_NEXT(pdj->dc_link);
@@ -1361,7 +1364,8 @@ int depend_on_exec(
         JOB_DEPEND_OP_READY,
         SYNC_SCHED_HINT_NULL,
         release_req);
-      if ((pjob == NULL) && ((pjob = find_job(jobid)) == NULL))
+      if ((pjob == NULL) &&
+          ((pjob = svr_find_job(jobid, TRUE)) == NULL))
         return PBSE_JOBNOTFOUND;
       }
     }
@@ -1495,7 +1499,7 @@ int depend_on_term(
           while (pparent)
             {
             if ((pjob == NULL) && 
-                ((pjob = find_job(job_id)) == NULL))
+                ((pjob = svr_find_job(job_id, TRUE)) == NULL))
               return(PBSE_JOBNOTFOUND);
 
             rc = send_depend_req(pjob, pparent, type,
@@ -1521,7 +1525,7 @@ int depend_on_term(
       while (pparent)
         {
         if ((pjob == NULL) && 
-            ((pjob = find_job(job_id)) == NULL))
+            ((pjob = svr_find_job(job_id, TRUE)) == NULL))
           return(PBSE_JOBNOTFOUND);
 
         /* "release" the job to execute */
@@ -1539,7 +1543,7 @@ int depend_on_term(
     pdep = (struct depend *)GET_NEXT(pdep->dp_link);
     }
   if (!job_unlocked)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   return(0);
   }  /* END depend_on_term() */
@@ -1604,7 +1608,7 @@ static void release_cheapest(
       {
       cheapest->dc_state = JOB_DEPEND_OP_RELEASE;
       }
-    pjob = find_job(job_id);
+    pjob = svr_find_job(job_id, TRUE);
     }
 
   return;
@@ -1675,7 +1679,7 @@ void set_depend_hold(
 
         if (djob)
           {
-          djp = find_job(djob->dc_child);
+          djp = svr_find_job(djob->dc_child, TRUE);
 
           if (!djp ||
               ((pdp->dp_type == JOB_DEPEND_TYPE_AFTERSTART) &&
@@ -1697,7 +1701,7 @@ void set_depend_hold(
             }
 
           if (djp != NULL)
-            pthread_mutex_unlock(djp->ji_mutex);
+            unlock_ji_mutex(djp, __func__, "1", LOGLEVEL);
           }
 
         break;
@@ -2149,7 +2153,7 @@ static int send_depend_req(
   if (preq == NULL)
     {
     log_err(errno, myid, msg_err_malloc);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     return(PBSE_SYSTEM);
     }
 
@@ -2201,7 +2205,7 @@ static int send_depend_req(
 
   /* save jobid and unlock mutex */
   strcpy(job_id, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
   get_batch_request_id(preq);
   strcpy(br_id, preq->rq_id);
