@@ -100,11 +100,13 @@
 #include "../lib/Liblog/log_event.h"
 #include "acct.h"
 #include "svrfunc.h"
+#include "ji_mutex.h"
 
 /* Private Function local to this file */
 
 /* Global Data Items: */
 
+extern int   LOGLEVEL;
 extern char *msg_manager;
 extern char *msg_jobrerun;
 
@@ -144,13 +146,13 @@ static void post_rerun(
 
     log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,preq->rq_ind.rq_signal.rq_jid,log_buf);
 
-    if ((pjob = find_job(preq->rq_ind.rq_signal.rq_jid)))
+    if ((pjob = svr_find_job(preq->rq_ind.rq_signal.rq_jid, FALSE)))
       {
       svr_evaljobstate(pjob, &newstate, &newsub, 1);
 
       svr_setjobstate(pjob, newstate, newsub, FALSE);
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       }
     }
 
@@ -174,14 +176,16 @@ static void post_rerun(
  */
 
 int req_rerunjob(
-    struct batch_request *preq)
-  {
-  int rc = PBSE_NONE;
-  job                  *pjob;
+   
+  struct batch_request *preq)
 
-  int                   Force;
-  int                   MgrRequired = TRUE;
-  char                  log_buf[LOCAL_LOG_BUF_SIZE];
+  {
+  int     rc = PBSE_NONE;
+  job    *pjob;
+
+  int     Force;
+  int     MgrRequired = TRUE;
+  char    log_buf[LOCAL_LOG_BUF_SIZE];
 
   /* check if requestor is admin, job owner, etc */
 
@@ -219,7 +223,7 @@ int req_rerunjob(
     snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "job %s is in a bad state",
         preq->rq_ind.rq_rerun);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
     return rc;
     }
 
@@ -232,7 +236,7 @@ int req_rerunjob(
     snprintf(log_buf, LOCAL_LOG_BUF_SIZE,
         "additional permissions required (ATR_DFLAG_MGWR | ATR_DFLAG_OPWR)");
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
     return rc;
     }
 
@@ -249,7 +253,7 @@ int req_rerunjob(
     snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "job %s not rerunnable",
         preq->rq_ind.rq_rerun);
     req_reject(rc, 0, preq, NULL, log_buf);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
     return rc;
     }
 
@@ -321,24 +325,34 @@ int req_rerunjob(
         snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "Rejected by mom");
         req_reject(rc, 0, preq, NULL, log_buf);
         if (pjob != NULL)
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
         return rc;
         }
       else
         {
-        int newstate, newsubst;
-        unsigned int dummy;
-        char *tmp;
+        int           newstate;
+        int           newsubst;
+        unsigned int  dummy;
+        char         *tmp;
+        long          cray_enabled = FALSE;
        
         if (pjob != NULL)
           {
-          tmp = parse_servername(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str, &dummy);
+          get_svr_attr_l(SRV_ATR_CrayEnabled, &cray_enabled);
+
+          if ((cray_enabled == TRUE) &&
+              (pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str != NULL))
+            tmp = parse_servername(pjob->ji_wattr[JOB_ATR_login_node_id].at_val.at_str, &dummy);
+          else
+            tmp = parse_servername(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str, &dummy);
           
           /* Cannot communicate with MOM, forcibly requeue job.
              This is a relatively disgusting thing to do */
           
           sprintf(log_buf, "rerun req to %s failed (rc=%d), forcibly requeueing job",
             tmp, rc);
+
+          free(tmp);
   
           log_event(
             PBSEVENT_ERROR | PBSEVENT_ADMIN | PBSEVENT_JOB,
@@ -346,7 +360,7 @@ int req_rerunjob(
             pjob->ji_qs.ji_jobid,
             log_buf);
           
-          log_err(-1, "req_rerunjob", log_buf);
+          log_err(-1, __func__, log_buf);
           
           strcat(log_buf, ", previous output files may be lost");
   
@@ -399,7 +413,7 @@ int req_rerunjob(
   
     /* note in accounting file */
     account_record(PBS_ACCT_RERUN, pjob, NULL);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "6", LOGLEVEL);
     }
 
   return rc;
