@@ -116,7 +116,7 @@
 #include "../lib/Libutils/u_lock_ctl.h" /* unlock_node */
 #include "svr_func.h" /* get_svr_attr_* */
 #include "req_stat.h" /* stat_mom_job */
-
+#include "ji_mutex.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
@@ -174,6 +174,7 @@ char *DispatchNode[20];
 extern job  *chk_job_request(char *, struct batch_request *);
 extern struct batch_request *cpy_checkpoint(struct batch_request *, job *, enum job_atr, int);
 void poll_job_task(work_task *);
+int  kill_job_on_mom(char *jobid, struct pbsnode *pnode);
 
 
 /*
@@ -219,7 +220,7 @@ int req_runjob(
   strcpy(job_id, pjob->ji_qs.ji_jobid);
   if (strstr(pjob->ji_qs.ji_jobid,"[]") != NULL)
     {
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     req_reject(PBSE_IVALREQ, 0, preq, NULL, "cannot run a job array");
     return(PBSE_IVALREQ);
     }
@@ -265,10 +266,10 @@ int req_runjob(
       job_atr_hold = pjob->ji_wattr[JOB_ATR_hold].at_val.at_long;
       job_exit_status = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
       job_state = pjob->ji_qs.ji_state;
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       update_array_values(pa,job_state,aeRun,
           job_id, job_atr_hold, job_exit_status);
-      if ((pjob = find_job(job_id)) == NULL)
+      if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
         {
         rc = PBSE_JOBNOTFOUND;
         req_reject(rc, 0, preq, NULL,
@@ -293,7 +294,7 @@ int req_runjob(
         log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pa->ai_qs.parent_id, log_buf);
         }
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
       pthread_mutex_unlock(pa->ai_mutex);
 
       return(PBSE_IVALREQ);
@@ -329,7 +330,7 @@ int req_runjob(
       }
     }
 
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
 
   return(rc);
   }  /* END req_runjob() */
@@ -389,7 +390,7 @@ static void post_checkpointsend(
     return;
 
   code = preq->rq_reply.brp_code;
-  pjob = find_job(preq->rq_extra);
+  pjob = svr_find_job(preq->rq_extra, FALSE);
 
   free(preq->rq_extra);
 
@@ -453,7 +454,7 @@ static void post_checkpointsend(
       }
 
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }    /* END if (pjob != NULL) */
 
   free_br(preq); /* close connection and release request */
@@ -565,7 +566,7 @@ int req_stagein(
 
     req_reject(PBSE_IVALREQ, 0, preq, NULL, NULL);
  
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     return(PBSE_IVALREQ);
     }
@@ -581,7 +582,7 @@ int req_stagein(
     req_reject(rc, 0, preq, NULL, NULL);
     }
 
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
   return(rc);
   }  /* END req_stagein() */
@@ -618,7 +619,7 @@ static void post_stagein(
     return;
 
   code = preq->rq_reply.brp_code;
-  pjob = find_job(preq->rq_extra);
+  pjob = svr_find_job(preq->rq_extra, FALSE);
 
   free(preq->rq_extra);
 
@@ -689,7 +690,7 @@ static void post_stagein(
       }
 
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }    /* END if (pjob != NULL) */
 
   free_br(preq); /* close connection and release request */
@@ -1063,6 +1064,203 @@ int svr_startjob(
   }  /* END svr_startjob() */
 
 
+
+
+int send_job_to_mom(
+ 
+  job           **pjob_ptr,   /* M */
+  batch_request  *preq,       /* I */
+  job            *parent_job) /* I - for heterogeneous jobs only */
+
+  {
+  job             *pjob = *pjob_ptr;
+  int              old_state;
+  int              old_subst;
+  long             job_timeout = 0;
+  long             tcp_timeout = 0;
+  unsigned long    job_momaddr = -1;
+  char             job_id[PBS_MAXSVRJOBID+1];
+  int              my_err = 0;
+  int              external = FALSE;
+  char             tmpLine[MAXLINE];
+  char            *mail_text = NULL;
+
+  if (parent_job != NULL)
+    external = pjob == parent_job->ji_external_clone;
+
+  old_state = pjob->ji_qs.ji_state;
+  old_subst = pjob->ji_qs.ji_substate;
+
+  svr_setjobstate(pjob, JOB_STATE_RUNNING, JOB_SUBSTATE_PRERUN, FALSE);
+
+  /* if job start timeout pbs_attribute is set use its value */
+  get_svr_attr_l(SRV_ATR_tcp_timeout, &tcp_timeout);
+  
+  if ((get_svr_attr_l(SRV_ATR_JobStartTimeout, &job_timeout) == PBSE_NONE) &&
+      (job_timeout > 0))
+    {
+    DIS_tcp_settimeout(job_timeout);
+    }
+
+  job_momaddr = pjob->ji_qs.ji_un.ji_exect.ji_momaddr;
+  strcpy(job_id, pjob->ji_qs.ji_jobid);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+  *pjob_ptr = NULL;
+  pjob = NULL;
+  if (preq->rq_reply.brp_un.brp_txt.brp_str != NULL)
+    mail_text = strdup(preq->rq_reply.brp_un.brp_txt.brp_str);
+
+  if (send_job_work(job_id, NULL, MOVE_TYPE_Exec, &my_err, preq) == PBSE_NONE)
+    {
+    /* SUCCESS */
+    DIS_tcp_settimeout(tcp_timeout);
+    
+    if (parent_job == NULL)
+      {
+      if ((pjob = svr_find_job(job_id, TRUE)) != NULL)
+        {
+        *pjob_ptr = pjob;
+
+        svr_mailowner(pjob, MAIL_BEGIN, MAIL_NORMAL, mail_text);
+        
+        if (mail_text != NULL)
+          free(mail_text);
+        }
+      }
+
+    return(PBSE_NONE);
+    }
+  else
+    {
+    DIS_tcp_settimeout(tcp_timeout);
+
+    if (parent_job == NULL)
+      pjob = svr_find_job(job_id, TRUE);
+    else
+      {
+      if (external == TRUE)
+        pjob = parent_job->ji_external_clone;
+      else
+        pjob = parent_job->ji_cray_clone;
+      }
+
+    if (pjob != NULL)
+      {
+      sprintf(tmpLine, "unable to run job, send to MOM '%lu' failed", job_momaddr);
+      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, tmpLine);
+      *pjob_ptr = pjob;
+      pjob->ji_qs.ji_destin[0] = '\0';
+      
+      svr_setjobstate(pjob, old_state, old_subst, FALSE);
+      }
+
+    if (mail_text != NULL)
+      free(mail_text);
+    
+    return(my_err);
+    }
+  } /* END send_job_to_mom() */
+
+
+
+
+/*
+ * kills the job on the mom and requeues the job
+ */
+int requeue_job(
+
+  job *pjob)
+
+  {
+  struct pbsnode *pnode = find_nodebyname(pjob->ji_qs.ji_destin);
+  int             retry = 0;
+  int             rc = -1;
+
+  if (pnode == NULL)
+    return(-1);
+
+  /* setting this makes it so that the obit will be ignored by pbs_server */
+  pjob->ji_qs.ji_un.ji_exect.ji_momaddr = 0;
+
+  while ((rc != PBSE_NONE) &&
+         (retry < 3))
+    {
+    rc = kill_job_on_mom(pjob->ji_qs.ji_jobid, pnode);
+    retry++;
+    }
+
+  /* set the job's state to queued */
+  svr_setjobstate(pjob, JOB_STATE_QUEUED, JOB_SUBSTATE_QUEUED, FALSE);
+
+  pjob->ji_qs.ji_destin[0] = '\0';
+
+  return(rc);
+  } /* END requeue_job() */
+
+
+
+int handle_heterogeneous_job_launch(
+
+  job           *pjob,
+  batch_request *preq)
+
+  {
+  job           *external_clone = pjob->ji_external_clone;
+  job           *cray_clone     = pjob->ji_cray_clone;
+  int            both_running   = FALSE;
+  int            rc             = PBSE_NONE;
+  batch_request *external_preq;
+  batch_request *cray_preq;
+  
+  unlock_ji_mutex(pjob, __func__, NULL, 0);
+  lock_ji_mutex(external_clone, __func__, NULL, 0);
+  lock_ji_mutex(cray_clone, __func__, NULL, 0);
+  
+  /* clone the batch requests to avoid double frees */
+  external_preq = duplicate_request(preq);
+  cray_preq     = duplicate_request(preq);
+  
+  /* client doesn't need a response from these */
+  external_preq->rq_noreply = TRUE;
+  cray_preq->rq_noreply     = TRUE;
+  
+  if ((rc = send_job_to_mom(&external_clone, external_preq, pjob)) == PBSE_NONE)
+    {
+    if ((rc = send_job_to_mom(&cray_clone, cray_preq, pjob)) != PBSE_NONE)
+      {
+      /* requeue the external job */
+      requeue_job(external_clone);
+      }
+    else
+      both_running = TRUE;
+    }
+  else
+    free_br(cray_preq);
+  
+  if (cray_clone != NULL)
+    unlock_ji_mutex(cray_clone, __func__, NULL, 0);
+  
+  if (external_clone != NULL)
+    unlock_ji_mutex(external_clone, __func__, NULL, 0);
+  
+  lock_ji_mutex(pjob, __func__, NULL, 0);
+  
+  if (both_running == TRUE)
+    {
+    svr_setjobstate(pjob, JOB_STATE_RUNNING, JOB_SUBSTATE_RUNNING, FALSE);
+    reply_ack(preq);
+    }
+  else
+    {
+    req_reject(rc, 0, preq, NULL, NULL);
+    }
+
+  return(rc);
+  } /* END handle_heterogenenous_job_launch() */
+
+
+
+
 /* PATH
     req_runjob()
  >    svr_startjob()
@@ -1082,20 +1280,11 @@ static int svr_strtjob2(
 
   {
   job             *pjob = *pjob_ptr;
-  int              old_state;
-  int              old_subst;
-  int              my_err = 0;
   pbs_attribute   *pattr;
-  char             tmpLine[MAXLINE];
   struct timeval   start_time;
   struct timezone  tz;
-  long             job_timeout = 0;
-  long             tcp_timeout = 0;
-  unsigned long    job_momaddr = -1;
-  char             job_id[PBS_MAXSVRJOBID+1];
-
-  old_state = pjob->ji_qs.ji_state;
-  old_subst = pjob->ji_qs.ji_substate;
+  int              rc = PBSE_NONE;
+  long             cray_enabled = FALSE;
 
   pattr = &pjob->ji_wattr[JOB_ATR_start_time];
 
@@ -1118,52 +1307,16 @@ static int svr_strtjob2(
     pattr->at_val.at_timeval.tv_usec = start_time.tv_usec;
     }
 
+  get_svr_attr_l(SRV_ATR_CrayEnabled, &cray_enabled);
 
-  /* send the job to MOM */
-
-  svr_setjobstate(pjob,JOB_STATE_RUNNING,JOB_SUBSTATE_PRERUN, FALSE);
-
-  /* if job start timeout pbs_attribute is set use its value */
-  get_svr_attr_l(SRV_ATR_tcp_timeout, &tcp_timeout);
-  
-  if ((get_svr_attr_l(SRV_ATR_JobStartTimeout, &job_timeout) == PBSE_NONE) &&
-      (job_timeout > 0))
-    {
-    DIS_tcp_settimeout(job_timeout);
-    }
-  job_momaddr = pjob->ji_qs.ji_un.ji_exect.ji_momaddr;
-  strcpy(job_id, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
-  *pjob_ptr = NULL;
-  pjob = NULL;
-
-  if (send_job_work(job_id, NULL, MOVE_TYPE_Exec, &my_err, preq) == PBSE_NONE)
-    {
-    /* SUCCESS */
-    DIS_tcp_settimeout(tcp_timeout);
-    if ((pjob = find_job(job_id)) != NULL)
-      {
-      *pjob_ptr = pjob;
-      }
-
-    return(PBSE_NONE);
-    }
+  /* check if this is a special heterogeneous job */
+  if ((cray_enabled == TRUE) &&
+      (pjob->ji_external_clone != NULL))
+    rc = handle_heterogeneous_job_launch(pjob, preq);
   else
-    {
-    DIS_tcp_settimeout(tcp_timeout);
+    rc = send_job_to_mom(&pjob, preq, NULL);
 
-    if ((pjob = find_job(job_id)) != NULL)
-      {
-      sprintf(tmpLine, "unable to run job, send to MOM '%lu' failed", job_momaddr);
-      log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,job_id,tmpLine);
-      *pjob_ptr = pjob;
-      pjob->ji_qs.ji_destin[0] = '\0';
-      
-      svr_setjobstate(pjob, old_state, old_subst, FALSE);
-      }
-    
-    return(my_err);
-    }
+  return(rc);
   }    /* END svr_strtjob2() */
 
 
@@ -1187,7 +1340,7 @@ void finish_sendmom(
   time_t     time_now = time(NULL);
   job *pjob;
 
-  if ((pjob = find_job(job_id)) == NULL)
+  if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
     {
     req_reject(PBSE_JOBNOTFOUND, 0, preq, node_name, log_buf);
     return;
@@ -1233,6 +1386,12 @@ void finish_sendmom(
         /* above saves job structure */
         }
       
+      if ((pjob->ji_wattr[JOB_ATR_restart_name].at_flags & ATR_VFLAG_SET) == 0)
+        {
+        pjob->ji_wattr[JOB_ATR_start_time].at_val.at_long = time(NULL);
+        pjob->ji_wattr[JOB_ATR_start_time].at_flags |= ATR_VFLAG_SET;
+        }
+      
       /* accounting log for start or restart */
       if (pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHECKPOINT_FILE)
         account_record(PBS_ACCT_RESTRT, pjob, "Restart from checkpoint");
@@ -1335,9 +1494,9 @@ void finish_sendmom(
           pjob->ji_momstat = 0;
           
           /* update mom-based job status */
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
           stat_mom_job(job_id);
-          pjob = find_job(job_id);
+          pjob = svr_find_job(job_id, TRUE);
           }
         else
           {
@@ -1356,7 +1515,7 @@ void finish_sendmom(
       break;
       }
     }  /* END switch (status) */
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
 
   } /* END finish_sendmom() */
 
@@ -1406,7 +1565,7 @@ static job *chk_job_torun(
 
     req_reject(PBSE_BADSTATE, 0, preq, NULL, "job already running");
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     return(NULL);
     }
@@ -1419,7 +1578,7 @@ static job *chk_job_torun(
 
       req_reject(PBSE_BADSTATE, 0, preq, NULL, NULL);
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
       return(NULL);
       }
@@ -1431,7 +1590,7 @@ static job *chk_job_torun(
 
     req_reject(PBSE_PERM, 0, preq, NULL, NULL);
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
 
     return(NULL);
     }
@@ -1446,7 +1605,7 @@ static job *chk_job_torun(
       req_reject(PBSE_IVALREQ, 0, preq, NULL, "job not in execution queue");
   
       unlock_queue(pque, __func__, NULL, LOGLEVEL);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
   
       return(NULL);
       }
@@ -1475,7 +1634,7 @@ static job *chk_job_torun(
       if ((exec_host = strdup(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str)) == NULL)
         {
         req_reject(PBSE_RMSYSTEM, 0, preq, NULL, "Cannot allocate memory");
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
         return(NULL);
         }
 
@@ -1492,7 +1651,7 @@ static job *chk_job_torun(
         else
           req_reject(PBSE_EXECTHERE, 0, preq, NULL, "allocated nodes must match input file stagein location");
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "6", LOGLEVEL);
         
         return(NULL);
         }
@@ -1513,7 +1672,7 @@ static job *chk_job_torun(
         {
         req_reject(PBSE_EXECTHERE, 0, preq, FailHost, EMsg);
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "7", LOGLEVEL);
         
         return(NULL);
         }
@@ -1549,7 +1708,7 @@ static job *chk_job_torun(
 
       req_reject(rc, 0, preq, FailHost, EMsg);
 
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "8", LOGLEVEL);
 
       return(NULL);
       }
@@ -2001,7 +2160,17 @@ static int assign_hosts(
     
     free(tmp);
 
-    rc = set_job_exec_info(pjob, pjob->ji_qs.ji_destin);
+    if ((cray_enabled == TRUE) &&
+        (pjob->ji_wattr[JOB_ATR_external_nodes].at_val.at_str != NULL))
+      {
+      split_job(pjob);
+      rc = set_job_exec_info(pjob->ji_external_clone, pjob->ji_external_clone->ji_qs.ji_destin);
+      rc = set_job_exec_info(pjob->ji_cray_clone, pjob->ji_qs.ji_destin);
+      }
+    else
+      {
+      rc = set_job_exec_info(pjob, pjob->ji_qs.ji_destin);
+      }
 
     if (rc != 0)
       {
