@@ -120,7 +120,7 @@
 #include "svr_func.h" /* get_svr_attr_* */
 #include "alps_functions.h"
 #include "node_manager.h" /* tfind_addr */
-
+#include "ji_mutex.h"
 
 /* Global Data Items: */
 
@@ -247,14 +247,14 @@ int req_stat_job(
       {
       type = tjstJob;
 
-      if ((pjob = find_job(name)) == NULL)
+      if ((pjob = svr_find_job(name, FALSE)) == NULL)
         {
         rc = PBSE_UNKJOBID;
         }
       }
    
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     }
   else if (isalpha(name[0]))
     {
@@ -395,6 +395,12 @@ static void req_stat_job_step2(
 
   /* See pbs_server_attributes(1B) for details on "poll_jobs" behaviour */
 
+  if (LOGLEVEL >= 7)
+    {
+    sprintf(log_buf, "note");
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   if (dpal == NULL)
     {
     /* build 'delta' pbs_attribute list */
@@ -451,7 +457,7 @@ static void req_stat_job_step2(
     if (cntl->sc_jobid[0] == '\0')
       pjob = NULL;
     else
-      pjob = find_job(cntl->sc_jobid);
+      pjob = svr_find_job(cntl->sc_jobid, FALSE);
 
     while (1)
       {
@@ -461,7 +467,7 @@ static void req_stat_job_step2(
 
         if (type == tjstJob)
           {
-          pjob = find_job(preq->rq_ind.rq_status.rq_id);
+          pjob = svr_find_job(preq->rq_ind.rq_status.rq_id, FALSE);
           }
         else if (type == tjstQueue)
           {
@@ -475,9 +481,9 @@ static void req_stat_job_step2(
             {
             if (pa->job_ids[job_array_index] != NULL)
               {
-              if ((pjob = find_job(pa->job_ids[job_array_index])) != NULL)
+              if ((pjob = svr_find_job(pa->job_ids[job_array_index], FALSE)) != NULL)
                 {
-                pthread_mutex_unlock(pjob->ji_mutex);
+                unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
                 break;
                 }
               }
@@ -494,7 +500,7 @@ static void req_stat_job_step2(
       else
         {
         strcpy(job_id, pjob->ji_qs.ji_jobid);
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
 
         if (type == tjstJob)
           break;
@@ -509,9 +515,9 @@ static void req_stat_job_step2(
             {
             if (pa->job_ids[job_array_index] != NULL)
               {
-              if ((pjob = find_job(pa->job_ids[job_array_index])) != NULL)
+              if ((pjob = svr_find_job(pa->job_ids[job_array_index], FALSE)) != NULL)
                 {
-                pthread_mutex_unlock(pjob->ji_mutex);
+                unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
                 break;
                 }
               }
@@ -529,7 +535,7 @@ static void req_stat_job_step2(
       job_substate = pjob->ji_qs.ji_substate;
       job_momstattime = pjob->ji_momstat;
       strcpy(cntl->sc_jobid, job_id);
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
       pjob = NULL;
 
       /* PBS_RESTAT_JOB defaults to 30 seconds */
@@ -542,7 +548,7 @@ static void req_stat_job_step2(
 
         if (rc != 0)
           {
-          pjob = find_job(job_id);
+          pjob = svr_find_job(job_id, FALSE);
 
           rc = 0;
 
@@ -591,7 +597,7 @@ static void req_stat_job_step2(
     }
 
   if (type == tjstJob)
-    pjob = find_job(preq->rq_ind.rq_status.rq_id);
+    pjob = svr_find_job(preq->rq_ind.rq_status.rq_id, FALSE);
 
   else if (type == tjstQueue)
     pjob = next_job(cntl->sc_pque->qu_jobs,&iter);
@@ -611,7 +617,7 @@ static void req_stat_job_step2(
       {
       if (pa->job_ids[job_array_index] != NULL)
         {
-        if ((pjob = find_job(pa->job_ids[job_array_index])) != NULL)
+        if ((pjob = svr_find_job(pa->job_ids[job_array_index], FALSE)) != NULL)
           {
           break;
           }
@@ -687,7 +693,7 @@ static void req_stat_job_step2(
 
       /* loop through jobs in queue */
       if (pjob != NULL)
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
 
       iter = -1;
 
@@ -697,7 +703,7 @@ static void req_stat_job_step2(
             (pjob->ji_qs.ji_state == JOB_STATE_QUEUED))
           {
           /* max_report of queued jobs reached for queue */
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "6", LOGLEVEL);
 
           continue;
           }
@@ -724,7 +730,7 @@ static void req_stat_job_step2(
               log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
               }
             }
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "7", LOGLEVEL);
           unlock_queue(pque, "req_stat_job_step2", "perm", LOGLEVEL);
           return;
           }
@@ -734,7 +740,7 @@ static void req_stat_job_step2(
         if (pjob->ji_qs.ji_state == JOB_STATE_QUEUED)
           qjcounter++;
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "8", LOGLEVEL);
         }    /* END foreach (pjob from pque) */
 
       if (LOGLEVEL >= 5)
@@ -776,7 +782,11 @@ static void req_stat_job_step2(
         }
       else
         {
+        if (pa != NULL)
+          pthread_mutex_unlock(pa->ai_mutex);
         pque = get_jobs_queue(&pjob);
+        if (pa != NULL)
+          pthread_mutex_lock(pa->ai_mutex);
 
         if ((pjob == NULL) ||
             (pque == NULL))
@@ -814,7 +824,7 @@ static void req_stat_job_step2(
           log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
           }
         }
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "9", LOGLEVEL);
 
       req_reject(rc, bad, preq, NULL, NULL);
 
@@ -826,7 +836,7 @@ static void req_stat_job_step2(
 nextjob:
 
     if (pjob != NULL)
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "10", LOGLEVEL);
 
     if (type == tjstJob)
       break;
@@ -845,7 +855,7 @@ nextjob:
         {
         if (pa->job_ids[job_array_index] != NULL)
           {
-          if ((pjob = find_job(pa->job_ids[job_array_index])) != NULL)
+          if ((pjob = svr_find_job(pa->job_ids[job_array_index], FALSE)) != NULL)
             {
             break;
             }
@@ -913,13 +923,13 @@ int stat_to_mom(
   char *job_momname = NULL;
   job *pjob = NULL;
 
-  if ((pjob = find_job(job_id)) == NULL)
+  if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
     return PBSE_JOBNOTFOUND;
 
   job_momaddr = pjob->ji_qs.ji_un.ji_exect.ji_momaddr;
   job_momport = pjob->ji_qs.ji_un.ji_exect.ji_momport;
   job_momname = strdup(pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
   if (job_momname == NULL)
     return PBSE_MEM_MALLOC;
@@ -996,8 +1006,10 @@ int stat_to_mom(
  */
 
 void stat_update(
-    struct batch_request *preq,
-    struct stat_cntl *cntl)
+    
+  struct batch_request *preq,
+  struct stat_cntl     *cntl)
+
   {
   job                  *pjob;
   struct batch_reply   *preply;
@@ -1015,7 +1027,7 @@ void stat_update(
 
     while (pstatus != NULL)
       {
-      if ((pjob = find_job(pstatus->brp_objname)) != NULL)
+      if ((pjob = svr_find_job(pstatus->brp_objname, FALSE)) != NULL)
         {
         sattrl = (svrattrl *)GET_NEXT(pstatus->brp_attr);
 
@@ -1047,7 +1059,7 @@ void stat_update(
 
         pjob->ji_momstat = time_now;
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         }
 
       pstatus = (struct brp_status *)GET_NEXT(pstatus->brp_stlink);
@@ -1059,7 +1071,7 @@ void stat_update(
       {
       /* we sent a stat request, but mom says it doesn't know anything about
          the job */
-      if ((pjob = find_job(preq->rq_ind.rq_status.rq_id)) != NULL)
+      if ((pjob = svr_find_job(preq->rq_ind.rq_status.rq_id, FALSE)) != NULL)
         {
         /* job really isn't running any more - mom doesn't know anything about it
            this can happen if a diskless node reboots and the mom_priv/jobs
@@ -1150,12 +1162,12 @@ void poll_job_task(
 
   if (job_id != NULL)
     {
-    pjob  = find_job(job_id);
+    pjob  = svr_find_job(job_id, FALSE);
     
     if (pjob != NULL)
       {
       job_state = pjob->ji_qs.ji_state;
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       get_svr_attr_l(SRV_ATR_PollJobs, &poll_jobs);
       if ((poll_jobs) && (job_state == JOB_STATE_RUNNING))
         {
@@ -1218,6 +1230,15 @@ int req_stat_que(
       }
     }
 
+  if (LOGLEVEL >= 7)
+    {
+    if (type == 1)
+      sprintf(log_buf, "no name");
+    else
+      sprintf(log_buf, "%s", name);
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   preply = &preq->rq_reply;
 
   preply->brp_choice = BATCH_REPLY_CHOICE_Status;
@@ -1519,7 +1540,7 @@ int req_stat_node(
       }
     }
 
-  if (!rc)
+  if (rc == PBSE_NONE)
     {
     /* SUCCESS */
 
