@@ -123,7 +123,6 @@ extern pthread_mutex_t *scheduler_sock_jobct_mutex;
 /* Functions private to this file */
 
 static int  put_4byte(int sock, unsigned int val);
-static void scheduler_close(int);
 static void listener_close(int);
 
 
@@ -159,51 +158,47 @@ const char *PSchedCmdType[] =
  * contact_sched - open connection to the scheduler and send it a command
  */
 
-static int contact_sched(
+void *contact_sched(
 
-  int cmd)  /* I */
+  void *new_cmd)  /* I */
 
   {
-  int sock;
+  int   sock;
 
   char  tmpLine[1024];
   char  EMsg[1024];
 
-  char *id = "contact_sched";
   char  log_buf[LOCAL_LOG_BUF_SIZE];
+  int cmd = *(int *)new_cmd;
+
+  free(new_cmd);
 
   /* connect to the Scheduler */
   sock = client_to_svr(pbs_scheduler_addr, pbs_scheduler_port, 1, EMsg);
 
   if (sock < 0)
     {
-    /* FAILURE */
+    /* Thread exit */
 
-#if 0
-    sprintf(tmpLine, "%s - port %d %s",
-            msg_sched_nocall,
-            pbs_scheduler_port,
-            EMsg);
-
-    log_ext(errno,id,tmpLine,LOG_ALERT);
-#endif
-
-    return(-1);
+    return(NULL);
     }
-  add_conn(
+
+  add_scheduler_conn(
     sock,
     FromClientDIS,
     pbs_scheduler_addr,
     pbs_scheduler_port,
     PBS_SOCK_INET,
-    process_pbs_server_port_scheduler);
+    NULL);
+
+  pthread_mutex_lock(scheduler_sock_jobct_mutex);
+  scheduler_sock = sock;
+  pthread_mutex_unlock(scheduler_sock_jobct_mutex);
 
   pthread_mutex_lock(svr_conn[sock].cn_mutex);
   svr_conn[sock].cn_authen = PBS_NET_CONN_FROM_PRIVIL;
   pthread_mutex_unlock(svr_conn[sock].cn_mutex);
 
-  net_add_close_func(sock, scheduler_close);
-
   /* send command to Scheduler */
 
   if (put_4byte(sock, cmd) < 0)
@@ -212,18 +207,28 @@ static int contact_sched(
             msg_sched_nocall,
             pbs_scheduler_port);
 
-    log_ext(errno,id,tmpLine,LOG_ALERT);
+    log_ext(errno, __func__, tmpLine, LOG_ALERT);
 
     close_conn(sock, FALSE);
 
-    return(-1);
+    /* Thread exit */
+    return(NULL);
     }
-    
+
+  /*
+   * call process_pbs_server_port_scheduler which will
+   * handle 1 or more batch requests that may be received
+   * from the scheduler.
+   */
+
+  process_pbs_server_port_scheduler(&sock);
+
   sprintf(log_buf, msg_sched_called, (cmd != SCH_ERROR) ? PSchedCmdType[cmd] : "ERROR");
 
   log_event(PBSEVENT_SCHED,PBS_EVENTCLASS_SERVER,server_name,log_buf);
 
-  return (sock);
+  /* Thread exit */
+  return(NULL);
   }  /* END contact_sched() */
 
 
@@ -246,6 +251,9 @@ int schedule_jobs(void)
 
   static int first_time = 1;
   int tmp_sched_sock = -1;
+  pthread_t tid;
+  pthread_attr_t t_attr;
+  int   *new_cmd = NULL;
 
   pthread_mutex_lock(svr_do_schedule_mutex);
 
@@ -266,15 +274,36 @@ int schedule_jobs(void)
     tmp_sched_sock = scheduler_sock;
   pthread_mutex_unlock(scheduler_sock_jobct_mutex);
 
-  if (tmp_sched_sock != -1)
+  if (tmp_sched_sock == -1)
     {
-    if ((tmp_sched_sock = contact_sched(cmd)) < 0)
+    if (pthread_attr_init(&t_attr) != 0)
       {
-      return(-1);
+      /* Can not init thread attribute structure */
+      perror("could not create listener thread for scheduler");
+      log_err(-1, __func__, "Failed to create listener thread for scheduler");
       }
-    pthread_mutex_lock(scheduler_sock_jobct_mutex);
-    scheduler_sock = tmp_sched_sock;
-    pthread_mutex_unlock(scheduler_sock_jobct_mutex);
+    else if (pthread_attr_setdetachstate(&t_attr, PTHREAD_CREATE_DETACHED) != 0)
+      {
+      /* Can not set thread initial state as detached */
+      pthread_attr_destroy(&t_attr);
+      perror("could not detach listener thread for scheduler");
+      log_err(-1, __func__, "Failed to detach listener thread for scheduler");
+      }
+    else
+      {
+      new_cmd = (int *)calloc(1, sizeof(int));
+      *new_cmd = cmd;
+
+      if (pthread_create(&tid, &t_attr, contact_sched, (void *)new_cmd)
+   != 0)
+        {
+        perror("could not start listener thread for scheduler");
+        log_err(-1, __func__, "Failed to start listener thread for scheduler");
+      return(-1);
+        }
+      }
+
+    pthread_attr_destroy(&t_attr);
 
     first_time = 0;
 
@@ -305,12 +334,11 @@ static int contact_listener(
   int l_idx)  /* I */
 
   {
-  int sock;
+  int   sock;
 
   char  tmpLine[1024];
   char  EMsg[1024];
 
-  char *id = "contact_listener";
   char  log_buf[LOCAL_LOG_BUF_SIZE];
 
   /* If this is the first time contacting the scheduler for
@@ -321,7 +349,7 @@ static int contact_listener(
     listener_command = SCH_SCHEDULE_FIRST;
     pthread_mutex_unlock(listener_command_mutex);
     }
- 
+
   /* connect to the Listener */
   sock = client_to_svr(listener_conns[l_idx].address,
                        listener_conns[l_idx].port, 1, EMsg);
@@ -340,7 +368,7 @@ static int contact_listener(
 
     /* we lost contact with the scheduler. reset*/
     listener_conns[l_idx].first_time = 1;
-    log_err(errno, id, tmpLine);
+    log_err(errno, __func__, tmpLine);
 
     return(-1);
     }
@@ -367,16 +395,16 @@ static int contact_listener(
   if (put_4byte(sock, listener_command) < 0)
     {
     pthread_mutex_unlock(listener_command_mutex);
-    
+
     sprintf(tmpLine, "%s %d - port %d",
             msg_listnr_nocall,
             l_idx + 1,
             listener_conns[l_idx].port);
 
-    log_err(errno, id, tmpLine);
+    log_err(errno, __func__, tmpLine);
 
     close_conn(sock, FALSE);
-  
+
 
     return(-1);
     }
@@ -429,10 +457,7 @@ void notify_listeners(void)
 /*
  * scheduler_close - connection to scheduler has closed, clear scheduler_called
  */
-
-static void scheduler_close(
-
-  int sock)
+void scheduler_close()
 
   {
   pthread_mutex_lock(scheduler_sock_jobct_mutex);
@@ -460,7 +485,7 @@ static void scheduler_close(
     listener_command = SCH_SCHEDULE_RECYC;
     pthread_mutex_unlock(listener_command_mutex);
     }
-    
+
   pthread_mutex_unlock(scheduler_sock_jobct_mutex);
 
   return;
