@@ -99,9 +99,11 @@
 #include "utils.h"
 #include "svr_func.h" /* get_svr_attr_* */
 #include "net_cache.h"
+#include "ji_mutex.h"
 
 /* Global Data */
 
+extern int    LOGLEVEL;
 extern struct credential conn_credent[PBS_NET_MAX_CONNECTIONS];
 extern char *pbs_o_host;
 extern char  server_host[];
@@ -436,8 +438,8 @@ int authenticate_user(
     {
     struct sockaddr_in *sai1;
     struct sockaddr_in *sai2;
-    struct addrinfo    *addr_info1;
-    struct addrinfo    *addr_info2;
+    struct addrinfo    *addr_info1 = NULL;
+    struct addrinfo    *addr_info2 = NULL;
 
     sai1 = get_cached_addrinfo(preq->rq_host);
     sai2 = get_cached_addrinfo(pcred->hostname);
@@ -573,7 +575,7 @@ void chk_job_req_permissions(
 
     req_reject(PBSE_PERM, 0, preq, NULL, "operation not permitted");
 
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     *pjob_ptr = NULL;
     }
@@ -606,7 +608,7 @@ void chk_job_req_permissions(
 
         req_reject(PBSE_BADSTATE, 0, preq, NULL, tmpLine);
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
         *pjob_ptr = NULL;
 
@@ -637,7 +639,7 @@ job *chk_job_request(
   {
   job *pjob = NULL;
 
-  if ((pjob = find_job(jobid)) == NULL)
+  if ((pjob = svr_find_job(jobid, FALSE)) == NULL)
     {
     log_event(
       PBSEVENT_DEBUG,
