@@ -137,7 +137,10 @@
 #include "array.h"
 #include "queue_func.h" /* find_queuebyname */
 #include "../lib/Libutils/u_lock_ctl.h" /* *startup */
+#include "ji_mutex.h"
+#include "user_info.h"
 
+#define MSG_LEN_LONG 160
 
 /* Private Functions */
 
@@ -174,7 +177,6 @@ extern int  svr_clnodes;
 extern int node_avail_complex(char *, int *, int *, int *, int *);
 extern int procs_available(int proc_ct);
 extern int procs_requested(char *spec);
-extern int remove_procct(job *);
 
 /* Private Functions */
 
@@ -307,7 +309,7 @@ int svr_enquejob(
   /* make sure queue is still there, there exists a small window ... */
   strcpy(job_id, pjob->ji_qs.ji_jobid);
   strcpy(queue_name, pjob->ji_qs.ji_queue);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
   pque = find_queuebyname(queue_name);
 
   if (pque == NULL)
@@ -316,13 +318,13 @@ int svr_enquejob(
     }
 
   /* This is called when a job is not yet in the queue,
-   * so find_job can not be used.... */
-  pthread_mutex_lock(pjob->ji_mutex);
+   * so svr_find_job can not be used.... */
+  lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
   if (pjob->ji_being_recycled == TRUE)
     {
     unlock_queue(pque, __func__, NULL, 0);
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
     return(PBSE_JOB_RECYCLED);
     }
 
@@ -382,42 +384,50 @@ int svr_enquejob(
     /* we have to unlock the job because next_job_from_back may 
        give us this job */
     job_qrank = pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long;
-    pthread_mutex_unlock(pjob->ji_mutex);
-    while ((pjcur = next_job_from_back(pque->qu_jobs,&iter)) != NULL)
+    unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
+
+    while ((pjcur = next_job_from_back(pque->qu_jobs, &iter)) != NULL)
       {
       if (job_qrank > pjcur->ji_wattr[JOB_ATR_qrank].at_val.at_long)
         {
-        pthread_mutex_unlock(pjcur->ji_mutex);
+        unlock_ji_mutex(pjcur, __func__, "5", LOGLEVEL);
         break;
         }
+
       if (strcmp(job_id, pjcur->ji_qs.ji_jobid) == 0)
         {
-        pthread_mutex_unlock(pjcur->ji_mutex);
+        unlock_ji_mutex(pjcur, __func__, "6", LOGLEVEL);
         unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
-        return PBSE_NONE;
+        return(PBSE_NONE);
         }
-      pthread_mutex_unlock(pjcur->ji_mutex);
+
+      unlock_ji_mutex(pjcur, __func__, "7", LOGLEVEL);
       }
-    if ((pjob = find_job(job_id)) == NULL)
+
+    if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
       {
       unlock_queue(pque, __func__, "array_template check lost job", LOGLEVEL);
       return(PBSE_JOBNOTFOUND);
       }
+
     if (pjcur == NULL)
       {
       /* link first in list */
-      insert_job_first(pque->qu_jobs,pjob);
+      insert_job_first(pque->qu_jobs, pjob);
       }
     else
       {
       /* link after 'current' job in list */
-      insert_job_after(pque->qu_jobs,pjcur,pjob);
-      pthread_mutex_unlock(pjcur->ji_mutex);
+      insert_job_after(pque->qu_jobs, pjcur, pjob);
+      unlock_ji_mutex(pjcur, __func__, "8", LOGLEVEL);
       }
 
     /* update counts: queue and queue by state */
     pque->qu_numjobs++;
     pque->qu_njstate[pjob->ji_qs.ji_state]++;
+    
+    /* increment this user's job count for this queue */
+    increment_queued_jobs(pque->qu_uih, pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str, pjob);
     }
 
   if (pjob->ji_is_array_template || pjob->ji_arraystruct == NULL)
@@ -425,27 +435,32 @@ int svr_enquejob(
     iter = -1;
 
     job_qrank = pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long;
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "9", LOGLEVEL);
+
     while ((pjcur = next_job_from_back(pque->qu_jobs_array_sum,&iter)) != NULL)
       {
       if (job_qrank > pjcur->ji_wattr[JOB_ATR_qrank].at_val.at_long)
         {
-        pthread_mutex_unlock(pjcur->ji_mutex);
+        unlock_ji_mutex(pjcur, __func__, "10", LOGLEVEL);
         break;
         }
+
       if (strcmp(job_id, pjcur->ji_qs.ji_jobid) == 0)
         {
-        pthread_mutex_unlock(pjcur->ji_mutex);
+        unlock_ji_mutex(pjcur, __func__, "11", LOGLEVEL);
         unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
         return PBSE_NONE;
         }
-      pthread_mutex_unlock(pjcur->ji_mutex);
+
+      unlock_ji_mutex(pjcur, __func__, "12", LOGLEVEL);
       } /* end of while */
-    if ((pjob = find_job(job_id)) == NULL)
+
+    if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
       {
       unlock_queue(pque, __func__, "array_template check lost job", LOGLEVEL);
       return(PBSE_JOBNOTFOUND);
       }
+
     if (pjcur == NULL)
       {
       /* link first in list */
@@ -456,7 +471,7 @@ int svr_enquejob(
       /* link after 'current' job in list */
       insert_job_after(pque->qu_jobs_array_sum,pjcur,pjob);
 
-      pthread_mutex_unlock(pjcur->ji_mutex);
+      unlock_ji_mutex(pjcur, __func__, "13", LOGLEVEL);
       }
     }
 
@@ -531,7 +546,7 @@ int svr_enquejob(
                               pjob,
                               ATR_ACTION_NOOP)) != 0)
         {
-        return(rc);
+        return(PBSE_BADDEPEND);
         }
       }
 
@@ -591,9 +606,13 @@ int svr_dequejob(
 
   /* remove job from server's all job list and reduce server counts */
 
-  if ((pjob = find_job(job_id)) == NULL)
+  if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
     return(PBSE_JOBNOTFOUND);
 
+
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+
   if (parent_queue_mutex_held == FALSE)
     {
     pque = get_jobs_queue(&pjob);
@@ -601,7 +620,7 @@ int svr_dequejob(
     if ((pjob == NULL) ||
         (pque == NULL))
       {
-      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 10");
       return(PBSE_JOBNOTFOUND);
       }
     }
@@ -630,6 +649,11 @@ int svr_dequejob(
         log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_JOB, __func__, "qu_numcompleted < 0. Recount required.");
         bad_ct = 1;
         }
+
+      if (pjob->ji_is_array_template == FALSE)
+        {
+        decrement_queued_jobs(pque->qu_uih, pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
+        }
       }
     else if (rc == PBSE_JOB_RECYCLED)
       {
@@ -658,8 +682,30 @@ int svr_dequejob(
   log_event(PBSEVENT_DEBUG2,PBS_EVENTCLASS_JOB,job_id,log_buf);
 
   if (bad_ct)   /* state counts are all messed up */
+    {
+    char queue_name[PBS_MAXQUEUENAME];
+
+    /* this function will lock queues and jobs */
+    unlock_ji_mutex(pjob, __func__, NULL, 0);
+
+    if (parent_queue_mutex_held == TRUE)
+      {
+      strcpy(queue_name, pque->qu_qs.qu_name);
+      unlock_queue(pque, __func__, NULL, LOGLEVEL);
+      }
+
     correct_ct();
 
+    /* lock queue then job */
+    if (parent_queue_mutex_held == TRUE)
+      {
+      pque = find_queuebyname(queue_name);
+      }
+
+    if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
+      return(PBSE_JOBNOTFOUND);
+    }
+
 #endif /* NDEBUG */
 
   pjob->ji_wattr[JOB_ATR_qtime].at_flags &= ~ATR_VFLAG_SET;
@@ -798,7 +844,7 @@ int svr_setjobstate(
 
         if (pjob == NULL)
           {
-          log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+          log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 11");
           return(PBSE_JOBNOTFOUND);
           }
         }
@@ -1472,74 +1518,12 @@ int count_queued_jobs(
   char      *user) /* I */
 
   {
-  job       *pj;
+  int num_jobs = 0;
 
-  int        num_jobs = 0;
-  int        i;
-  int        iter = -1;
-  int        num_arrays = 0;
-  job_array *arrays[PBS_MAXJOBARRAY];
-
-  if (pque == NULL)
-    {
-    return(-1);
-    }
-
-  while ((pj = next_job(pque->qu_jobs,&iter)) != NULL)
-    {
-    if (pj->ji_qs.ji_state <= JOB_STATE_RUNNING)
-      {
-      if (user != NULL)
-        {
-        if (!strcmp(pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str,user))
-          {
-          num_jobs++;
-          }
-        }
-      else
-        {
-        num_jobs++;
-        }
-      }
-
-    /* record arrays in queue to check later */
-    if (pj->ji_arraystruct != NULL)
-      {
-      int found = FALSE;
-
-      /* make sure to not insert a duplicate */
-      for (i = 0; i < num_arrays; i++)
-        {
-        if (arrays[i] == pj->ji_arraystruct)
-          {
-          found = TRUE;
-
-          pthread_mutex_unlock(pj->ji_mutex);
-
-          break;
-          }
-        }
-
-      if (found == FALSE)
-        {
-        arrays[num_arrays] = pj->ji_arraystruct;
-        num_arrays++;
-        }
-      }
-
-    pthread_mutex_unlock(pj->ji_mutex);
-    }
-
-  /* also count any jobs not yet queued that have already been accepted
-   * into the queue */
-  for (i = 0; i < num_arrays; i++)
-    {
-    pthread_mutex_lock(arrays[i]->ai_mutex);
-
-    num_jobs += (arrays[i]->ai_qs.num_jobs - arrays[i]->ai_qs.num_cloned);
-
-    pthread_mutex_unlock(arrays[i]->ai_mutex);
-    }
+  if (user == NULL)
+    num_jobs = pque->qu_numjobs;
+  else
+    num_jobs = get_num_queued(pque->qu_uih, user);
 
   return(num_jobs);
   } /* END count_queued_jobs */
@@ -1632,6 +1616,9 @@ int svr_chkque(
 
   struct array_strings *pas;
   int j = 0;
+  char jobid[PBS_MAXSVRJOBID+1];
+
+  strcpy(jobid, pjob->ji_qs.ji_jobid);
 
   if (EMsg != NULL)
     EMsg[0] = '\0';
@@ -1940,27 +1927,48 @@ int svr_chkque(
       return(PBSE_QUNOENB);
       }
 
-    if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET) &&
-        ((count_queued_jobs(pque,NULL) + array_jobs) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long))
-      {
-      if (EMsg)
-        snprintf(EMsg, 1024,
-          "total number of jobs in queue exceeds the queue limit: "
-          "user %s, queue %s",
-          pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
-          pque->qu_qs.qu_name);
 
-      return(PBSE_MAXQUED);
+    if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET)) 
+      {
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+      user_jobs = count_queued_jobs(pque, NULL);
+
+      lock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+      if (pjob->ji_being_recycled == TRUE)
+        {
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+        return(PBSE_JOB_RECYCLED);
+        }
+
+      if ((user_jobs + array_jobs) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long)
+        {
+        if (EMsg)
+          snprintf(EMsg, 1024,
+            "total number of jobs in queue exceeds the queue limit: "
+            "user %s, queue %s",
+            pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
+            pque->qu_qs.qu_name);
+
+        return(PBSE_MAXQUED);
+        }
       }
 
     if ((pque->qu_attr[QA_ATR_MaxUserJobs].at_flags & ATR_VFLAG_SET) &&
         (pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long >= 0))
       {
       /* count number of jobs user has in queue */
+      unlock_ji_mutex(pjob, __func__, NULL, 0);
 
       user_jobs = count_queued_jobs(pque,
           pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
 
+      lock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+      if (pjob->ji_being_recycled == TRUE)
+        {
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+        return(PBSE_JOB_RECYCLED);
+        }
+
       if (user_jobs + array_jobs >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
         {
         if (EMsg)
@@ -2123,7 +2131,7 @@ void job_wait_over(
     return;
     }
 
-  pjob = find_job(jobid);
+  pjob = svr_find_job(jobid, TRUE);
   free(jobid);
 
   if (pjob != NULL)
@@ -2142,7 +2150,7 @@ void job_wait_over(
         /* recreate the work task entry */
         set_task(WORK_Timed, when, job_wait_over, strdup(pjob->ji_qs.ji_jobid), FALSE);
         
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         
         return;
         }
@@ -2160,7 +2168,7 @@ void job_wait_over(
     svr_evaljobstate(pjob, &newstate, &newsub, 0);
     svr_setjobstate(pjob, newstate, newsub, FALSE);
     
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
     }
 
   return;
@@ -2501,7 +2509,7 @@ void set_resc_deflt(
     pque = get_jobs_queue(&pjob);
     if (pjob == NULL)
       {
-      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 12");
       return;
       }
     }
@@ -2528,7 +2536,7 @@ void set_resc_deflt(
 #endif
     pthread_mutex_unlock(server.sv_attr_mutex);
 
-    unlock_queue(pque, "set_resc_deflt", NULL, LOGLEVEL);
+    unlock_queue(pque, __func__, NULL, LOGLEVEL);
     }
 
   for (i = 0;i < JOB_ATR_LAST;++i)
@@ -2548,18 +2556,12 @@ void set_resc_deflt(
   
   if ((pque = get_jobs_queue(&pjob)) != NULL)
     {
-    if (pque->qu_qs.qu_type == QTYPE_Execution)
-      {
-      /* unset the procct resource if it has been set */
-      remove_procct(pjob);
-      }
-
     if (has_queue_mutex == FALSE)
-      unlock_queue(pque, "set_resc_deflt", NULL, LOGLEVEL);
+      unlock_queue(pque, __func__, NULL, LOGLEVEL);
     }
   else if (pjob == NULL)
     {
-    log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+    log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 13");
     }
  
   return;
@@ -2785,10 +2787,10 @@ void correct_ct()
       if (pjob->ji_qs.ji_state == JOB_STATE_COMPLETE)
         pque->qu_numcompleted++;
       
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       }
     
-    unlock_queue(pque, "correct_ct", NULL, LOGLEVEL);
+    unlock_queue(pque, __func__, NULL, LOGLEVEL);
     } /* END for each queue */
   
   sprintf(log_buf, "%s:2", __func__);
@@ -2806,7 +2808,81 @@ void correct_ct()
   }  /* END correct_ct() */
 
 
+int lock_ji_mutex(
 
+  job        *pjob,
+  const char *id,
+  char       *msg,
+  int        logging)
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 20)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "locking %s in method %s-%s", pjob->ji_qs.ji_jobid, id, msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_lock(pjob->ji_mutex) != 0)
+    {
+    if (logging >= 20)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock queue %s mutex in method %s",
+                                   pjob->ji_qs.ji_jobid, id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+  if (err_msg != NULL)
+  free(err_msg);
+
+  return rc;
+  }
+
+
+
+int unlock_ji_mutex(
+
+  job        *pjob,
+  const char *id,
+  char       *msg,
+  int        logging)
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 20)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "unlocking %s in method %s-%s", pjob->ji_qs.ji_jobid, id, msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_unlock(pjob->ji_mutex) != 0)
+    {
+    if (logging >= 20)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock queue %s mutex in method %s",
+                                          pjob->ji_qs.ji_jobid, id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+   if (err_msg != NULL)
+     free(err_msg);
+
+   return rc;
+   }
 
 
 #endif  /* NDEBUG */
