@@ -114,7 +114,7 @@
 #include "../lib/Libutils/u_lock_ctl.h" /* unlock_node */
 #include "queue_func.h" /* find_queuebyname */
 #include "req_runjob.h" /* finish_sendmom */
-
+#include "ji_mutex.h"
 
 #if __STDC__ != 1
 #include <memory.h>
@@ -130,7 +130,7 @@
 extern void remove_stagein(job **);
 extern void remove_checkpoint(job **);
 extern int  job_route(job *);
-extern int job_purge(job *);
+extern int svr_job_purge(job *);
 int PBSD_commit_get_sid(int ,long *,char *);
 int get_job_file_path(job *,enum job_file, char *, int);
 
@@ -262,6 +262,7 @@ static int local_move(
   {
   pbs_queue *routing_que;
   pbs_queue *dest_que;
+  pbs_queue *tmp_que;
   char      *destination = pjob->ji_qs.ji_destin;
   int        mtype;
   char       log_buf[LOCAL_LOG_BUF_SIZE];
@@ -278,7 +279,7 @@ static int local_move(
 
     if (pjob == NULL)
       {
-      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue");
+      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 14");
       return(PBSE_JOBNOTFOUND);
       }
     }
@@ -348,7 +349,7 @@ static int local_move(
   /* queue_rank for new queue and enqueue into destination  */
 
   strcpy(job_id, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
   
   /* if we come out of svr_dequejob successfully pjob->ji_mutex will be locked */
   rc = svr_dequejob(job_id, TRUE); 
@@ -368,8 +369,10 @@ static int local_move(
   if (parent_queue_mutex_held == TRUE)
     {
     /* re-lock the routing queue */
-    if ((routing_que = lock_queue_with_job_held(routing_que, &pjob)) == NULL)
+    if ((tmp_que = lock_queue_with_job_held(routing_que, &pjob)) == NULL)
       lock_queue(routing_que, __func__, NULL, 0);
+    else
+      routing_que = tmp_que;
     }
 
   if (*my_err != PBSE_NONE)
@@ -400,6 +403,10 @@ void finish_routing_processing(
   int          newstate;
   int          newsub;
 
+
+  if (LOGLEVEL >= 10)
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+
   switch (status)
     {
     case LOCUTION_SUCCESS:  /* normal return, job was routed */
@@ -413,7 +420,7 @@ void finish_routing_processing(
           remove_checkpoint(&pjob);
 
         if (pjob != NULL)
-          job_purge(pjob); /* need to remove server job struct */
+          svr_job_purge(pjob); /* need to remove server job struct */
         }
 
       break;
@@ -427,7 +434,7 @@ void finish_routing_processing(
         
         svr_mailowner(pjob, 'a', TRUE, "Coudln't route job to remote server");
 
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
         return;
         }
@@ -453,7 +460,7 @@ void finish_routing_processing(
         else if (status != 0)
           job_abt(&pjob, msg_routexceed);
         else
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
         unlock_queue(pque, __func__, NULL, LOGLEVEL);
         }
@@ -514,7 +521,7 @@ void finish_moving_processing(
         req->rq_ind.rq_move.rq_destin, req->rq_user, req->rq_host);
 
       if (pjob != NULL)
-        job_purge(pjob);
+        svr_job_purge(pjob);
     
       reply_ack(req);
 
@@ -530,7 +537,7 @@ void finish_moving_processing(
         svr_evaljobstate(pjob, &newstate, &newsub, 1);
         svr_setjobstate(pjob, newstate, newsub, FALSE);
    
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
         }
 
       req_reject(status, 0, req, NULL, NULL);
@@ -554,7 +561,7 @@ void finish_move_process(
 
   {
   char  log_buf[LOCAL_LOG_BUF_SIZE+1];
-  job  *pjob = find_job(job_id);
+  job  *pjob = svr_find_job(job_id, TRUE);
 
   if (pjob == NULL)
     {
@@ -583,7 +590,7 @@ void finish_move_process(
         break;
         
       case MOVE_TYPE_Exec:
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         pjob = NULL;
         finish_sendmom(job_id, preq, time, node_name, status, mom_err);
         
@@ -591,7 +598,7 @@ void finish_move_process(
       } /* END switch (type) */
     }
   if (pjob != NULL)
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
 
 
   } /* END finish_move_process() */
@@ -666,7 +673,7 @@ int send_job_work(
   unsigned long         job_momaddr = -1;
   unsigned short        job_momport = -1;
 
-  if ((pjob = find_job(job_id)) == NULL)
+  if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
     return(PBSE_JOBNOTFOUND);
 
   if (strlen(pjob->ji_qs.ji_destin) != 0)
@@ -677,7 +684,6 @@ int send_job_work(
   job_momaddr = pjob->ji_qs.ji_un.ji_exect.ji_momaddr;
   job_momport = pjob->ji_qs.ji_un.ji_exect.ji_momport;
 
-
   if (pjob->ji_qs.ji_svrflags & JOB_SVFLG_SCRIPT)
     has_job_script = TRUE;
 
@@ -718,7 +724,7 @@ int send_job_work(
     encode_type = ATR_ENCODE_SVR;
 
     /* clear default resource settings */
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     ret = svr_dequejob(job_id, FALSE);
     if (ret)
       return(ret);
@@ -745,7 +751,7 @@ int send_job_work(
   attrl_fixlink(&attrl);
 
   /* put together the job script file name */
-  if (pjob->ji_wattr[JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET)
+  if (pjob->ji_arraystruct != NULL)
     {
     snprintf(script_name, sizeof(script_name), "%s%s%s",
       path_jobs, pjob->ji_arraystruct->ai_qs.fileprefix, JOB_SCRIPT_SUFFIX);
@@ -762,7 +768,7 @@ int send_job_work(
         (get_job_file_path(pjob ,StdErr, stderr_path, sizeof(stderr_path)) != 0) ||
         (get_job_file_path(pjob, Checkpoint, chkpt_path, sizeof(chkpt_path)) != 0))
       {
-      pthread_mutex_unlock(pjob->ji_mutex);
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       goto send_job_work_end;
       }
     }
@@ -778,7 +784,7 @@ int send_job_work(
       change_substate_on_attempt_to_queue = TRUE;
     }
   
-  pthread_mutex_unlock(pjob->ji_mutex);
+  unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
 
   for (NumRetries = 0;NumRetries < RETRY;NumRetries++)
     {
@@ -831,11 +837,11 @@ int send_job_work(
       {
       if (change_substate_on_attempt_to_queue == TRUE)
         {
-        if ((pjob = find_job(job_id)) != NULL)
+        if ((pjob = svr_find_job(job_id, TRUE)) != NULL)
           {
           pjob->ji_qs.ji_substate = JOB_SUBSTATE_TRNOUT;
           job_save(pjob, SAVEJOB_QUICK, 0);
-          pthread_mutex_unlock(pjob->ji_mutex);
+          unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
           }
         else
           break;
@@ -895,11 +901,11 @@ int send_job_work(
           }
         }
 
-      if ((pjob = find_job(job_id)) != NULL)
+      if ((pjob = svr_find_job(job_id, TRUE)) != NULL)
         {
         pjob->ji_qs.ji_substate = JOB_SUBSTATE_TRNOUTCM;      
         job_save(pjob, SAVEJOB_QUICK, 0);
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "5", LOGLEVEL);
         }
       else
         break;
@@ -973,11 +979,11 @@ int send_job_work(
     else if (sid != -1)
       {
       /* save the sid */
-      if ((pjob = find_job(job_id)) != NULL)
+      if ((pjob = svr_find_job(job_id, TRUE)) != NULL)
         {
         pjob->ji_wattr[JOB_ATR_session_id].at_val.at_long = sid;
         pjob->ji_wattr[JOB_ATR_session_id].at_flags |= ATR_VFLAG_SET;
-        pthread_mutex_unlock(pjob->ji_mutex);
+        unlock_ji_mutex(pjob, __func__, "6", LOGLEVEL);
         }
       else
         {
@@ -1062,12 +1068,12 @@ void *send_job(
   struct batch_request *preq = (struct batch_request *)args->data;
   struct pbsnode       *np;
 
-  pjob = find_job(job_id);
+  pjob = svr_find_job(job_id, TRUE);
 
   if (pjob != NULL)
     {
     job_momaddr = pjob->ji_qs.ji_un.ji_exect.ji_momaddr;
-    pthread_mutex_unlock(pjob->ji_mutex);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
     if (LOGLEVEL >= 6)
       {
@@ -1086,6 +1092,8 @@ void *send_job(
     send_job_work(job_id,node_name,type,&local_errno,preq);
     }
 
+  if (args)
+    free(args);
   return(NULL);
   }  /* END send_job() */
 
