@@ -126,6 +126,8 @@ extern char     *path_priv;
 extern char     *msg_svdbopen;
 extern char     *msg_svdbnosv;
 
+long             recovered_tcp_timeout = 5000;
+extern int       disable_timeout_check;
 
 /**
  * Recover server state from server database.
@@ -141,10 +143,11 @@ int svr_recov(
   int read_only)  /* I */
 
   {
-  int i;
-  int sdb;
+  int  i;
+  int  sdb;
+  char log_buf[LOCAL_LOG_BUF_SIZE];
 
-  void recov_acl(attribute *, attribute_def *, char *, char *);
+  void recov_acl(pbs_attribute *, attribute_def *, char *, char *);
 
   sdb = open(svrfile, O_RDONLY, 0);
 
@@ -168,12 +171,14 @@ int svr_recov(
     }
 
   /* read in server structure */
-  pthread_mutex_lock(server.sv_qs_mutex);
+  lock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
   i = read(sdb, (char *) & server.sv_qs, sizeof(struct server_qs));
 
   if (i != sizeof(struct server_qs))
     {
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
+
     if (i < 0)
       log_err(errno, __func__, "read of serverdb failed");
     else
@@ -198,6 +203,7 @@ int svr_recov(
         0,
         !read_only) != 0 ) 
     {
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
     log_err(errno, __func__, "error on recovering server attr");
 
     close(sdb);
@@ -216,7 +222,7 @@ int svr_recov(
     server.sv_attr[SRV_ATR_NextJobNumber].at_flags |= ATR_VFLAG_SET| ATR_VFLAG_MODIFY;
     }
 
-  pthread_mutex_unlock(server.sv_qs_mutex);
+  unlock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
   close(sdb);
 
@@ -242,7 +248,7 @@ int svr_recov(
       }
     }    /* END for (i) */
 
-  return(0);
+  return(PBSE_NONE);
   }  /* END svr_recov() */
 
 
@@ -304,16 +310,16 @@ int size_to_str(
 /*
  * attr_to_str
  *
- * @param ds - the dynamic string we're printing the attribute into
- * @param aindex - the attribute's index
- * @param attr - the attribute
+ * @param ds - the dynamic string we're printing the pbs_attribute into
+ * @param aindex - the pbs_attribute's index
+ * @param attr - the pbs_attribute
  * @param XML - boolean telling us whether to print XML or not
  */
 int attr_to_str(
 
   dynamic_string   *ds,     /* O */
   attribute_def    *at_def, /* I */
-  struct attribute  attr,   /* I */
+  pbs_attribute     attr,   /* I */
   int               XML)    /* I */
 
   {
@@ -382,7 +388,7 @@ int attr_to_str(
 
     case ATR_TYPE_SIZE:
 
-      rc = size_to_dynamic_string(ds, attr.at_val.at_size);
+      rc = size_to_dynamic_string(ds, &(attr.at_val.at_size));
 
       break;
 
@@ -451,7 +457,7 @@ int attr_to_str(
             append_dynamic_string(ds, current->rs_defin->rs_name);
             append_dynamic_string(ds, ">");
 
-            size_to_dynamic_string(ds, current->rs_value.at_val.at_size);
+            size_to_dynamic_string(ds, &(current->rs_value.at_val.at_size));
 
             append_dynamic_string(ds, "</");
             append_dynamic_string(ds, current->rs_defin->rs_name);
@@ -478,7 +484,7 @@ int attr_to_str(
     case ATR_TYPE_JINFOP:
 
       break;
-    } /* END switch attribute type */
+    } /* END switch pbs_attribute type */
 
   return(rc);
   } /* END attr_to_str */
@@ -486,20 +492,19 @@ int attr_to_str(
 
 
 
-/* converts a string to an attribute 
+/* converts a string to an pbs_attribute 
  * @return PBSE_NONE on success
  */
 
 int str_to_attr(
 
-  char                *name,    /* I */
+  char                 *name,    /* I */
   char                 *val,    /* I */
-  struct attribute     *attr,   /* O */
+  pbs_attribute        *attr,   /* O */
   struct attribute_def *padef)  /* I */
 
   {
   int   index;
-  char *id = "str_to_attr";
   char  buf[MAXLINE<<5];
   char  log_buf[LOCAL_LOG_BUF_SIZE];
 
@@ -507,7 +512,7 @@ int str_to_attr(
       (val  == NULL) ||
       (attr == NULL))
     {
-    log_err(-1,id,"Illegal NULL pointer argument");
+    log_err(-1, __func__, "Illegal NULL pointer argument");
 
     return(-10);
     }
@@ -516,11 +521,11 @@ int str_to_attr(
 
   if (index < 0)
     {
-    /* couldn't find attribute */
+    /* couldn't find pbs_attribute */
     snprintf(log_buf,sizeof(log_buf),
       "Couldn't find attribute %s\n",
       name);
-    log_err(-1,id,log_buf);
+    log_err(-1, __func__, log_buf);
 
     return(ATTR_NOT_FOUND);
     }
@@ -531,6 +536,9 @@ int str_to_attr(
 
       attr[index].at_val.at_long = atol(val);
 
+      if (index == SRV_ATR_tcp_timeout)
+        recovered_tcp_timeout = attr[index].at_val.at_long;
+
       break;
 
     case ATR_TYPE_CHAR:
@@ -547,7 +555,7 @@ int str_to_attr(
 
       if (attr[index].at_val.at_str == NULL)
         {
-        log_err(PBSE_SYSTEM,id,"Cannot allocate memory\n");
+        log_err(PBSE_SYSTEM, __func__, "Cannot allocate memory\n");
 
         return(PBSE_SYSTEM);
         }
@@ -657,7 +665,7 @@ int str_to_attr(
           
           errFlg = TRUE;
 
-          log_err(rc,id,log_buf);
+          log_err(rc, __func__, log_buf);
           }
         }
 
@@ -675,7 +683,7 @@ int str_to_attr(
     case ATR_TYPE_JINFOP:
 
       break;
-    } /* END switch (attribute type) */
+    } /* END switch (pbs_attribute type) */
 
   attr[index].at_flags |= ATR_VFLAG_SET;
 
@@ -688,7 +696,7 @@ int str_to_attr(
 int svr_recov_xml(
 
   char *svrfile,  /* I */
-  int read_only)  /* I */
+  int   read_only)  /* I */
 
   {
   int   sdb;
@@ -705,8 +713,6 @@ int svr_recov_xml(
   char *end;
   char  log_buf[LOCAL_LOG_BUF_SIZE];
 
-  char *id = "svr_recov_xml";
-
   sdb = open(svrfile, O_RDONLY, 0);
 
   if (sdb < 0)
@@ -717,11 +723,11 @@ int svr_recov_xml(
         "cannot locate server database '%s' - use 'pbs_server -t create' to create new database if database has not been initialized.",
         svrfile);
 
-      log_err(errno, id, log_buf);
+      log_err(errno, __func__, log_buf);
       }
     else
       {
-      log_err(errno, id, msg_svdbopen);
+      log_err(errno, __func__, msg_svdbopen);
       }
 
     return(-1);
@@ -735,7 +741,7 @@ int svr_recov_xml(
       "Unable to read from serverdb file - %s",
       strerror(errno));
 
-    log_err(errno,id,log_buf);
+    log_err(errno, __func__, log_buf);
 
     return(-1);
     }
@@ -750,7 +756,7 @@ int svr_recov_xml(
     /* no server tag - check if this is the old format */
     log_event(PBSEVENT_SYSTEM,
       PBS_EVENTCLASS_SERVER,
-      id,
+      __func__,
       "Cannot find a server tag, attempting to load legacy format\n");
 
     close(sdb);
@@ -763,7 +769,7 @@ int svr_recov_xml(
   if (end == NULL)
     {
     /* no server tag???? */
-    log_err(-1,id,"No server tag found in the database file???");
+    log_err(-1, __func__, "No server tag found in the database file???");
     close(sdb);
 
     return(-1);
@@ -774,7 +780,7 @@ int svr_recov_xml(
   /* adjust end for the newline character preceeding the close server tag */
   end--;
 
-  pthread_mutex_lock(server.sv_qs_mutex);
+  lock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
   while (current < end)
     {
@@ -827,11 +833,14 @@ int svr_recov_xml(
             "Error creating attribute %s",
             child_parent);
 
-          log_err(rc,id,log_buf);
+          log_err(rc, __func__, log_buf);
 
           break;
           }
         }
+
+      if (recovered_tcp_timeout < 300)
+        disable_timeout_check = TRUE;
       }
     else
       {
@@ -850,7 +859,7 @@ int svr_recov_xml(
       ATR_VFLAG_SET| ATR_VFLAG_MODIFY;
     }
 
-  pthread_mutex_unlock(server.sv_qs_mutex);
+  unlock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
   return(PBSE_NONE);
   } /* END svr_recov_xml() */
@@ -874,25 +883,28 @@ int svr_save_xml(
   time_t  time_now = time(NULL);
   char   *tmp_file = NULL;
   int     tmp_file_len = 0;
+  char log_buf[LOCAL_LOG_BUF_SIZE + 1];
 
   tmp_file_len = strlen(path_svrdb) + 5;
   if ((tmp_file = calloc(sizeof(char), tmp_file_len)) == NULL)
     {
     rc = PBSE_MEM_MALLOC;
-    return rc;
+    return(rc);
     }
   else
     {
     snprintf(tmp_file, tmp_file_len - 1, "%s.tmp", path_svrdb);
     }
 
-  pthread_mutex_lock(server.sv_qs_mutex);
+  lock_sv_qs_mutex(server.sv_qs_mutex, __func__);
   fds = open(tmp_file, O_WRONLY | O_CREAT | O_Sync | O_TRUNC, 0600);
 
   if (fds < 0)
     {
-    pthread_mutex_unlock(server.sv_qs_mutex);
+    sprintf(log_buf, "%s:1", __func__);
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
     log_err(errno, __func__, msg_svdbopen);
+
     free(tmp_file);
     return(-1);
     }
@@ -905,19 +917,20 @@ int svr_save_xml(
     ps->sv_qs.sv_jobidnumber,
     time_now);
   
-  
   len = strlen(buf);
 
   if ((rc = write_buffer(buf,len,fds)))
     {
-    pthread_mutex_unlock(server.sv_attr_mutex);
+    sprintf(log_buf, "%s:2", __func__);
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
     free(tmp_file);
     return(rc);
     }
 
   if ((rc = save_attr_xml(svr_attr_def,ps->sv_attr,SRV_ATR_LAST,fds)) != 0)
     {
-    pthread_mutex_unlock(server.sv_attr_mutex);
+    sprintf(log_buf, "%s:3", __func__);
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
     free(tmp_file);
     return(rc);
     }
@@ -926,7 +939,8 @@ int svr_save_xml(
   snprintf(buf,sizeof(buf),"</server_db>");
   if ((rc = write_buffer(buf,strlen(buf),fds)))
     {
-    pthread_mutex_unlock(server.sv_qs_mutex);
+    sprintf(log_buf, "%s:4", __func__);
+    unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
     free(tmp_file);
     return(rc);
     }
@@ -937,10 +951,13 @@ int svr_save_xml(
     {
     rc = PBSE_CAN_NOT_MOVE_FILE;
     }
-  pthread_mutex_unlock(server.sv_qs_mutex);
+
+  sprintf(log_buf, "%s:5", __func__);
+  unlock_sv_qs_mutex(server.sv_qs_mutex, log_buf);
 
   free(tmp_file);
-  return(0);
+
+  return(PBSE_NONE);
   } /* END svr_save_xml */
 
 
@@ -970,17 +987,17 @@ int svr_save(
 /**
  * Save an Access Control List to its file.
  *
- * @param attr   A pointer to an acl (access control list) attribute.
- * @param pdef   A pointer to the attribute definition structure.
+ * @param attr   A pointer to an acl (access control list) pbs_attribute.
+ * @param pdef   A pointer to the pbs_attribute definition structure.
  * @param subdir The sub-directory path specifying where to write the file.
  * @param name   The parent object name which in this context becomes the file name.
- * @return       Zero on success (File may not be written if attribute is clean) or -1 on error.
+ * @return       Zero on success (File may not be written if pbs_attribute is clean) or -1 on error.
  */
 
 int save_acl(
 
-  attribute     *attr,  /* acl attribute */
-  attribute_def *pdef,  /* attribute def structure */
+  pbs_attribute *attr,  /* acl pbs_attribute */
+  attribute_def *pdef,  /* pbs_attribute def structure */
   char          *subdir, /* sub-directory path */
   char          *name)  /* parent object name = file name */
 
@@ -1089,29 +1106,29 @@ int save_acl(
 /**
  * Reload an Access Control List from its file.
  *
- * @param attr   A pointer to an acl (access control list) attribute.
- * @param pdef   A pointer to the attribute definition structure.
+ * @param attr   A pointer to an acl (access control list) pbs_attribute.
+ * @param pdef   A pointer to the pbs_attribute definition structure.
  * @param subdir The sub-directory path specifying where to read the file.
  * @param name   The parent object name which in this context is the file name.
- * @return       Zero on success (File may not be written if attribute is clean) or -1 on error.
+ * @return       Zero on success (File may not be written if pbs_attribute is clean) or -1 on error.
  */
 
 void recov_acl(
 
-  attribute     *pattr, /* acl attribute */
-  attribute_def *pdef, /* attribute def structure */
+  pbs_attribute *pattr, /* acl pbs_attribute */
+  attribute_def *pdef, /* pbs_attribute def structure */
   char          *subdir, /* directory path */
   char         *name) /* parent object name = file name */
 
   {
-  static char *this_function_name = "recov_acl";
-  char        *buf;
-  int          fds;
-  char         filename1[MAXPATHLEN];
-  char         log_buf[LOCAL_LOG_BUF_SIZE];
+  static char   *this_function_name = "recov_acl";
+  char          *buf;
+  int            fds;
+  char           filename1[MAXPATHLEN];
+  char           log_buf[LOCAL_LOG_BUF_SIZE];
 
-  struct stat  sb;
-  attribute    tempat;
+  struct stat    sb;
+  pbs_attribute  tempat;
 
   errno = 0;
 
